@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/calma/CalmaRdio.c,v 1.4 2001/06/15 17:53:20 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/calma/CalmaRdio.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -26,7 +26,7 @@ static char rcsid[]="$Header: /ufs/repository/magic/calma/CalmaRdio.c,v 1.4 2001
 
 #include <netinet/in.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/utils.h"
@@ -34,19 +34,20 @@ static char rcsid[]="$Header: /ufs/repository/magic/calma/CalmaRdio.c,v 1.4 2001
 #include "database/database.h"
 #include "database/databaseInt.h"
 #include "utils/malloc.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "cif/cif.h"
 #include "cif/CIFint.h"
 #include "cif/CIFread.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/textio.h"
 #include "calma/calmaInt.h"
 
 /* Forward declarations */
 bool calmaReadR8();
+bool calmaSkipBytes();
 
 
 /*
@@ -74,6 +75,7 @@ calmaReadTransform(ptrans, name)
 {
     int nbytes, rtype, flags, angle;
     double dangle;
+    double dmag;
     Transform t;
 
     /* Default is the identity transform */
@@ -99,8 +101,20 @@ calmaReadTransform(ptrans, name)
     if (nbytes < 0) return (FALSE);
     if (rtype == CALMA_MAG)
     {
-	calmaReadError("Magnification ignored for subcell %s\n", name);
-	(void) calmaSkipBytes(nbytes - CALMAHEADERLENGTH);
+	if (nbytes != CALMAHEADERLENGTH + 8)
+	{
+	    (void) calmaSkipBytes(nbytes - CALMAHEADERLENGTH);
+	    return (FALSE);
+	}
+	if (!calmaReadR8(&dmag)) return (FALSE);
+
+        if (dmag != (double)((int)(dmag + 0.5)))
+	{
+	    calmaReadError("Non-integer magnification (%g) in transform\n", dmag);
+	    calmaReadError("Rounding to %d.\n", (int)(dmag + 0.5));
+	}
+	GeoScaleTrans(ptrans, (int)(dmag + 0.5), &t);
+	*ptrans = t;
     }
     else UNREADRH(nbytes, rtype);
 
@@ -521,6 +535,7 @@ calmaSkipTo(what)
  * ----------------------------------------------------------------------------
  */
 
+bool
 calmaSkipBytes(nbytes)
     int nbytes;	/* Skip this many bytes */
 {
