@@ -556,8 +556,10 @@ calmaOutFunc(def, f, cliprect)
     GEO_EXPAND(&def->cd_bbox, CIFCurStyle->cs_radius, &bigArea);
     CIFErrorDef = def;
     CIFGen(def, &bigArea, CIFPlanes, &DBAllTypeBits, TRUE, TRUE, (ClientData) f);
-    CIFGenSubcells(def, &bigArea, CIFPlanes);
-    CIFGenArrays(def, &bigArea, CIFPlanes);
+    if (!CIFHierWriteDisable)
+	CIFGenSubcells(def, &bigArea, CIFPlanes);
+    if (!CIFArrayWriteDisable)
+	CIFGenArrays(def, &bigArea, CIFPlanes);
 
     for (type = 0; type < CIFCurStyle->cs_nLayers; type++)
     {
