@@ -16,13 +16,13 @@
  *     * of the United States of America may require an export license.    * 
  *     *********************************************************************
  *
- * rcsid $Header: /ufs/repository/magic/calma/calmaInt.h,v 1.3 2001/01/12 22:12:13 jsolomon Exp $
+ * rcsid $Header: /usr/cvsroot/magic/calma/calmaInt.h,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $
  */
 
 #ifndef _CALMAINT_H
 #define _CALMAINT_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "database/database.h"
 
 /* Record data types */
@@ -133,11 +133,12 @@ typedef struct
 
 /* Globals for Calma reading */
 extern FILE *calmaInputFile;
-extern int calmaReadScale1;
-extern int calmaReadScale2;
+extern char *calmaFilename;
+extern int  calmaReadScale1;
+extern int  calmaReadScale2;
 extern bool calmaLApresent;
-extern int calmaLAnbytes;
-extern int calmaLArtype;
+extern int  calmaLAnbytes;
+extern int  calmaLArtype;
 
 /*
  * Macros for number representation conversion.
@@ -147,7 +148,7 @@ extern int calmaLArtype;
 #endif
 
 #ifndef	ntohl
-# ifdef	IS_BIG_ENDIAN
+# ifdef	WORDS_BIGENDIAN
 # define ntohl(x)        (x)
 # define ntohs(x)        (x)
 # define htonl(x)        (x)
@@ -213,6 +214,13 @@ typedef union { char uc[4]; unsigned int ul; } FourByteInt;
 extern HashTable calmaLayerHash;
 extern int calmaElementIgnore[];
 extern CellDef *calmaFindCell();
+
+/* (Added by Nishit, 8/18/2004--8/24/2004) */
+extern CellDef *calmaLookCell();
+extern void calmaWriteContact();
+extern CellDef *calmaGetContactCell();
+extern bool calmaIsContactCell;
+
 extern char *calmaRecordName();
 extern void calmaSkipSet();
 
