@@ -23,6 +23,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/cif/
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
 
 #include "utils/magic.h"
@@ -134,6 +135,93 @@ CIFReadCellInit(ptrkeys)
     }
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * cifForgetCell --
+ *
+ * 	This local procedure is used to find a cell in the subcell
+ *	table and remove its CellDef entry. 
+ *
+ * Results:
+ *	FALSE if no such entry was found, otherwise TRUE.
+ *
+ * Side effects:
+ *	Mucks with the CIF cell name hash table.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+bool
+cifForgetCell(cifNum)
+    int cifNum;
+{
+    HashEntry *h;
+
+    h = HashLookOnly(&CifCellTable, (char *)cifNum);
+    if (h == NULL)
+	return FALSE;
+    else if (HashGetValue(h) == 0)
+	return FALSE;
+
+    HashSetValue(h, 0);
+    return TRUE;
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * cifUniqueCell --
+ *
+ *	Attempt to find a cell in the CIF subcell name hash table.
+ *	If one exists, rename its definition so that it will not
+ *	be overwritten when the cell is redefined.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	None.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+cifUniqueCell(cifNum)
+   int cifNum;
+{
+    HashEntry *h;
+    CellDef *def, *testdef;
+    char name[17];
+    int reused = 0;
+
+    h = HashLookOnly(&CifCellTable, (char *)cifNum);
+
+    if ((h == NULL) || HashGetValue(h) == 0)
+    {
+	/* Cell was deleted with "DD".  Don't rename anything */
+	return;
+    }
+
+    sprintf(name, "%d", cifNum);
+    def = DBCellLookDef(name);
+    if (def == (CellDef *)NULL)
+	return;
+
+    testdef = def;
+    while (testdef != NULL)
+    {
+	sprintf(name, "%d_%d", cifNum, ++reused);
+	testdef = DBCellLookDef(name);
+    }
+    DBCellRenameDef(def, name);
+
+    h = HashFind(&CifCellTable, (char *)cifNum);
+    HashSetValue(h, 0);
+
+    CIFReadError("Warning: cell definition %d reused.\n", cifNum);
+}
+	
 /*
  * ----------------------------------------------------------------------------
  *
@@ -159,13 +247,16 @@ cifFindCell(cifNum)
     int cifNum;			/* The CIF number of the desired cell. */
 {
     HashEntry *h;
-    CellDef *def;
+    CellDef *def, *testdef;
+    int reused;
+
+    h = HashFind(&CifCellTable, (char *)cifNum);
 
-    h = HashFind(&CifCellTable, (char *) cifNum);
     if (HashGetValue(h) == 0)
     {
 	char name[15];
-	(void) sprintf(name, "%d", cifNum);
+
+	sprintf(name, "%d", cifNum);
 	def = DBCellLookDef(name);
 	if (def == NULL)
 	{
@@ -177,7 +268,7 @@ cifFindCell(cifNum)
 	     * then it will cause a core dump.
 	     */
 
-	     DBReComputeBbox(def);
+	    DBReComputeBbox(def);
 	}
 	HashSetValue(h, def);
     }
@@ -336,6 +427,12 @@ CIFParseStart()
 	CIFSkipToSemi();
 	return FALSE;
     }
+    else if (number < 0)
+    {
+	CIFReadError("illegal negative symbol number; definition ignored.\n");
+	CIFSkipToSemi();
+	return FALSE;
+    }
 
     if (!CIFParseInteger(&cifReadScale1))
     {
@@ -355,10 +452,20 @@ CIFParseStart()
 	}
     }
 
+    if (cifReadScale1 <= 0 || cifReadScale2 <= 0)
+    {
+	CIFReadError("Illegal scale %d / %d changed to 1 / 1\n",
+		cifReadScale1, cifReadScale2);
+	cifReadScale1 = 1;
+	cifReadScale2 = 1;
+    }
+
+
     /*
      * Set up the cell definition.
      */
 
+    cifUniqueCell(number);
     cifReadCellDef = cifFindCell(number);
     DBCellClearDef(cifReadCellDef);
     DBCellSetAvail(cifReadCellDef);
@@ -578,7 +685,10 @@ CIFParseDelete()
 	CIFSkipToSemi();
 	return FALSE;
     }
-    CIFReadError("definition delete not implemented; ignored.\n");
+
+    /* Unlink the hash entry from its target definition */
+    cifForgetCell(number);
+
     CIFSkipToSemi();
     return TRUE;
 }
@@ -683,6 +793,7 @@ CIFParseCall()
     int		called;
     Transform	transform;
     CellUse 	*use;
+    CellDef	*def;
     
     /* Take the `C'. */
 
@@ -698,11 +809,23 @@ CIFParseCall()
 
     (void) CIFParseTransform(&transform);
 
+    def = cifFindCell(called);
+
+    /* avoid recursion
+     */
+
+    if (DBIsAncestor(def, cifReadCellDef))
+    {
+	CIFReadError("attempt to place cell use inside its own definition!\n");
+	CIFSkipToSemi();
+	return FALSE;
+    }
+
     /* Find the use and add it to the current cell.  Give it an
      * id also.
      */
 
-    use = DBCellNewUse(cifFindCell(called), cifSubcellId);
+    use = DBCellNewUse(def, cifSubcellId);
     (void) DBLinkCell(use, cifReadCellDef);
     DBSetTrans(use, &transform);
     DBPlaceCell(use, cifReadCellDef);
