@@ -18,23 +18,21 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/cif/CIFrdtech.c,v 1.5 2001/07/23 17:49:50 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/cif/CIFrdtech.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <ctype.h>
-#ifdef SYSV
 #include <string.h>
-#endif
+#include <ctype.h>
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "textio/textio.h"
 #include "utils/utils.h"
 #include "cif/CIFint.h"
@@ -226,6 +224,18 @@ CIFParseReadLayers(string, mask)
 	i = CIFReadNameToType(string, TRUE);
 	if (i >= 0)
 	    TTMaskSetType(mask, i);
+	else
+	{
+	    HashEntry *he;
+	    TileTypeBitMask *amask;
+
+	    he = HashLookOnly(&DBTypeAliasTable, string);
+	    if (he != NULL)
+	    {
+		amask = (TileTypeBitMask *)HashGetValue(he);
+		TTMaskSetMask(mask, amask);
+	    }
+	}
 
 	if (p == NULL) break;
 	*p = ',';
@@ -406,7 +416,7 @@ CIFReadTechLine(sectionName, argc, argv)
     HashEntry *he;
     CalmaLayerType clt;
     int calmaLayers[CALMA_LAYER_MAX], calmaTypes[CALMA_LAYER_MAX];
-    int nCalmaLayers, nCalmaTypes, l, t;
+    int nCalmaLayers, nCalmaTypes, l, t, j;
 
     if (argc <= 0) return TRUE;
     else if (argc >= 2) l = strlen(argv[1]);
@@ -434,7 +444,7 @@ CIFReadTechLine(sectionName, argc, argv)
 	for (newStyle = cifReadStyleList; newStyle != NULL; 
 		newStyle = newStyle->crs_next)
 	{
-	    if (!strcmp(newStyle->crs_name, argv[1]))
+	    if (!strncmp(newStyle->crs_name, argv[1], l))
 		break;
 	}
 	if (newStyle == NULL)
@@ -592,7 +602,12 @@ CIFReadTechLine(sectionName, argc, argv)
 	while (*tptr != '\0')
 	{
 	    cptr = strchr(tptr, ',');
-	    if (cptr != NULL) *cptr = '\0';
+	    if (cptr != NULL)
+	    {
+		*cptr = '\0';
+		for (j = 1; isspace(*(cptr - j)); j++)
+		    *(cptr - j) = '\0';
+	    }
 
 	    if (*tptr == '*')
 	    {
@@ -655,7 +670,7 @@ CIFReadTechLine(sectionName, argc, argv)
 	{
 	    cifCurReadOp = (CIFOp *) mallocMagic(sizeof(CIFOp));
 	    cifCurReadOp->co_opcode = CIFOP_OR;
-	    cifCurReadOp->co_bloats = (int *)NULL;
+	    cifCurReadOp->co_client = (ClientData)NULL;
 	    CIFParseReadLayers(argv[2], &cifCurReadOp->co_cifMask);
 	    TTMaskZero(&cifCurReadOp->co_paintMask);
 	    cifCurReadOp->co_next = NULL;
@@ -779,7 +794,7 @@ CIFReadTechLine(sectionName, argc, argv)
     newOp->co_opcode = 0;
     newOp->co_distance = 0;
     newOp->co_next = NULL;
-    newOp->co_bloats = (int *)NULL;
+    newOp->co_client = (ClientData)NULL;
 
     if (strcmp(argv[0], "and") == 0)
 	newOp->co_opcode = CIFOP_AND;
@@ -789,6 +804,8 @@ CIFReadTechLine(sectionName, argc, argv)
 	newOp->co_opcode = CIFOP_OR;
     else if (strcmp(argv[0], "grow") == 0)
 	newOp->co_opcode = CIFOP_GROW;
+    else if (strcmp(argv[0], "grow-grid") == 0)
+	newOp->co_opcode = CIFOP_GROW_G;
     else if (strcmp(argv[0], "shrink") == 0)
 	newOp->co_opcode = CIFOP_SHRINK;
     else
@@ -807,6 +824,7 @@ CIFReadTechLine(sectionName, argc, argv)
 	    break;
 	
 	case CIFOP_GROW:
+	case CIFOP_GROW_G:
 	case CIFOP_SHRINK:
 	    if (argc != 2) goto wrongNumArgs;
 	    newOp->co_distance = atoi(argv[1]);
@@ -913,7 +931,6 @@ CIFReadLoadStyle(stylename)
     invcifr = TechSectionGetMask("cifinput", NULL);
     TechLoad(NULL, invcifr);
 
-    CIFReadTechFinal();
     CIFTechInputScale(DBLambda[0], DBLambda[1], TRUE);
 }
     
