@@ -911,7 +911,7 @@ bool
 is_clockwise(pathHead)
     CIFPath *pathHead;
 {
-    CIFPath *path, *midx, *last;
+    CIFPath *path, *midx = NULL, *last;
     Point *p1, *p2, *p3;
     dlong sdir;
     int minx = INFINITY;
@@ -930,6 +930,8 @@ is_clockwise(pathHead)
 	}
     }
 
+    if (!midx) return TRUE;   /* single-point polygon? */
+
     /* Rare case of colinear points (implies degenerate polygon) requires */
     /* moving along pointlist until points are not colinear and repeating */
     /* the search for the minimum.					  */
