@@ -22,11 +22,9 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/cif/
 #endif  /* not lint */
 
 #include <stdio.h>
-#include <ctype.h>
-#ifdef SYSV
-#include <string.h>
-#endif
 #include <stdlib.h>	/* for atof()	*/
+#include <string.h>
+#include <ctype.h>
 #include <math.h>	/* for pow()	*/
 
 #include "utils/magic.h"
@@ -36,6 +34,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/cif/
 #include "database/database.h"
 #include "utils/tech.h"
 #include "utils/utils.h"
+#include "utils/styles.h"
 #include "cif/CIFint.h"
 #include "calma/calmaInt.h"
 #include "textio/textio.h"
@@ -729,7 +728,7 @@ CIFTechLine(sectionName, argc, argv)
 #ifdef THREE_D
 	newLayer->cl_height = 0.0;
 	newLayer->cl_thick = 0.0;
-	newLayer->cl_renderStyle = 0;
+	newLayer->cl_renderStyle = STYLE_PALEHIGHLIGHTS - TECHBEGINSTYLES;
 #endif
 	if (strcmp(argv[0], "templayer") == 0)
 	    newLayer->cl_flags |= CIF_TEMP;
@@ -1723,7 +1722,6 @@ CIFLoadStyle(stylename)
     invcif = TechSectionGetMask("cifoutput", NULL);
     TechLoad(NULL, invcif);
 
-    CIFTechFinal();
     CIFTechOutputScale(DBLambda[0], DBLambda[1]);
 }
 
