@@ -84,6 +84,11 @@ bool CIFDoCellIdLabels = TRUE;
 
 /* prefix string for pathnames */
 char *CIFPathPrefix = NULL;
+
+/* These are normally FALSE---enable at your own risk! */
+bool CIFHierWriteDisable = FALSE;
+bool CIFArrayWriteDisable = FALSE;
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -376,8 +381,10 @@ cifOutFunc(def, f)
     GEO_EXPAND(&def->cd_bbox, CIFCurStyle->cs_radius, &bigArea);
     CIFErrorDef = def;
     CIFGen(def, &bigArea, CIFPlanes, &DBAllTypeBits, TRUE, TRUE);
-    CIFGenSubcells(def, &bigArea, CIFPlanes);
-    CIFGenArrays(def, &bigArea, CIFPlanes);
+    if (!CIFHierWriteDisable)
+	CIFGenSubcells(def, &bigArea, CIFPlanes);
+    if (!CIFArrayWriteDisable)
+	CIFGenArrays(def, &bigArea, CIFPlanes);
     for (type = 0; type < CIFCurStyle->cs_nLayers; type++)
     {
 	layer = CIFCurStyle->cs_layers[type];
