@@ -82,30 +82,30 @@ CmdEdit(w, cmd)
     CellDef *csave;
     int cmdEditRedisplayFunc();		/* Forward declaration. */
     int cmdEditEnumFunc();		/* Forward declaration. */
+    bool noCurrentUse = FALSE;
 
     if (cmd->tx_argc > 1)
     {
 	TxError("Usage: edit\nMaybe you want the \"load\" command\n");
 	return;
     }
-
-    if (EditCellUse->cu_def->cd_flags & CDNOEDIT)
+    usave = EditCellUse;
+    if (usave != (CellUse *)NULL)
     {
-	TxError("File %s is not writeable.  EDIT not set.\n",
-		EditCellUse->cu_def->cd_file);
-	cmdFoundNewEdit = FALSE;
-	return;
-    }
 
-    /* Record the current edit cell's area for redisplay (now that it's
-     * not the edit cell, it will be displayed differently).  Do this
-     * only in windows where the edit cell is displayed differently from
-     * other cells.
-     */
+        /* Record the current edit cell's area for redisplay (now that it's
+         * not the edit cell, it will be displayed differently).  Do this
+         * only in windows where the edit cell is displayed differently from
+         * other cells.
+         */
     
-    GeoTransRect(&EditToRootTransform, &(EditCellUse->cu_def->cd_bbox), &area);
-    (void) WindSearch(DBWclientID, (ClientData) NULL,
-	    (Rect *) NULL, cmdEditRedisplayFunc, (ClientData) &area);
+        GeoTransRect(&EditToRootTransform, &(usave->cu_def->cd_bbox), &area);
+        (void) WindSearch(DBWclientID, (ClientData) NULL,
+	    	(Rect *) NULL, cmdEditRedisplayFunc, (ClientData) &area);
+
+	DBWUndoOldEdit(EditCellUse, EditRootDef, &EditToRootTransform,
+			&RootToEditTransform);
+    }
 	
     /* Use the position of the point to select one of the currently-selected
      * cells (if there are more than one).  If worst comes to worst, just
@@ -113,15 +113,22 @@ CmdEdit(w, cmd)
      */
     
     (void) ToolGetPoint((Point *) NULL, &pointArea);
-    DBWUndoOldEdit(EditCellUse, EditRootDef,
-	    &EditToRootTransform, &RootToEditTransform);
+
     cmdFoundNewEdit = FALSE;
-    usave = EditCellUse;
     csave = EditRootDef;
+    usave = EditCellUse;
+
     (void) SelEnumCells(FALSE, (bool *) NULL, (SearchContext *) NULL,
 	    cmdEditEnumFunc, (ClientData) &pointArea);
 
-    if (EditCellUse->cu_def->cd_flags & CDNOEDIT)
+    if (EditCellUse == (CellUse *)NULL)
+    {
+	TxError("No cell selected to edit.\n");
+	EditCellUse = usave;
+	EditRootDef = csave;
+	return;
+    }
+    else if (EditCellUse->cu_def->cd_flags & CDNOEDIT)
     {
 	TxError("File %s is not writeable.  Edit not set.\n",
 		EditCellUse->cu_def->cd_file);
@@ -342,7 +349,7 @@ CmdElement(w, cmd)
 		    {
 			TxError("Unknown style \"%s\".", cmd->tx_argv[4]);
 			TxError("Use a number or one of the long names in the"
-				" .dstyle5 file\n");
+				" .dstyle file\n");
 			return;
 		    }
 		}
@@ -469,7 +476,7 @@ CmdElement(w, cmd)
 		    	    {
 				TxError("Unknown style \"%s\".", cmd->tx_argv[5]);
 				TxError("Use a number or one of the long names "
-						"in the .dstyle5 file\n");
+						"in the .dstyle file\n");
 				return;
 			    }
 			}
@@ -673,9 +680,12 @@ CmdErase(w, cmd)
 	}
     }
     DBAdjustLabels(EditCellUse->cu_def, &editRect);
-    DRCCheckThis (EditCellUse->cu_def, TT_CHECKPAINT, &editRect);
-    TTMaskClearType(&mask, L_CELL);
+
+    /* Don't run expensive DRC when only labels were erased */
     TTMaskClearType(&mask, L_LABEL);
+    if (!TTMaskIsZero(&mask))
+	DRCCheckThis (EditCellUse->cu_def, TT_CHECKPAINT, &editRect);
+    TTMaskClearType(&mask, L_CELL);
     SelectClear();
     DBWAreaChanged(EditCellUse->cu_def, &editRect, DBW_ALLWINDOWS, &mask);
     DBReComputeBbox(EditCellUse->cu_def);
