@@ -22,10 +22,8 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/comm
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <ctype.h>
-#ifdef SYSV
 #include <string.h>
-#endif
+#include <ctype.h>
 
 #include "tcltk/tclmagic.h"
 #include "utils/magic.h"
@@ -299,136 +297,6 @@ scalegridusage:
     return;
 }
 
-#ifdef MAGIC_WRAPPER
-/*
- * ----------------------------------------------------------------------------
- *
- * CmdSearch --
- *
- *	This is a low-level search command that allows a hierarchical tile
- *	search to execute a TCL procedure on each tile found.
- *
- *	Use: search [layers] <tcl_procedure>
- *
- *	<tcl_procedure> takes a list containing 4 integer values representing
- *	the bounding box (llx, lly, urx, ury) of the tile, and one value
- *	which is either a string containing the type name of the tile, or a
- *	list of two layers in the case of a split tile, representing LEFT
- *	and RIGHT types, respectively.
- *
- * ----------------------------------------------------------------------------
- */
-
-void
-CmdSearch(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
-{
-    SearchContext scx;
-    TileTypeBitMask visitMask;
-    int xMask, windowMask;
-    char *tclproc, *pptr;
-    int cmdTclProcSrFunc();     /* Fwd declaration */
-    CellDef *rootBoxDef;
-    MagWindow *window;
-
-    bzero(&scx, sizeof(SearchContext));
-    if (!ToolGetBox (&rootBoxDef, NULL))
-    {
-	TxError ("Box tool must be present\n");
-	return;
-    }
-    window = ToolGetBoxWindow (&scx.scx_area, &windowMask);
-    if (!window)
-    {
-	TxError ("Box tool does not exist in any window\n");
-	return;
-    }
-    xMask = ((DBWclientRec *)window->w_clientData)->dbw_bitmask;
-    if ((windowMask & ~xMask) != 0)
-    {
-	window = CmdGetRootPoint((Point *) NULL, (Rect *) NULL);
-	xMask = ((DBWclientRec *) window->w_clientData)->dbw_bitmask;
-	if ((windowMask & xMask) == 0)
-	{
-	    TxPrintf("The box is in more than one window;  use the cursor\n");
-	    TxPrintf("to select the one you want to select from.\n");
-	    return;
-	}
-    }
-    scx.scx_use = (CellUse *) window->w_surfaceID;
-    scx.scx_trans = GeoIdentityTransform;
-
-    if ((cmd->tx_argc == 1) || (cmd->tx_argc > 3))
-    {
-	TxError("Usage: search [layers] <tcl_procedure>\n");
-	return;
-    }
-
-    if (cmd->tx_argc == 3)
-    {
-	if (!CmdParseLayers(cmd->tx_argv[1], &visitMask))
-	    return;
-    }
-    else visitMask = DBAllButSpaceAndDRCBits;
-    pptr = cmd->tx_argv[cmd->tx_argc - 1];
-    if (*pptr == '{')           /* in-line procedure */
-    {
-	tclproc = StrDup(NULL, pptr + 1);
-	pptr = tclproc + strlen(tclproc) - 1;
-	if (*pptr == '}') *pptr = '\0';
-    }
-    else
-	tclproc = StrDup(NULL, cmd->tx_argv[cmd->tx_argc - 1]);
-
-    (void) DBTreeSrTiles(&scx, &visitMask, xMask,
-		cmdTclProcSrFunc, (ClientData) tclproc);
-   
-    freeMagic(tclproc);
-}   
-
-/*
- * cmdTclProcSrFunc --
- *  
- * Filter procedure applied to tiles by cmdSearch() above.
- */ 
-  
-int
-cmdTclProcSrFunc(tile, cxp)
-    Tile *tile;
-    TreeContext *cxp;
-{
-    Rect tileRect, rootRect;
-    SearchContext *scx = cxp->tc_scx;
-    char *tclproc = (char *)cxp->tc_filter->tf_arg;
-    char evalstr[512], *eptr;
-    int rval;
-
-    TiToRect(tile, &tileRect);
-    GeoTransRect(&scx->scx_trans, &tileRect, &rootRect);
-    if (GEO_OVERLAP((&tileRect), &cxp->tc_scx->scx_area))
-    {
-	sprintf(evalstr, "%s %d %d %d %d ", tclproc, rootRect.r_xbot,
-		rootRect.r_ybot, rootRect.r_xtop, rootRect.r_ytop);
-	eptr = evalstr + strlen(evalstr);
-#ifdef NONMANHATTAN
-	if (IsSplit(tile))
-	    sprintf(eptr, "{%s %s}\n", DBTypeLongNameTbl[SplitLeftType(tile)],
-			DBTypeLongNameTbl[SplitRightType(tile)]);
-	else
-#endif
-	    sprintf(eptr, "%s\n", DBTypeLongNameTbl[TiGetType(tile)]);
-
-	rval = Tcl_EvalEx(magicinterp, evalstr, -1, 0);
-	if (rval != TCL_OK) return 1;
-    }
-    /* Allow interrupts in case something goes wrong with the Tcl procedure */
-    if (SigInterruptPending) return 1;
-    return 0;
-}   
-
-#endif
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1952,7 +1820,11 @@ CmdStretch(w, cmd)
 		}
 	    }
 	}
-	else amountx = amounty = 1;
+	else
+	{
+	    amountx = cmdParseCoord(w, "1l", TRUE, TRUE);
+	    amounty = cmdParseCoord(w, "1l", TRUE, FALSE);
+	}
 
 	switch (indx)
 	{
