@@ -63,7 +63,7 @@ TileTypeBitMask CmdYMAllButSpace;
 /*
  * ----------------------------------------------------------------------------
  *
- * cmdParseCoord --
+ * cmdScaleCoord --
  *
  * Replaces the use of atoi() in command parsing of coordinates.  Allows
  * coordinates to be declared in internal units, lambda, user units, or
@@ -85,8 +85,13 @@ TileTypeBitMask CmdYMAllButSpace;
  * specifies whether the given distance is in the X (TRUE) or Y (FALSE)
  * direction.
  *
+ *    This is the "general-purpose" routine, taking a value "scale" so
+ * that returned units can be a fraction of internal units, e.g., to
+ * represent wire centerlines (scale = 2) or highlights (any scale).
+ *
  * Results:
- *      Integer representing the given coordinate in internal units
+ *      Integer representing the given coordinate in internal units,
+ *	multiplied up by "scale".
  *
  * Side effects:
  *	None
@@ -95,10 +100,11 @@ TileTypeBitMask CmdYMAllButSpace;
  */
 
 int
-cmdParseCoord(w, arg, is_relative, is_x)
+cmdScaleCoord(w, arg, is_relative, is_x, scale)
     MagWindow *w;
     char *arg;
     bool is_relative, is_x;
+    int scale;
 {
     char *endptr;
     double dval = 0;
@@ -106,6 +112,7 @@ cmdParseCoord(w, arg, is_relative, is_x)
     DBWclientRec *crec;
 
     dval = strtod(arg, &endptr);
+    dval *= (double)scale;
 
     if (endptr == arg)
     {
@@ -195,7 +202,33 @@ cmdParseCoord(w, arg, is_relative, is_x)
     return round(dval);
 }
 
-
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * cmdParseCoord ---
+ *
+ *	This is the "normal" usage, calling cmdScaleCoord at a scale of 1.
+ *	This routine should be used in all circumstances where the result
+ *	is expected in internal units.
+ *
+ * Results:
+ *      Integer representing the given coordinate in internal units
+ *
+ * Side Effects:
+ *	None.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+int
+cmdParseCoord(w, arg, is_relative, is_x)
+    MagWindow *w;
+    char *arg;
+    bool is_relative, is_x;
+{
+    return cmdScaleCoord(w, arg, is_relative, is_x, 1);
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
