@@ -1227,19 +1227,16 @@ CmdWire(w, cmd)
 		else
 		    width = cmdParseCoord(w, cmd->tx_argv[3], FALSE, TRUE);
 
-		/* By doubling DBLambda[1], we can get back the	*/
-		/* coordinates in 2x internal units, which is	*/
-		/* what is needed by routine PaintWireList.	*/
+		/* Get the coordinates in 2x internal units, which is	*/
+		/* what is needed by routine PaintWireList.		*/
 
-		DBLambda[1] *= 2; 
 		points = (locargc - 4) / 2;
 		plist = (Point *)mallocMagic(points * sizeof(Point));
 		for (i = 0, j = 4; i < points; i++)
 		{
-		    plist[i].p_x = cmdParseCoord(w, cmd->tx_argv[j++], FALSE, TRUE);
-		    plist[i].p_y = cmdParseCoord(w, cmd->tx_argv[j++], FALSE, FALSE);
+		    plist[i].p_x = cmdScaleCoord(w, cmd->tx_argv[j++], FALSE, TRUE, 2);
+		    plist[i].p_y = cmdScaleCoord(w, cmd->tx_argv[j++], FALSE, FALSE, 2);
 		}
-		DBLambda[1] /= 2; 
 
 		def->cd_flags |= CDMODIFIED | CDGETNEWSTAMP;
 		ui.pu_def = def;
