@@ -17,20 +17,21 @@
  */
 
 #ifndef	lint
-static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcell.c,v 1.2 2001/01/12 22:12:19 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/database/DBcell.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif	/* not lint */
 
 #include <sys/types.h>
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "database/databaseInt.h"
-#include "undo/undo.h"
-#include "signals/signals.h"
+#include "utils/undo.h"
+#include "utils/signals.h"
 
 int placeCellFunc();
 int deleteCellFunc();
@@ -155,7 +156,6 @@ DBPlaceCell (celluse, targetcell)
     targetcell->cd_flags |= CDMODIFIED|CDGETNEWSTAMP;
     if (UndoIsEnabled())
 	DBUndoCellUse(celluse, UNDO_CELL_PLACE);
-    celluse->cu_delta = 0;		/* For plowing */
     SigEnableInterrupts();
 }
 
