@@ -18,11 +18,12 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellbox.c,v 1.2 2001/01/12 22:12:19 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/database/DBcellbox.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -31,7 +32,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/database/DBcellbox.c,v 1.2
 #include "database/databaseInt.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 
 
 /*
@@ -67,8 +68,8 @@ DBPrintUseId(scx, name, size)
 			 */
     int size;		/* Maximum number of characters to copy into string. */
 {
-    register CellUse *use = scx->scx_use;
-    register char *sp, *id, *ep;
+    CellUse *use = scx->scx_use;
+    char *sp, *id, *ep;
     char indices[100];
 
     if ((id = use->cu_id) == (char *) NULL)
@@ -183,7 +184,7 @@ DBCellSetModified(cellDef, ismod)
 /*
  * ----------------------------------------------------------------------------
  *
- * dbComputeBbox --
+ * DBComputeUseBbox --
  *
  * Compute the bounding box for a CellUse in coordinates of its parent.
  *
@@ -198,10 +199,10 @@ DBCellSetModified(cellDef, ismod)
  */
 
 void
-dbComputeBbox(use)
-    register CellUse *use;
+DBComputeUseBbox(use)
+    CellUse *use;
 {
-    register Rect *box;
+    Rect *box;
     Rect childRect;
     int xdelta, ydelta;
 
@@ -254,7 +255,7 @@ dbComputeBbox(use)
 
 bool
 DBIsChild(cu1, cu2)
-    register CellUse *cu1, *cu2;
+    CellUse *cu1, *cu2;
 {
     return (cu1->cu_parent == cu2->cu_def);
 }
@@ -310,7 +311,7 @@ DBSetTrans(cellUse, trans)
     Transform *trans;
 {
     cellUse->cu_transform = *trans;
-    dbComputeBbox(cellUse);
+    DBComputeUseBbox(cellUse);
 }
 
 /*
@@ -369,7 +370,7 @@ DBMakeArray(cellUse, rootToCell, xlo, ylo, xhi, yhi, xsep, ysep)
     cellUse->cu_xhi = xhi;
     cellUse->cu_yhi = yhi;
 
-    dbComputeBbox(cellUse);
+    DBComputeUseBbox(cellUse);
 }
 
 /*
@@ -400,7 +401,7 @@ DBMakeArray(cellUse, rootToCell, xlo, ylo, xhi, yhi, xsep, ysep)
 
 void
 DBArrayOverlap(cu, parentRect, pxlo, pxhi, pylo, pyhi)
-    register CellUse *cu;	/* Pointer to cell use which may be an array */
+    CellUse *cu;	/* Pointer to cell use which may be an array */
     Rect *parentRect;		/* Clipping rectangle cu->cu_parent coords */
     int *pxlo, *pxhi;
     int *pylo, *pyhi;
@@ -594,8 +595,8 @@ dbReComputeBboxFunc(cellDef, boundProc, recurseProc)
     Rect redisplayArea;
     CellUse *use;
     CellDef *parent;
-    register Label *label;
-    register bool foundAny;
+    Label *label;
+    bool foundAny;
     int pNum;
 
     /* Cells which declare their bounding box to be fixed	*/
@@ -711,7 +712,7 @@ dbReComputeBboxFunc(cellDef, boundProc, recurseProc)
     for (use = cellDef->cd_parents; use != NULL; use = use->cu_nextuse)
     {
 	redisplayArea = use->cu_bbox;
-	dbComputeBbox(use);
+	DBComputeUseBbox(use);
 	if ((parent = use->cu_parent) != (CellDef *) NULL)
 	{
 	    parent->cd_flags |= CDBOXESCHANGED;
