@@ -281,7 +281,8 @@ DBCellCopyPaint(scx, mask, xMask, targetUse)
     int xMask;			/* Expansion state mask to be used in search */
     CellUse *targetUse;		/* Cell into which material is to be stuffed */
 {
-    int pNum, planeMask;
+    int pNum;
+    PlaneMask planeMask;
     TreeContext cxp;
     TreeFilter filter;
     struct copyAllArg arg;
