@@ -21,9 +21,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/data
 #endif  /* not lint */
 
 #include <stdio.h>
-#ifdef SYSV
 #include <string.h>
-#endif
 
 #include "tcltk/tclmagic.h"
 #include "utils/magic.h"
@@ -1165,6 +1163,9 @@ DBCellDefAlloc()
     cellDef->cd_bbox.r_ytop = 1;
     cellDef->cd_name = (char *) NULL;
     cellDef->cd_file = (char *) NULL;
+#ifdef FILE_LOCKS
+    cellDef->cd_fd = -1;
+#endif
     cellDef->cd_parents = (CellUse *) NULL;
     cellDef->cd_labels = (Label *) NULL;
     cellDef->cd_lastLabel = (Label *) NULL;
