@@ -17,11 +17,11 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/database/DBexpand.c,v 1.2 2001/01/12 22:12:20 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/database/DBexpand.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -73,7 +73,7 @@ DBExpand(cellUse, expandMask, expandFlag)
 {
     CellDef *def;
 
-    if (DBIsExpand(cellUse, expandMask) == expandFlag)
+    if (DBDescendSubcell(cellUse, expandMask) == expandFlag)
 	return;
 
     if (expandFlag)
@@ -182,13 +182,14 @@ dbExpandFunc(scx, arg)
     struct expandArg *arg;	/* Client data from caller */
 {
     CellUse *childUse = scx->scx_use;
+    int n = DBLambda[1];
 
     /*
      * Change the expansion status of this cell if necessary.  Call the
      * client's function if the expansion status has changed.
      */
 
-    if (!DBIsExpand(childUse, arg->ea_xmask))
+    if (!DBDescendSubcell(childUse, arg->ea_xmask))
     {
 	/* If the cell is unavailable, then don't expand it.
 	 */
@@ -234,7 +235,7 @@ dbUnexpandFunc(scx, arg)
      * Change the expansion status of this cell if necessary.
      */
 
-    if (DBIsExpand(childUse, arg->ea_xmask))
+    if (DBDescendSubcell(childUse, arg->ea_xmask))
     {
 	if (!GEO_SURROUND(&childUse->cu_def->cd_bbox, &scx->scx_area)
 	    || GEO_SURROUND(&scx->scx_area, &childUse->cu_def->cd_bbox))
