@@ -30,10 +30,23 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/data
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/file.h>
+
+#ifdef HAVE_DIRENT_H
+#include <dirent.h>
+#include <unistd.h>
+#define direct dirent
+#else
+#include <sys/dir.h>
+#endif
+
 #include <sys/stat.h>
 #include <time.h>
 #include <sys/time.h>
 
+#ifdef HAVE_PATHS_H
+#include <paths.h>
+#endif
+
 #include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -50,6 +63,10 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/data
 #include "utils/malloc.h"
 #include "utils/signals.h"
 
+#ifndef _PATH_TMP
+#define _PATH_TMP "/tmp"
+#endif
+
 extern char *Path;
 
 /* Suffix for all Magic files */
@@ -61,6 +78,9 @@ int DBLambda[2] = {1, 1};
 /* If set to FALSE, don't print warning messages. */
 bool DBVerbose = TRUE;
 
+/* Global name of backup file for this session */
+static char *DBbackupFile = (char *)NULL;
+
 /* Forward declarations */
 char *dbFgets();
 FILE *dbReadOpen();
@@ -80,6 +100,7 @@ bool dbReadUse();
  *
  * ---------------------------------------------------------------------------
  */
+
 static int
 file_is_not_writeable(name)
     char *name;
@@ -88,13 +109,13 @@ file_is_not_writeable(name)
 
     /* attempt to read stat buffer for file */
 
-    if(lstat(name,&sbuf) < 0) return(-1);
+    if (lstat(name,&sbuf) < 0) return(-1);
 
     /* regular file? if not, error */
-    if(!S_ISREG(sbuf.st_mode)) { errno = EACCES; return(-1); }
+    if (!S_ISREG(sbuf.st_mode)) { errno = EACCES; return(-1); }
 
     /* can we write to it? */
-    if(access(name, W_OK) < 0) return(-1);
+    if (access(name, W_OK) < 0) return(-1);
 
     /* the OS thinks we can write to the file;
        but does the file think so?
@@ -114,16 +135,13 @@ file_is_not_writeable(name)
     return(0);
 }
 
-
-
 /*
  * ----------------------------------------------------------------------------
  *
- * DBCellRead --
+ * dbCellReadDef --
  *
- * If the cell is already marked as available (CDAVAILABLE), do nothing.
  *
- * Otherwise, read in the paint for a cell from its associated disk file.
+ * Read in the paint for a cell from its associated disk file.
  * If a filename for the cell is specified, we try to open it
  * somewhere in the search path.  Otherwise, we try the filename
  * already associated with the cell, or the name of the cell itself
@@ -145,18 +163,16 @@ file_is_not_writeable(name)
  *
  * Results:
  *	TRUE if the cell could be read successfully, FALSE
- *	otherwise.  If the cell is already read in, TRUE is
- *	also returned.
+ *	otherwise.
  *
  * Side effects:
+ 	Clears the cell's MODIFIED bit.
  *	Updates the tile planes for the cell definition.
  *	In the event of an error while reading in the cell,
  *	the external integer errno is set to the UNIX error
  *	encountered.
  *
- *	The cell definition is marked as available.
- *	The cell's MODIFIED bit is cleared by this routine.  If
- *	newTechOk is TRUE and the cell's technology is different
+ *	If newTechOk is TRUE and the cell's technology is different
  *	from the current one, the current technology is changed.
  *
  * Errors:
@@ -233,7 +249,8 @@ file_is_not_writeable(name)
  */
 
 bool
-DBCellRead(cellDef, name, ignoreTech)
+dbCellReadDef(f, cellDef, name, ignoreTech)
+    FILE *f;		/* The file, already opened by the caller */
     CellDef *cellDef;	/* Pointer to definition of cell to be read in */
     char *name;		/* Name of file from which to read definition.
 			 * If NULL, then use cellDef->cd_file; if that
@@ -252,7 +269,6 @@ DBCellRead(cellDef, name, ignoreTech)
     char line[2048], tech[50], layername[50];
     PaintResultType *ptable;
     bool result = TRUE;
-    FILE *f;
     Rect *rp;
     int c;
     TileType type, rtype, loctype;
@@ -261,12 +277,6 @@ DBCellRead(cellDef, name, ignoreTech)
     Rect r;
     int n = 1, d = 1;
 
-    if (cellDef->cd_flags & CDAVAILABLE)
-	return (TRUE);
-
-    if ((f = dbReadOpen(cellDef, name, TRUE)) == NULL)
-	return (FALSE);
-
     /*
      * It's very important to disable interrupts during the body of
      * this routine.  Otherwise, if the user types the interrupt key
@@ -313,11 +323,6 @@ DBCellRead(cellDef, name, ignoreTech)
 		TxError("\"cellname delete %s\" and \"load %s -force\" to"
 			" force the cell to load as technology %s\n",
 			cellDef->cd_name, cellDef->cd_name, DBTechName);
-		(void) fclose(f);
-#ifdef FILE_LOCKS
-		flock_close(f, cellDef, name);
-#endif
-		f = NULL;
 		SigEnableInterrupts();
 		return (FALSE);
 	    }
@@ -569,11 +574,6 @@ nextrect:
 
 done:
 
-    (void) fclose(f);
-#ifdef FILE_LOCKS
-    flock_close(f, cellDef, name);
-#endif
-    f = NULL;
     cellDef->cd_flags &= ~(CDMODIFIED|CDBOXESCHANGED|CDGETNEWSTAMP);
 
     /*
@@ -624,13 +624,323 @@ done:
 badfile:
     TxError("File %s contained format error\n", cellDef->cd_name);
     DRCCheckThis(cellDef, TT_CHECKPAINT, (Rect *) NULL);
-#ifdef FILE_LOCKS
-    flock_flag = 1;
-#endif
     result = FALSE;
     goto done;
 }
-
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * DBRemoveBackup() --
+ *
+ * Remove any crash backup file.  This routine is normally called either on
+ * normal program exit, or after the successful read-in of a crash backup.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	If DBbackupFile is non-NULL, then memory is freed, and the backup
+ *	file is removed from the filesystem temp directory.  Otherwise,
+ *	nothing happens.
+ *	
+ * ----------------------------------------------------------------------------
+ */
+
+void
+DBRemoveBackup()
+{
+    if (DBbackupFile != (char *)NULL)
+    {
+	unlink(DBbackupFile);
+	freeMagic(DBbackupFile);
+	DBbackupFile = (char *)NULL;
+    }
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * DBFileRecovery() --
+ *
+ * Get the name of the first backup file found in the /tmp directory,
+ * prompt for action, and if action is "read", then load it.
+ *
+ * Results:
+ *	None.
+ *
+ * Side Effects:
+ *	Prompts for action.
+ *	Loads the contents of the backup file into the database.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+DBFileRecovery(filename)
+    char *filename;
+{
+    DIR *cwd;
+    struct direct *dp;
+    struct stat sbuf;
+    uid_t userid = getuid();
+    time_t recent = 0;
+    char *snptr, *tempdir, tempname[256];
+    int pid;
+    static char *actionNames[] = {"read", "cancel", 0 };
+    char *prompt;
+    int action;
+
+    if (DBbackupFile != NULL)
+    {
+	TxError("Error:  Backup file in use for current session.\n");
+	return;
+    }
+
+    if (filename == NULL)
+    {
+
+	tempdir = getenv("TMPDIR");
+	if (tempdir == NULL) tempdir = _PATH_TMP;
+
+	cwd = opendir(tempdir);
+	if (cwd == NULL) return;
+
+	/* Find the most recent crash file in the temp directory */
+
+	while ((dp = readdir(cwd)) != NULL)
+	{
+	    char *doslash = (tempdir[strlen(tempdir) - 1] == '/') ? "" : "/";
+	    sprintf(tempname, "%s%s%s", tempdir, doslash, dp->d_name);
+	    snptr = tempname + strlen(tempdir);
+	    if (!strncmp(snptr, "MAG", 3))
+	    {
+		char *dotptr = strchr(snptr, '.');
+	        pid = -1;
+		if (dotptr && dotptr > snptr + 3)
+		{
+		    *dotptr = '\0';
+		    if (sscanf(snptr + 3, "%d", &pid) != 1)
+			pid = -1;
+		    *dotptr = '.';
+		}
+		if ((!stat(tempname, &sbuf)) && (sbuf.st_uid == userid))
+		{
+		    if ((recent == 0) || (sbuf.st_ctime > recent))
+		    {
+			/* If the PID encoded in the name belongs to an	*/
+			/* active process, then we should not try to	*/
+			/* open it.					*/
+
+			if (pid != -1)
+			    if (SigCheckProcess(pid) == TRUE)
+				continue;
+
+			recent = sbuf.st_ctime;
+			DBbackupFile = StrDup(&DBbackupFile, tempname);
+		    }
+		}  
+	    } 
+	}
+	closedir(cwd);
+    }
+    else
+    {
+	DBbackupFile = StrDup(&DBbackupFile, filename);
+	recent = 1;
+    }
+
+    if (recent > 0)
+    {			/* There exists at least one temporary file	*/
+			/* belonging to this user.  Ask to recover	*/
+			/* the most recent one.				*/
+
+	prompt = TxPrintString("Recover from backup file %s?", DBbackupFile);
+	action = TxDialog(prompt, actionNames, 0);
+
+	switch(action)
+	{
+	    case 0:	/* Read */
+		if (DBReadBackup(DBbackupFile) == TRUE)
+		    DBRemoveBackup();
+		break;
+	    case 1:	/* Cancel */
+		break;
+	}
+    }
+
+    /* Make sure we've cleared out the backup filename */
+
+    if (DBbackupFile != NULL)
+    {
+	freeMagic(DBbackupFile);
+	DBbackupFile = (char *)NULL;
+    }
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * DBReadBackup --
+ *
+ * This file reads a backup file containing multiple cell definitions.
+ *
+ * Results:
+ *	TRUE if the backup file was read successfully, FALSE otherwise.
+ *
+ * Side Effects:
+ *	Side effects are the side effects caused by dbCellReadDef()
+ *	(see above).  As many cells as are listed in the backup file
+ *	are created and added to the database.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+bool
+DBReadBackup(name)
+    char *name;		/* Name of the backup file */
+{
+    FILE *f;
+    char *filename, *rootname, *chrptr;
+    char line[256];
+    CellDef *cellDef;
+    bool result = TRUE;
+
+    if ((f = PaOpen(name, "r", NULL, "", NULL, NULL)) == NULL)
+    {
+	TxError("Cannot open backup file \"%s\"\n", name);
+	return FALSE;
+    }
+
+    if (dbFgets(line, sizeof(line), f) == NULL)
+    {
+	TxError("Bad backup file %s; can't restore!\n", name);
+	return FALSE;
+    }
+
+    while (strncmp(line, "end", 3) != 0)
+    {
+	if (strncmp(line, "file", 4) == 0)
+	{
+	    filename = line + 4;
+
+	    /* Remove any trailing return character */
+	    chrptr = strrchr(filename, '\n');
+	    if (chrptr != NULL) *chrptr = '\0';
+
+	    /* Remove any trailing file extension */
+	    chrptr = strstr(filename, ".mag");
+	    if (chrptr != NULL) *chrptr = '\0';
+	    rootname = strrchr(filename, '/');
+	    if (rootname == NULL)
+		rootname = filename;
+	    else
+		rootname++;
+
+	    /* Remove any leading whitespace */
+	    while (isspace(*rootname) && *rootname != '\0') rootname++;
+	    if (strlen(rootname) == 0) return FALSE;
+
+ 	    cellDef = DBCellLookDef(rootname);
+	    if (cellDef == (CellDef *)NULL)
+		cellDef = DBCellNewDef(rootname, (char *)NULL);
+
+	    cellDef->cd_flags &= ~CDNOTFOUND;
+	    cellDef->cd_flags |= CDAVAILABLE;
+
+	    if (dbCellReadDef(f, cellDef, filename, TRUE) == FALSE)
+		return FALSE;
+
+	    if (dbFgets(line, sizeof(line), f) == NULL)
+	    {
+		TxError("Error in backup file %s; partial restore only!\n",
+			name);
+		return FALSE;
+	    }
+	}
+	else
+	{
+	    TxError("Error in backup file %s; expected keyword"
+			" \"file\", got \"%s\"!\n", name, line);
+	    return FALSE;
+	}
+    }
+    chrptr = strrchr(line, '\n');
+    if (chrptr > line + 4)
+    {
+	/* Remove the trailing return character */
+	*chrptr = '\0';
+	DBWreload(line + 4);
+    }
+    return TRUE;
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * DBCellRead --
+ *
+ * This is the wrapper for DBCellReadDef.  The routine has been divided into
+ * parts so that a single backup file can be made and recovered, and in
+ * preparation for allowing certain cell definitions to be in-lined into the
+ * output file (such as polygonXXXXX cells generated by the gds read-in).
+ *
+ * Results:
+ *	TRUE if the cell could be read successfully, FALSE
+ *	otherwise.  If the cell is already read in, TRUE is
+ *	also returned.
+ *
+ * Side Effects:
+ *	If the cell is already marked as available (CDAVAILABLE), this
+ *	routine	does nothing (has no side effects).
+ *
+ *	Otherwise, side effects are the side effects caused by
+ *	dbCellReadDef() (see above).  In addition, the cell
+ *	definition is marked as available.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+bool
+DBCellRead(cellDef, name, ignoreTech)
+    CellDef *cellDef;	/* Pointer to definition of cell to be read in */
+    char *name;		/* Name of file from which to read definition.
+			 * If NULL, then use cellDef->cd_file; if that
+			 * is NULL try the name of the cell.
+			 */
+    bool ignoreTech;	/* If FALSE then the technology of the file MUST
+			 * match the current technology, or else the
+			 * subroutine will return an error condition
+			 * without reading anything.  If TRUE, a
+			 * warning will be printed if the technology
+			 * names do not match, but an attempt will be
+			 * made to read the file anyway.
+			 */
+{
+    FILE *f;
+    bool result;
+
+    if (cellDef->cd_flags & CDAVAILABLE)
+	result = TRUE;
+
+    else if ((f = dbReadOpen(cellDef, name, TRUE)) == NULL)
+	result = FALSE;
+
+    else
+    {
+	result = (dbCellReadDef(f, cellDef, name, ignoreTech));
+#ifdef FILE_LOCKS
+	/* Close files that were locked by another user */
+	if (cellDef->cd_fd == -1) fclose(f);
+#else
+	/* When using fcntl() to enforce file locks, we can't	*/
+	/* close the file descriptor without losing the lock.	*/
+	fclose(f);
+#endif
+    }
+    return result;
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -667,23 +977,31 @@ dbReadOpen(cellDef, name, setFileName)
 			 */
 {
     FILE *f;
-    char *filename;
+    char *filename, *realname;
+    bool is_locked;
+
 #ifdef FILE_LOCKS
-    char *realname;
+    if (cellDef->cd_fd != -1)
+    {
+	close(cellDef->cd_fd);
+	cellDef->cd_fd = -1;
+    }
 #endif
 
     if (name != (char *) NULL)
     {
-	f = PaOpen(name, "r", DBSuffix, Path, CellLibPath, &filename);
+	f = PaLockOpen(name, "r", DBSuffix, Path,
+			CellLibPath, &filename, &is_locked);
     }
     else if (cellDef->cd_file != (char *) NULL)
     {
-	f = PaOpen(cellDef->cd_file, "r", "", ".", (char *) NULL, &filename);
+	f = PaLockOpen(cellDef->cd_file, "r", "", ".",
+			(char *) NULL, &filename, &is_locked);
     }
     else
     {
-	f = PaOpen(cellDef->cd_name, "r", DBSuffix,
-			Path, CellLibPath, &filename);
+	f = PaLockOpen(cellDef->cd_name, "r", DBSuffix, Path,
+			CellLibPath, &filename, &is_locked);
     }
 
     if (f == NULL)
@@ -698,32 +1016,33 @@ dbReadOpen(cellDef, name, setFileName)
 	    TxError("File %s couldn't be found\n", cellDef->cd_file);
 	else {
 	    TxError("Cell %s couldn't be found\n", cellDef->cd_name);
-#ifdef FILE_LOCKS
-	    realname = (char *) mallocMagic((unsigned) (strlen(cellDef->cd_name) + strlen(DBSuffix) + 1));
+	    realname = (char *) mallocMagic((unsigned) (strlen(cellDef->cd_name)
+			+ strlen(DBSuffix) + 1));
 	    (void) sprintf(realname, "%s%s", cellDef->cd_name, DBSuffix);
 	    cellDef->cd_file = StrDup(&cellDef->cd_file, realname);
-#endif
 	}
 	cellDef->cd_flags |= CDNOTFOUND;
 	return ((FILE *) NULL);
     }
+
 #ifdef FILE_LOCKS
     else
     {
-	if (file_is_not_writeable (filename) || (flock_flag != 0))
+	if (file_is_not_writeable(filename) || (is_locked == TRUE))
 	{
 	    cellDef->cd_flags |= CDNOEDIT;
-	    if ((flock_flag == 0) && DBVerbose)
+	    if ((is_locked == FALSE) && DBVerbose)
 		TxPrintf("Warning: cell <%s> from file %s is not writeable\n",
 			cellDef->cd_name, filename);
 	}
-	flock_flag = 0;
+	if (is_locked == FALSE)
+	    cellDef->cd_fd = fileno(f);
 	cellDef->cd_flags &= ~CDNOTFOUND;
     }
 #else
-    if (file_is_not_writeable (filename) && DBVerbose)
-	TxPrintf("Warning: cell <%s> from file %s is not writeable\n", cellDef->cd_name,
-		filename);
+    if (file_is_not_writeable(filename) && DBVerbose)
+	TxPrintf("Warning: cell <%s> from file %s is not writeable\n",
+		cellDef->cd_name, filename);
     TxFlushOut();
 
     cellDef->cd_flags &= ~CDNOTFOUND;
@@ -2080,9 +2399,6 @@ DBCellWrite(cellDef, fileName)
 	      TxError("Warning: I/O error in writing file\n");
 	 }
 	 fclose(realf);
-#ifdef FILE_LOCKS
-	 flock_close(realf, cellDef, expandname);
-#endif
 	 realf = NULL;
     }
 
@@ -2267,10 +2583,7 @@ DBGetTech(cellName)
     static char line[512];
     char *p;
 
-    /* The use of "rb" below is a kludge to prevent this call from	*/
-    /* checking if the cell is locked. mdg 09/14/03			*/
-
-    f = PaOpen(cellName, "rb", DBSuffix, Path, CellLibPath, (char **) NULL);
+    f = PaOpen(cellName, "r", DBSuffix, Path, CellLibPath, (char **) NULL);
     if (f == NULL) return NULL;
 
     p = (char *) NULL;
@@ -2289,55 +2602,156 @@ ret:
     f = NULL;
     return (p);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
- * DBPanicSave --
+ * DBWriteBackup --
  *
- * Save all modified cells to disk, in files "cellname.save".
- * This is intended as an emergency measure for cases when magic
- * has to die (eg, upon receiving a SIGTERM signal).
+ * Save all modified cells to "filename", if specified, or the current
+ * setting of DBbackupFile, which is the current name of the crash
+ * backup file.  If "filename" is NULL and no name has been set for
+ * DBbackupFile, then DBbackupFile is generated as a unique filename
+ * in the temp directory.  If "filename" is non-null, then DBbackupFile
+ * is set to this name, erasing any previous value.  If "filename" is
+ * an empty string, then the DBbackupFile reverts to NULL.
  *
  * Results:
- *	None.
+ *	TRUE if the backup file was created, FALSE if an error was
+ *	encountered.
  *
  * Side effects:
- *	Writes cells to disk.
+ *	Writes cells to disk (in a single file).
+ *	Allocates and sets global variable DBbackupFile.
  *	Does NOT clear the modified bits.
  *
  * ----------------------------------------------------------------------------
  */
 
-void
-DBPanicSave()
+bool
+DBWriteBackup(filename)
+    char *filename;
 {
-    int dbPanicFunc();
-    int flags = CDMODIFIED | CDBOXESCHANGED | CDSTAMPSCHANGED;
+    FILE *f;
+    int fd, pid;
+    char *tempdir;
+    MagWindow *mw;
 
-    DBUpdateStamps();
-    (void) DBCellSrDefs(flags, dbPanicFunc, (ClientData) NULL);
+    int dbWriteBackupFunc(), dbCheckModifiedCellsFunc();
+    int flags = CDMODIFIED;
+    int result;
+
+    /* First check if there are any modified cells that need to be written */
+
+    result = DBCellSrDefs(flags, dbCheckModifiedCellsFunc, (ClientData)NULL);
+    if (result == 0) return TRUE;		/* Nothing to write */
+
+    if (filename == NULL)
+    {
+	if (DBbackupFile == (char *)NULL)
+	{
+	    char *doslash, *template;
+
+	    tempdir = getenv("TMPDIR");
+	    if (tempdir == NULL) tempdir = _PATH_TMP;
+	    template = (char *)mallocMagic(20 + strlen(tempdir));
+	    pid = (int)getpid();
+
+	    doslash = (tempdir[strlen(tempdir) - 1] == '/') ? "" : "/";
+	    sprintf(template, "%s/MAG%d.XXXXXX", tempdir, pid);
+
+	    fd = mkstemp(template);
+	    if (fd == -1)
+	    {
+		TxError("Error generating backup file\n");
+		freeMagic(template);
+		return FALSE;
+	    }
+	    close(fd);
+	    DBbackupFile = StrDup(&DBbackupFile, template);
+	    freeMagic(template);
+	    TxPrintf("Created database crash recovery file %s\n", DBbackupFile);
+	}
+	filename = DBbackupFile;
+    }
+    else
+    {
+	if (strlen(filename) == 0)
+	{
+	    DBbackupFile = StrDup(&DBbackupFile, (char *)NULL);
+	    return TRUE;
+	}
+	DBbackupFile = StrDup(&DBbackupFile, filename);
+	TxPrintf("Created database crash recovery file %s\n", DBbackupFile);
+    }
+
+    f = fopen(filename, "w");
+    if (f == NULL)
+    {
+	TxError("Backup file %s cannot be opened for writing.\n", filename);
+	return FALSE;
+    }
+
+    result = DBCellSrDefs(flags, dbWriteBackupFunc, (ClientData)f);
+
+    /* End by printing the keyword "end" followed by the cell to load	*/
+    /* into the first available window, so that we don't have a default	*/
+    /* blank display after crash recovery.				*/
+
+    mw = WindSearchWid(0);
+    if (mw != NULL)
+	fprintf(f, "end %s\n", ((CellUse *)mw->w_surfaceID)->cu_def->cd_name);
+    else
+	fprintf(f, "end\n");
+    fclose(f);
+    return TRUE;
 }
 
 /*
- * Filter function used by DBPanicSave() above.
- * This function is called for each known CellDef whose modified bit
- * is set.
+ * Filter function used by DBWriteBackup() above.
+ * This function writes a single cell definition to the crash backup
+ * file.  Only editable cells whose paint, labels, or subcells have
+ * changed are considered.
  */
 
-    /*ARGSUSED*/
 int
-dbPanicFunc(def)
+dbWriteBackupFunc(def, f)
     CellDef *def;	/* Pointer to CellDef to be saved */
+    FILE *f;		/* File to append to */
 {
-    static char suffix[] = ".save";
-    char savename[512], *name = def->cd_file;
+    char *name = def->cd_file;
+    int result, save_flags;
+
+    if (def->cd_flags & (CDINTERNAL | CDNOEDIT | CDNOTFOUND)) return 0;
+    else if (!(def->cd_flags & CDAVAILABLE)) return 0;
 
-    if (def->cd_flags & CDINTERNAL) return 0;
     if (name == NULL) name = def->cd_name;
-    strncpy(savename, name, sizeof savename - sizeof suffix);
-    savename[sizeof savename - sizeof suffix] = '\0';
-    strcat(savename, ".save");
-    (void) DBCellWrite(def, savename);
-    return 0;
+
+    fprintf(f, "file %s\n", name);
+    
+    /* Save/restore flags such that the crash recovery file write does	*/
+    /* *not* clear the CDMODIFIED, et al., bits				*/
+
+    save_flags = def->cd_flags;
+    def->cd_flags &= ~(CDGETNEWSTAMP);
+    result = DBCellWriteFile(def, f);
+    def->cd_flags = save_flags;
+    return (result == TRUE) ? FALSE : TRUE;
+}
+
+/*
+ * Filter function used by DBWriteBackup() above.
+ * This function checks if at least one cell needs to be written to the
+ * crash backup file.  Only editable cells whose paint, labels, or
+ * subcells have changed are considered.
+ */
+
+int
+dbCheckModifiedCellsFunc(def, cdata)
+    CellDef *def;	/* Pointer to CellDef to be saved */
+    ClientData cdata;	/* Unused */
+{
+    if (def->cd_flags & (CDINTERNAL | CDNOEDIT | CDNOTFOUND)) return 0;
+    else if (!(def->cd_flags & CDAVAILABLE)) return 0;
+    return 1;
 }
