@@ -837,7 +837,7 @@ dbPickFunc2(tile, mask)
     tmp = *dbAdjustPlaneTypes;
     TTMaskClearType(&tmp, type);
     TTMaskClearMask(&mask[0], &tmp);
-    TTMaskClearMask(&tmp, &DBComponentTbl[type]);
+    TTMaskClearMask(&tmp, DBResidueMask(type));
     TTMaskClearMask(&mask[1], &tmp);
     TTMaskSetType(&mask[2], type);
     return 0;
