@@ -46,7 +46,7 @@ TileTypeBitMask DBLayerTypeMaskTbl[NT];
 
 /* Filled in after contact types have been generated */
 TileTypeBitMask DBPlaneTypes[PL_MAXTYPES];
-int 	        DBTypePlaneMaskTbl[NT];
+PlaneMask        DBTypePlaneMaskTbl[NT];
 
 /* --------------------- Data local to this file ---------------------- */
 
@@ -485,7 +485,8 @@ dbTechContactResidues(argc, argv, contactType)
     char **argv;
     TileType contactType;
 {
-    int       homePlane, residuePlane, nresidues, pMask;
+    int       homePlane, residuePlane, nresidues;
+    PlaneMask pMask;
     TileType  residueType, imageType;
     bool      residueOnHome;
     LayerInfo *lp;
@@ -716,7 +717,8 @@ DBHomePlaneTypes(pNum)
     int pNum;
 {
     TileTypeBitMask uMask, *rMask;
-    int m, n, p;
+    int m, n;
+    PlaneMask p;
     LayerInfo *lc, *lr;
 
     TTMaskZero(&uMask);
@@ -895,6 +897,51 @@ DBResidueMask(type)
     return (&li->l_residues);
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * DBFullResidueMask --
+ *
+ *   Get the residue mask of the specified type.  For stacking contacts,
+ *   decompose the contact residues into their component residue layers.
+ *
+ * Results:
+ *	None.
+ *
+ * Side Effects:
+ *	"rmask" is a pointer to a TileTypeBitMask.  The result is placed
+ *	in this location.
+ * ----------------------------------------------------------------------------
+ */
+
+void
+DBFullResidueMask(type, rmask)
+    TileType type;
+    TileTypeBitMask *rmask;
+{
+    TileType t;
+    TileTypeBitMask *lmask;
+    LayerInfo *li, *lr;
+
+    li = &dbLayerInfo[type];
+    lmask = &li->l_residues;
+    TTMaskZero(rmask);
+
+    if (type < DBNumUserLayers)
+    {
+	TTMaskSetMask(rmask, &li->l_residues);
+    }
+    else
+    {
+	for (t = DBNumUserLayers; t < DBNumTypes; t++)
+	    if (TTMaskHasType(lmask, t))
+	    {
+		lr = &dbLayerInfo[t];
+		TTMaskSetMask(rmask, &lr->l_residues);
+	    }
+    }
+}
+
 
 /*
  * ----------------------------------------------------------------------------
