@@ -24,10 +24,8 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/data
 #endif  /* not lint */
 
 #include <stdio.h>
-#include <ctype.h>
-#ifdef SYSV
 #include <string.h>
-#endif
+#include <ctype.h>
 
 #include "tcltk/tclmagic.h"
 #include "utils/magic.h"
@@ -341,24 +339,28 @@ DBPlaneShortName(pNum)
  * ----------------------------------------------------------------------------
  */
 
-int
+PlaneMask
 DBTechTypesToPlanes(mask)
     TileTypeBitMask *mask;
 {
     TileType t;
-    int planeMask, noCellMask;
+    PlaneMask planeMask, noCellMask, retMask;
 
     /* Space tiles are present in all planes but the cell plane */
     noCellMask = ~(PlaneNumToMaskBit(PL_CELL));
-    if (TTMaskHasType(mask, TT_SPACE))
-	return ((PlaneNumToMaskBit(DBNumPlanes)-1) & noCellMask);
+    if (TTMaskHasType(mask, TT_SPACE)) {
+	retMask = PlaneNumToMaskBit(DBNumPlanes) - 1;
+	retMask &= noCellMask;
+	return retMask;
+    }
 
     planeMask = 0;
     for (t = 0; t < DBNumTypes; t++)
 	if (TTMaskHasType(mask, t))
 	    planeMask |= DBTypePlaneMaskTbl[t];
 
-    return (planeMask & noCellMask);
+    retMask = planeMask & noCellMask;
+    return retMask;
 }
 
 
@@ -553,7 +555,7 @@ DBTechPrintCanonicalType(layername)
  * ----------------------------------------------------------------------------
  */
 
-int
+PlaneMask
 DBTechNoisyNameMask(layers, mask)
     char *layers;			/* String to be parsed. */
     TileTypeBitMask *mask;		/* Where to store the layer mask. */
@@ -565,7 +567,7 @@ DBTechNoisyNameMask(layers, mask)
 				*/
     char save;
     bool allBut;
-    int planemask = 0;
+    PlaneMask planemask = 0;
 
     TTMaskZero(mask);
     p = layers;
@@ -736,14 +738,15 @@ DBTechNoisyNameMask(layers, mask)
  * ----------------------------------------------------------------------------
  */
 
-int
+PlaneMask
 DBTechMinSetPlanes(typeMask, newTypes)
     TileTypeBitMask typeMask;		/* Collection of tile types. */
     TileTypeBitMask *newTypes;		/* Filled in with new set of types
 					 * equivalent to typeMask.
 					 */
 {
-    int planes, okPlanes, i, j;
+    int i, j;
+    PlaneMask planes, okPlanes;
     TileTypeBitMask tempTypes;
 
     /*
