@@ -38,11 +38,9 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/data
 PaintResultType DBPaintResultTbl[NP][NT][NT];
 PaintResultType DBEraseResultTbl[NP][NT][NT];
 PaintResultType DBWriteResultTbl[NT][NT];
-unsigned int DBTypePaintPlanesTbl[NT];
-unsigned int DBTypeErasePlanesTbl[NT];
 
-    /* Components */
-TileTypeBitMask DBComponentTbl[NT];
+PlaneMask DBTypePaintPlanesTbl[NT];
+PlaneMask DBTypeErasePlanesTbl[NT];
 
 /* ----------------- Data local to tech file processing --------------- */
 
@@ -484,7 +482,7 @@ dbTechSaveCompose(ruleType, t, argc, argv)
 	 * The planes comprising 't' must be a superset of the
 	 * planes comprising 'r' and the planes comprising 's'.
 	 */
-	if (((PlaneMask(r) | PlaneMask(s)) & ~PlaneMask(t)) != 0)
+	if (((LayerPlaneMask(r) | LayerPlaneMask(s)) & ~LayerPlaneMask(t)) != 0)
 	{
 	    TechError("Component planes are a superset of result planes\n");
 	    return FALSE;
@@ -493,7 +491,7 @@ dbTechSaveCompose(ruleType, t, argc, argv)
 	if (ruleType == RULE_COMPOSE)
 	{
 	    /* Types r and s can't appear on planes outside of t's */
-	    if ((PlaneMask(r) | PlaneMask(s)) != PlaneMask(t))
+	    if ((LayerPlaneMask(r) | LayerPlaneMask(s)) != LayerPlaneMask(t))
 	    {
 		TechError("Union of pair planes must = result planes\n");
 		return FALSE;
@@ -544,9 +542,10 @@ dbTechCheckImages(t, r, s)
     TileType r;	/* First constituent */
     TileType s;			/* Second constituent */
 {
-    int pNum, pMask;
+    int pNum;
+    PlaneMask pMask;
 
-    if (pMask = (PlaneMask(r) & ~PlaneMask(s)))
+    if (pMask = (LayerPlaneMask(r) & ~LayerPlaneMask(s)))
     {
 	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 	    if (PlaneMaskHasPlane(pMask, pNum) && (t != r))
@@ -590,7 +589,8 @@ dbTechAddPaintErase(type, sectionName, argc, argv)
     int argc;
     char *argv[];
 {
-    int pNum, pMask, rMask;
+    int pNum;
+    PlaneMask pMask, rMask;
     TileType t1, t2, tres;
 
     if (argc < 3)
@@ -613,7 +613,7 @@ dbTechAddPaintErase(type, sectionName, argc, argv)
 	    return FALSE;
 	}
 	else
-	   pMask = PlaneMask(t1);
+	   pMask = LayerPlaneMask(t1);
     }
     else
     {
@@ -621,7 +621,7 @@ dbTechAddPaintErase(type, sectionName, argc, argv)
 	else
 	    pMask = PlaneNumToMaskBit(pNum);
     }
-    rMask = PlaneMask(tres);
+    rMask = LayerPlaneMask(tres);
 
     /* (The plane mask of "tres" may be a subset of t1, but NOT vice	*/
     /* versa. Otherwise we will end up creating rules that are not	*/
