@@ -25,6 +25,8 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/dbwi
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
+
 #include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -112,7 +114,7 @@ DBWFeedbackRedraw(window, plane)
 				 * needs to be redrawn.
 				 */
 {
-    long long x, y;
+    dlong x, y;
     int i, halfScale, curStyle, newStyle, curScale;
     CellDef *windowRoot;
     Rect worldArea, screenArea, tmp;
@@ -159,6 +161,13 @@ DBWFeedbackRedraw(window, plane)
 	 */
 
 	tmp = fb->fb_area;
+
+#ifdef NONMANHATTAN
+	/* Don't clip non-Manhattan tiles, or else the diagonals are	*/
+	/* clipped to an incorrect position.				*/
+
+	if (!(fb->fb_style & TT_DIAGONAL))
+#endif
 	GeoClip(&tmp, &worldArea);
 
 	/*
@@ -167,13 +176,13 @@ DBWFeedbackRedraw(window, plane)
 	if (tmp.r_xtop < tmp.r_xbot || tmp.r_ytop < tmp.r_ybot)
 	    continue;
 
-	x = ((long long)(tmp.r_xbot - worldArea.r_xbot) * window->w_scale) + halfScale;
+	x = ((dlong)(tmp.r_xbot - worldArea.r_xbot) * window->w_scale) + halfScale;
 	screenArea.r_xbot = (int)((x/curScale + window->w_origin.p_x) >> SUBPIXELBITS);
-	x = ((long long)(tmp.r_xtop - worldArea.r_xbot) * window->w_scale) + halfScale;
+	x = ((dlong)(tmp.r_xtop - worldArea.r_xbot) * window->w_scale) + halfScale;
 	screenArea.r_xtop = (int)((x/curScale + window->w_origin.p_x) >> SUBPIXELBITS);
-	y = ((long long)(tmp.r_ybot - worldArea.r_ybot) * window->w_scale) + halfScale;
+	y = ((dlong)(tmp.r_ybot - worldArea.r_ybot) * window->w_scale) + halfScale;
 	screenArea.r_ybot = (int)((y/curScale + window->w_origin.p_y) >> SUBPIXELBITS);
-	y = ((long long)(tmp.r_ytop - worldArea.r_ybot) * window->w_scale) + halfScale;
+	y = ((dlong)(tmp.r_ytop - worldArea.r_ybot) * window->w_scale) + halfScale;
 	screenArea.r_ytop = (int)((y/curScale + window->w_origin.p_y) >> SUBPIXELBITS);
 
 	/*
@@ -215,6 +224,20 @@ DBWFeedbackRedraw(window, plane)
 #ifdef NONMANHATTAN
 	if (fb->fb_style & TT_DIAGONAL)
 	    GrDiagonal(&screenArea, fb->fb_style);
+
+	/* Special case (i.e., "hack")---to get a diagonal line	*/
+	/* instead of a triangle, set TT_SIDE but not		*/
+	/* TT_DIAGONAL.	 TT_DIRECTION still indicates / or \	*/
+
+	else if (fb->fb_style & TT_SIDE)
+	{
+	    if (fb->fb_style & TT_DIRECTION)
+	        GrClipLine(screenArea.r_xbot, screenArea.r_ytop,
+			screenArea.r_xtop, screenArea.r_ybot);
+	    else
+	        GrClipLine(screenArea.r_xbot, screenArea.r_ybot,
+			screenArea.r_xtop, screenArea.r_ytop);
+	}
 	else
 #endif
 	GrFastBox(&screenArea);
@@ -246,10 +269,11 @@ dbwFeedbackAlways1()
  */
 
 void
-DBWFeedbackClear()
+DBWFeedbackClear(text)
+    char *text;
 {
     int i, oldCount;
-    Feedback *fb;
+    Feedback *fb, *fl, *fe;
     Rect area;
     CellDef *currentRoot;
 
@@ -260,22 +284,57 @@ DBWFeedbackClear()
     currentRoot = (CellDef *) NULL;
     oldCount = DBWFeedbackCount;
     DBWFeedbackCount = 0;
-    for (i = 0, fb = dbwfbArray; i < oldCount; i++, fb++)
+    fl = (Feedback *)NULL;
+    for (fb = dbwfbArray; fb < dbwfbArray + oldCount; fb++)
     {
-	if (currentRoot != fb->fb_rootDef)
+	if ((text == NULL) || 
+		((fb->fb_text == NULL) && (fl->fb_text == (char *)(-1))) ||
+		((fb->fb_text != NULL) && (strstr(fb->fb_text, text) != NULL)))
 	{
-	    if (currentRoot != (CellDef *) NULL)
-		DBWHLRedraw(currentRoot, &area, TRUE);
-	    area = GeoNullRect;
+	    if (currentRoot != fb->fb_rootDef)
+	    {
+		if (currentRoot != (CellDef *) NULL)
+		    DBWHLRedraw(currentRoot, &area, TRUE);
+		area = GeoNullRect;
+	    }
+	    (void) GeoInclude(&fb->fb_rootArea, &area);
+	    currentRoot = fb->fb_rootDef;
+	    if (fb->fb_text != NULL) freeMagic(fb->fb_text);
+	    if (text != NULL) fb->fb_text = (char *)(-1);
 	}
-	freeMagic(fb->fb_text);
-	fb->fb_text = NULL;
-	(void) GeoInclude(&fb->fb_rootArea, &area);
-	currentRoot = fb->fb_rootDef;
+	fl = fb;
     }
     if (currentRoot != NULL)
 	DBWHLRedraw(currentRoot, &area, TRUE);
     dbwfbNextToShow = 0;
+
+    if (text != NULL)
+    {
+	/* Close up feedback list around removed text entries */
+
+	fl = dbwfbArray;
+	fe = fl + oldCount;
+	for (fb = dbwfbArray; fb < fe; fb++)
+	{
+	    while ((fb->fb_text == (char *)(-1)) && (fb < fe)) fb++;
+	    if (fb < fe) *fl++ = *fb;
+	}
+	DBWFeedbackCount = (int)(fl - dbwfbArray);
+
+	for (fb = fl; fb < dbwfbArray + oldCount; fb++)
+	    fb->fb_text = NULL;
+    }
+
+    /* Free up feedback memory whenever we have removed all feedback entries */
+    if (DBWFeedbackCount == 0)
+    {
+	if (dbwfbArray != NULL) {
+	    freeMagic((char *) dbwfbArray);
+	    dbwfbArray = NULL;
+	}
+	dbwfbSize = 0;
+	return;
+    }
 }
 
 /*
@@ -330,6 +389,7 @@ DBWFeedbackAdd(area, text, cellDef, scaleFactor, style)
 {
     Rect tmp, tmp2, tmp3;
     Transform transform;
+    int i;
     Feedback *fb;
     extern int dbwfbGetTransform();	/* Forward declaration. */
 
@@ -357,33 +417,44 @@ DBWFeedbackAdd(area, text, cellDef, scaleFactor, style)
 
     /* Make sure there's enough space in the current array.  If
      * not, make a new array, copy the old to the new, then delete
-     * the old array.
+     * the old array.  Use memcpy() to make sure this happens very fast.
      */
     
     if (DBWFeedbackCount == dbwfbSize)
     {
 	Feedback *new;
-	int i;
 
 	if (dbwfbSize == 0) dbwfbSize = 32;
-	else dbwfbSize *= 2;
-	new = (Feedback *) mallocMagic((unsigned) dbwfbSize*sizeof(Feedback));
-	for (i = 0; i < dbwfbSize; i++)
-	{
-	    if (i < DBWFeedbackCount) new[i] = dbwfbArray[i];
-	    else new[i].fb_text = NULL;
-	}
-	if (dbwfbArray != NULL)
-	    freeMagic((char *) dbwfbArray);
+	else dbwfbSize <<= 1;
+
+	new = (Feedback *) mallocMagic(dbwfbSize * sizeof(Feedback));
+	memcpy((char *)new, (char *)dbwfbArray, DBWFeedbackCount * sizeof(Feedback));
+
+	for (i = DBWFeedbackCount; i < dbwfbSize; i++) new[i].fb_text = NULL;
+
+	if (dbwfbArray != NULL) freeMagic((char *) dbwfbArray);
 	dbwfbArray = new;
     }
     fb = &dbwfbArray[DBWFeedbackCount];
     fb->fb_area = *area;
-    (void) StrDup(&(fb->fb_text), text);
+
+    /* If the text is the same as the last non-NULL text entry,	*/
+    /* then leave the fb_text entry NULL.			*/
+
+    if (DBWFeedbackCount > 0)
+    {
+	i = DBWFeedbackCount - 1;
+	while (dbwfbArray[i].fb_text == NULL) i--;
+	if (strcmp(dbwfbArray[i].fb_text, text))
+	    StrDup(&(fb->fb_text), text);
+    }
+    else
+	StrDup(&(fb->fb_text), text);
+
     fb->fb_rootDef = dbwfbRootDef;
     fb->fb_scale = scaleFactor;
     fb->fb_style = style;
-    DBWFeedbackCount += 1;
+    DBWFeedbackCount++;
 
     /* Round the area up into Magic coords, and save it too. */
     if (area->r_xtop > 0)
@@ -446,6 +517,21 @@ dbwfbWindFunc()
 {
     return 1;
 }
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * Client initialization
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+dbwFeedbackInit()
+{
+    DBWHLAddClient(DBWFeedbackRedraw);
+}
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -472,15 +558,6 @@ DBWFeedbackShow()
     CellDef *currentRoot;
     Feedback *fb;
     int i;
-    static bool initialized = FALSE;
-
-    /* Do one-time-only initialization. */
-
-    if (!initialized)
-    {
-	DBWHLAddClient(DBWFeedbackRedraw);
-	initialized = TRUE;
-    }
 
     /* Scan through all of the feedback areas starting with dbwfbNextToShow.
      * Save up the total bounding box until the root definition changes,
@@ -551,5 +628,6 @@ DBWFeedbackNth(nth, area, pRootDef, pStyle)
     *area = dbwfbArray[nth].fb_rootArea;
     if (pRootDef != NULL) *pRootDef = dbwfbArray[nth].fb_rootDef;
     if (pStyle != NULL) *pStyle = dbwfbArray[nth].fb_style;
+    while (dbwfbArray[nth].fb_text == NULL) nth--;
     return dbwfbArray[nth].fb_text;
 }
