@@ -201,10 +201,14 @@ DRCCheckThis (celldef, operation, area)
 					 *  of CellDefs waiting for DRC
 					 */
 
-				/*  Insert celldef into list of Defs
-				 *  waiting to be checked, unless it is
-				 *  already there.
-				 */
+    /* Ignore read-only, internal, and vendor GDS cells.  None of these	*/
+    /* can contain DRC errors that could be fixed in magic.		*/
+
+    if (celldef->cd_flags & (CDVENDORGDS | CDNOEDIT | CDINTERNAL)) return;
+
+    /* Insert celldef into list of Defs waiting to be checked, unless	*/
+    /* it is already there.						*/
+
     pback = &DRCPendingRoot;
     p = DRCPendingRoot;
 
