@@ -17,14 +17,14 @@
  */
 
 #ifndef	lint
-static char rcsid[] = "$Header: /ufs/repository/magic/drc/DRCprint.c,v 1.2 2001/01/12 22:12:29 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/drc/DRCprint.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif	/* not lint */
 
 #include <stdio.h>
 #include <string.h>
 #include <sys/types.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
