@@ -18,10 +18,8 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/ext2
 
 #include <stdio.h>
 #include <stdlib.h>		/* for atof() */
-#include <ctype.h>
-#ifdef SYSV
 #include <string.h>
-#endif
+#include <ctype.h>
 
 #include "tcltk/tclmagic.h"
 #include "utils/magic.h"
@@ -247,7 +245,8 @@ Exttospice_Init(interp)
 {
     /* Sanity checks! */
     if (interp == NULL) return TCL_ERROR;
-    if (Tcl_PkgRequire(interp, "Tclmagic", "7.3", 0) == NULL) return TCL_ERROR;
+    if (Tcl_PkgRequire(interp, "Tclmagic", MAGIC_VERSION, 0) == NULL)
+	return TCL_ERROR;
     if (Tcl_InitStubs(interp, "8.1", 0) == NULL) return TCL_ERROR;
 
     TxPrintf("Auto-loading EXTTOSPICE module\n");
@@ -263,7 +262,7 @@ Exttospice_Init(interp)
     if (WindReplaceCommand(DBWclientID, "ext2spice", CmdExtToSpice) < 0)
 	return TCL_ERROR;
 
-    Tcl_PkgProvide(interp, "Exttospice", "7.3");
+    Tcl_PkgProvide(interp, "Exttospice", MAGIC_VERSION);
     return TCL_OK;
 }
 
