@@ -24,9 +24,8 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extf
 #include <stdio.h>
 #include <ctype.h>
 #include <stdlib.h>
-#ifdef SYSV
 #include <string.h>
-#endif
+
 #include "utils/magic.h"
 #include "utils/paths.h"
 #include "utils/geometry.h"
@@ -50,7 +49,7 @@ char *EFArgTech = NULL;		/* -T: Tech specified on command line */
 
     /* Misc globals */
 int EFScale = 0;		/* Uninitialized scale factor */
-char *EFVersion = "7.3";	/* Version number of .ext format we read */
+char *EFVersion = MAGIC_VERSION;/* Version number of .ext format we read */
 char *EFLibPath = NULL;		/* Library search path for .ext files */
 char *EFTech = NULL;
 char *EFStyle = NULL;		/* Start with no extraction style */
@@ -335,7 +334,7 @@ usage:
  *
  * Load the search path string pointed to by 'path'
  * with whatever is specified in the .magicrc files
- * in $CAD_HOME/lib/magic/sys, ~, and ., searched in that
+ * in $CAD_ROOT/magic/sys, ~, and ., searched in that
  * order with the last path taking precedence. See paths.h.
  *
  * Results:
