@@ -18,14 +18,14 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/extflat/EFflat.c,v 1.2 2001/01/12 22:12:35 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extflat/EFflat.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
@@ -53,8 +53,14 @@ HierContext efFlatContext;
 
 /* Forward declarations */
 int efFlatSingleCap();
-int efFlatGlobHash(), efFlatGlobCmp();
-char *efFlatGlobCopy();
+void efFlatGlob();
+int efFlatGlobHash(HierName *);
+bool efFlatGlobCmp(HierName *, HierName *);
+char *efFlatGlobCopy(HierName *);
+void efFlatGlobError(EFNodeName *, EFNodeName *);
+void efAddNodes(HierContext *, bool);
+int efAddOneConn(HierContext *, char *, char *, Connection *);
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -82,7 +88,7 @@ char *efFlatGlobCopy();
  * ----------------------------------------------------------------------------
  */
 
-int
+void
 EFFlatBuild(name, flags)
     char *name;		/* Name of root def being flattened */
     int flags;		/* Say what to flatten; see above */
@@ -117,7 +123,10 @@ EFFlatBuild(name, flags)
 
     if (flags & EF_FLATNODES)
     {
-	efFlatNodes(&efFlatContext);
+	if (flags & EF_NOFLATSUBCKT)
+	    efFlatNodesStdCell(&efFlatContext);
+	else
+	    efFlatNodes(&efFlatContext);
 	efFlatKills(&efFlatContext);
 	efFlatGlob();
     }
@@ -131,6 +140,8 @@ EFFlatBuild(name, flags)
 	efFlatDists(&efFlatContext);
 
     if (efHNStats) efHNPrintSizes("after building flattened table");
+
+ return;
 }
 
 /*
@@ -150,7 +161,7 @@ EFFlatBuild(name, flags)
  * ----------------------------------------------------------------------------
  */
 
-int
+void
 EFFlatDone()
 {
 #ifdef	MALLOCTRACE
@@ -165,6 +176,7 @@ EFFlatDone()
     HashFreeKill(&efCapHashTable);
     HashKill(&efNodeHashTable);
     HashKill(&efHNUseHashTable);
+    return;
 }
 
 
@@ -199,10 +211,11 @@ EFFlatDone()
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatNodes(hc)
     HierContext *hc;
 {
-    (void) efHierSrUses(hc, efFlatNodes, (ClientData) NULL);
+    (void) efHierSrUses(hc, efFlatNodes);
 
     /* Add all our own nodes to the table */
     efAddNodes(hc, FALSE);
@@ -245,6 +258,7 @@ efFlatNodes(hc)
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatNodesStdCell(hc)
     HierContext *hc;
 {
@@ -283,6 +297,7 @@ efFlatNodesStdCell(hc)
  * ----------------------------------------------------------------------------
  */
 
+void
 efAddNodes(hc, stdcell)
     HierContext *hc;
     bool stdcell;
@@ -400,7 +415,7 @@ efAddNodes(hc, stdcell)
  * distinct nodes in the flat table to merge.
  *
  * Results:
- *	None.
+ *      Returns 0
  *
  * Side effects:
  *	May merge nodes from the list efNodeList as per the connection
@@ -409,6 +424,7 @@ efAddNodes(hc, stdcell)
  * ----------------------------------------------------------------------------
  */
 
+int
 efAddConns(hc)
     HierContext *hc;
 {
@@ -443,7 +459,7 @@ efAddConns(hc)
  * NULL, we just adjust the R and C of the node 'name1'.
  *
  * Results:
- *	None.
+ *      Returns 0
  *
  * Side effects:
  *	May merge nodes from the list efNodeList.
@@ -451,6 +467,7 @@ efAddConns(hc)
  * ----------------------------------------------------------------------------
  */
 
+int
 efAddOneConn(hc, name1, name2, conn)
     HierContext *hc;
     char *name1, *name2;	/* These are strings, not HierNames */
@@ -516,7 +533,7 @@ efAddOneConn(hc, name1, name2, conn)
  * ----------------------------------------------------------------------------
  */
 
-int
+void
 efFlatGlob()
 {
     EFNodeName *nameFlat, *nameGlob;
@@ -626,9 +643,10 @@ efFlatGlob()
     }
 
     HashKill(&globalTable);
+    return;
 }
 
-int
+void
 efFlatGlobError(nameGlob, nameFlat)
     EFNodeName *nameGlob, *nameFlat;
 {
@@ -656,18 +674,20 @@ efFlatGlobError(nameGlob, nameFlat)
     if (nn) TxPrintf("    .... (no more names will be printed)\n");
     TxPrintf("I'm merging the two pieces into a single node, but you\n");
     TxPrintf("should be sure eventually to connect them in the layout.\n\n");
+    return;
 }
 
-int
+bool
 efFlatGlobCmp(hierName1, hierName2)
     HierName *hierName1, *hierName2;
 {
     if (hierName1 == hierName2)
-	return 0;
+	return FALSE;
 
-    return (hierName1 == NULL || hierName2 == NULL
-		|| hierName1->hn_hash != hierName2->hn_hash
-		|| strcmp(hierName1->hn_name, hierName2->hn_name) != 0);
+    return ((bool)(hierName1 == NULL || hierName2 == NULL
+		   || hierName1->hn_hash != hierName2->hn_hash
+		   || strcmp(hierName1->hn_name, hierName2->hn_name) != 0
+		  ));
 }
 
 char *
@@ -714,6 +734,7 @@ efFlatGlobHash(hierName)
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatKills(hc)
     HierContext *hc;
 {
@@ -772,6 +793,7 @@ efFlatKills(hc)
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatCaps(hc)
     HierContext *hc;
 {
@@ -803,7 +825,7 @@ efFlatCaps(hc)
  * add the capacitor if either terminal is a killed node.
  *
  * Results:
- *	None.
+ *      Returns 0
  *
  * Side effects:
  *	Adds an entry to efCapHashTable indexed by the nodes of 'name1'
@@ -815,6 +837,7 @@ efFlatCaps(hc)
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatSingleCap(hc, name1, name2, conn)
     HierContext *hc;		/* Contains hierarchical pathname to cell */
     char *name1, *name2;	/* Names of nodes connecting to capacitor */
@@ -876,6 +899,7 @@ efFlatSingleCap(hc, name1, name2, conn)
  * ----------------------------------------------------------------------------
  */
 
+int
 efFlatDists(hc)
     HierContext *hc;
 {
@@ -946,7 +970,7 @@ HashEntry *he;
  * argument promotion in ANSI C
  *
  */
-int
+void
 CapHashSetValue(he, c)
 HashEntry *he; 
 double c;
@@ -957,4 +981,5 @@ double c;
 		HashSetValue(he, capp);
 	}
 	*capp = (EFCapValue) c;
+	return;
 }
