@@ -19,12 +19,13 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtArray.c,v 1.3 2001/07/23 17:49:51 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extract/ExtArray.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -35,8 +36,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtArray.c,v 1.3 2
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
-#include "misc/styles.h"
+#include "utils/signals.h"
+#include "utils/styles.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
 
@@ -440,6 +441,7 @@ extArrayPrimaryFunc(use, trans, x, y, ha)
  * ----------------------------------------------------------------------------
  */
 
+int
 extArrayInterFunc(use, trans, x, y, ha)
     CellUse *use;	/* Use of which this is an array element */
     Transform *trans;	/* Transform from use->cu_def to use->cu_parent
