@@ -20,21 +20,21 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtHard.c,v 1.2 2001/01/12 22:12:37 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extract/ExtHard.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "utils/malloc.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
