@@ -626,7 +626,8 @@ extPathPairDistance(lab1, lab2, pMin, pMax)
 {
     struct extPathArg epa;
     TileTypeBitMask mask;
-    int pMask, pNum;
+    PlaneMask pMask;
+    int pNum;
     Rect r;
 
     /* Skip if either type is space (sanity check) */
@@ -770,7 +771,8 @@ extPathFlood(tile, p, distance, epa)
 {
     TileType type = TiGetType(tile);
     Label *lab2 = epa->epa_lab2;
-    int pMask, pNum, newdistance;
+    int pNum, newdistance;
+    PlaneMask pMask;
     Tile *tp;
     char mesg[512];
     Point p2;
@@ -839,7 +841,7 @@ extPathFlood(tile, p, distance, epa)
     if (DBIsContact(type))
     {
 	int saveplane = epa->epa_pNum;
-	int pMask = DBConnPlanes[type];
+	PlaneMask pMask = DBConnPlanes[type];
 	pMask &= ~(PlaneNumToMaskBit(epa->epa_pNum));
 
 	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
