@@ -18,14 +18,15 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtMain.c,v 1.2 2001/01/12 22:12:37 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extract/ExtMain.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <math.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
@@ -34,13 +35,13 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtMain.c,v 1.2 20
 #include "debug/debug.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/stack.h"
 #include "utils/utils.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
-#include "undo/undo.h"
+#include "utils/main.h"
+#include "utils/undo.h"
 
 /* Imports from elsewhere in this module */
 extern FILE *extFileOpen();
@@ -84,6 +85,9 @@ void extDefParentFunc();
 void extDefParentAreaFunc();
 void extExtractStack();
 
+bool extContainsGeometry();
+bool extContainsCellFunc();
+bool extTimestampMisMatch();
 
 /*
  * ----------------------------------------------------------------------------
@@ -197,6 +201,7 @@ ExtAll(rootUse)
  * cell defs, in preparation for extracting a subtree
  * rooted at a particular def.
  */
+int
 extDefInitFunc(def)
     CellDef *def;
 {
@@ -209,6 +214,7 @@ extDefInitFunc(def)
  * if it hasn't already been pushed, and then recurse
  * on all that def's children.
  */
+int
 extDefPushFunc(use)
     CellUse *use;
 {
@@ -462,7 +468,8 @@ extContainsGeometry(def, allButUse, area)
     CellUse *allButUse;
     Rect *area;
 {
-    int extContainsPaintFunc(), extContainsCellFunc();
+    int extContainsPaintFunc();
+    bool extContainsCellFunc();
     int pNum;
 
     if (TiSrArea((Tile *) NULL, def->cd_planes[PL_CELL], area,
@@ -636,7 +643,7 @@ extExtractStack(stack, doExtract, rootDef)
 	{
 	    if (doExtract)
 	    {
-		ExtCell(def, (char *) NULL, def == rootDef);
+		ExtCell(def, (char *) NULL, (def == rootDef));
 		fatal += extNumFatal;
 		warnings += extNumWarnings;
 	    }
