@@ -85,7 +85,8 @@ ExtFindNeighbors(tile, tilePlaneNum, arg)
     TileType type, t;
     TileTypeBitMask *mask;
     Rect biggerArea;
-    int pNum, pMask, tilesfound;
+    int pNum, tilesfound;
+    PlaneMask pMask;
     PlaneAndArea pla;
 
     tilesfound = 0;
