@@ -23,11 +23,9 @@ static char sccsid[] = "@(#)ExtTech.c	4.8 MAGIC (Berkeley) 10/26/85";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include <math.h>
-#ifdef SYSV
-#include <string.h>
-#endif
 #include <stdlib.h>		/* for strtod() */
+#include <string.h>
+#include <math.h>
 #include <ctype.h>		/* for isspace() */
 
 #include "tcltk/tclmagic.h"
@@ -701,7 +699,6 @@ ExtLoadStyle(stylename)
     invext = TechSectionGetMask("extract", NULL);
     TechLoad(NULL, invext);
 
-    extTechFinalStyle(ExtCurStyle);
     ExtTechScale(DBLambda[0], DBLambda[1]);
 }
 
@@ -880,7 +877,8 @@ ExtTechLine(sectionName, argc, argv)
     int argc;
     char *argv[];
 {
-    int n, l, j, size, val, p1, p2, p3, nterm, pov, pshield, class;
+    int n, l, j, size, val, p1, p2, p3, nterm, class;
+    PlaneMask pshield, pov;
     CapValue capVal, gscap, gccap;
     TileTypeBitMask types1, types2, near, far, ov, shield, subsTypes;
     char *subsName, *transName, *cp, *endptr;
