@@ -81,7 +81,7 @@ void extMore();
 
 void extShowTrans(char *, TileTypeBitMask *, FILE *);
 void extShowMask(TileTypeBitMask *, FILE *);
-void extShowPlanes(int, FILE *);
+void extShowPlanes(PlaneMask, FILE *);
 void extShowConnect(char *, TileTypeBitMask *, FILE *);
 
 
@@ -530,7 +530,7 @@ extShowMask(m, out)
 
 void
 extShowPlanes(m, out)
-    int m;
+    PlaneMask m;
     FILE *out;
 {
     int pNum;
