@@ -18,14 +18,14 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtYank.c,v 1.2 2001/01/12 22:12:38 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/extract/ExtYank.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "tiles/tile.h"
@@ -34,7 +34,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/extract/ExtYank.c,v 1.2 20
 #include "utils/malloc.h"
 #include "textio/textio.h"
 #include "debug/debug.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "extract/extract.h"
 #include "extract/extractInt.h"
 
