@@ -189,35 +189,6 @@ typedef struct {	/* Maintain plane information when pushing	*/
 } PlaneAndArea; 
 
 
-/*
- * The following updates reg->lreg_ll and reg->lreg_pnum so that
- * they are always the lowest leftmost coordinate in a cell, on
- * the plane with the lowest number.
- */
-#define	extSetNodeNum(reg, pn, tp) \
-    if (1) { \
-	if ((pn) < (reg)->lreg_pnum) \
-	{ \
-	    (reg)->lreg_type = TiGetType(tp); \
-	    (reg)->lreg_pnum = (pn); \
-	    (reg)->lreg_ll = (tp)->ti_ll; \
-	} \
-	else if ((pn) == (reg)->lreg_pnum) \
-	{ \
-	    if (LEFT(tp) < (reg)->lreg_ll.p_x) \
-	    { \
-		(reg)->lreg_ll = (tp)->ti_ll; \
-		(reg)->lreg_type = TiGetType(tp); \
-	    } \
-	    else if (LEFT(tp) == (reg)->lreg_ll.p_x \
-		    && BOTTOM(tp) < (reg)->lreg_ll.p_y) \
-	    { \
-		(reg)->lreg_ll.p_y = BOTTOM(tp); \
-		(reg)->lreg_type = TiGetType(tp); \
-	    } \
-	} \
-    } else
-
 /*
  * The following constructs a node name from the plane number 'n'
  * and lower left Point l, and places it in the string 's' (which must
@@ -601,7 +572,7 @@ typedef struct extstyle
 	 * only those types t for which some entry of exts_overlapCap[t][s]
 	 * is non-zero.
 	 */
-    int			 exts_overlapPlanes;
+    PlaneMask		 exts_overlapPlanes;
     TileTypeBitMask	 exts_overlapTypes[NP];
 
 	/*
@@ -611,7 +582,7 @@ typedef struct extstyle
 	 * with which our overlap capacitance is non-zero.
 	 */
     TileTypeBitMask	 exts_overlapOtherTypes[NT];
-    int			 exts_overlapOtherPlanes[NT];
+    PlaneMask		 exts_overlapOtherPlanes[NT];
     
 	/*
 	 * Both exts_overlapShieldTypes[][] and exts_overlapShieldPlanes[][]
@@ -620,7 +591,7 @@ typedef struct extstyle
 	 * shield capacitance between their index types.
 	 */
     TileTypeBitMask	 exts_overlapShieldTypes[NT][NT];
-    int			 exts_overlapShieldPlanes[NT][NT];
+    PlaneMask		 exts_overlapShieldPlanes[NT][NT];
 
 	/*
 	 * The table extOverlapCap[][] is indexed by two types to give the
@@ -729,9 +700,9 @@ typedef struct extstyle
 	 * sideOverlapShieldPlanes is indexed like overlapShieldPlanes, not
 	 * like sideOverlapOtherPlanes.
 	 */
-    int			 exts_sideOverlapOtherPlanes[NT][NT];
+    PlaneMask		 exts_sideOverlapOtherPlanes[NT][NT];
     TileTypeBitMask	 exts_sideOverlapOtherTypes[NT][NT];
-    int			 exts_sideOverlapShieldPlanes[NT][NT];
+    PlaneMask		 exts_sideOverlapShieldPlanes[NT][NT];
 
 	/*
 	 * Both exts_overlapShieldTypes[][] and exts_overlapShieldPlanes[][]
@@ -750,7 +721,7 @@ typedef struct extstyle
 	 * is non-empty), and exts_sidePlanes a mask of those planes containing
 	 * tiles in exts_sideTypes[].
 	 */
-    int			 exts_sidePlanes;
+    PlaneMask		 exts_sidePlanes;
     TileTypeBitMask	 exts_sideTypes[NP];
 
 	/*
@@ -889,7 +860,6 @@ typedef struct node
  */
 extern ClientData extUnInit;
 
-#define extSetRegion(tp,r)	( (tp)->ti_client = (ClientData) (r) )
 #define extGetRegion(tp)	( (tp)->ti_client )
 #define extHasRegion(tp,und)	( (tp)->ti_client != (und) )
 
@@ -897,14 +867,43 @@ extern ClientData extUnInit;
 /* For non-recursive flooding algorithm */
 #define	VISITPENDING	((ClientData) NULL)	/* Marks tiles on stack */
 
+#ifdef NONMANHATTAN
+
+/* Note that this macro depends on MAXPLANES being small	*/
+/* compared to the bit position of TT_SIDE.  Since tens of	*/
+/* thousands of planes is inconceivable, this should not be a	*/
+/* problem.  It is necessary to push the tile's TT_SIDE	bit	*/
+/* because the search algorithm can overwrite it between the	*/
+/* time the tile is pushed and the time that it is popped.	*/
+
 #define	PUSHTILE(tp, pl) \
 	(tp)->ti_client = VISITPENDING; \
-	STACKPUSH((ClientData)tp, extNodeStack); \
-	STACKPUSH((ClientData)pl, extNodeStack)
+	STACKPUSH((ClientData)(pl | ((TileType)(tp)->ti_body & TT_SIDE)), \
+		extNodeStack); \
+	STACKPUSH((ClientData)tp, extNodeStack)
 
 #define POPTILE(tp, pl) \
+	tp = (Tile *) STACKPOP(extNodeStack); \
 	pl = (int) STACKPOP(extNodeStack); \
-	tp = (Tile *) STACKPOP(extNodeStack)
+	if (pl & TT_SIDE) { \
+	   TiSetBody((tp), TiGetTypeExact(tp) | TT_SIDE); \
+	   pl &= (~TT_SIDE); \
+	} \
+	else \
+	   TiSetBody((tp), TiGetTypeExact(tp) & (~TT_SIDE))
+
+#else
+
+#define	PUSHTILE(tp, pl) \
+	(tp)->ti_client = VISITPENDING; \
+	STACKPUSH((ClientData)pl, extNodeStack); \
+	STACKPUSH((ClientData)tp, extNodeStack)
+
+#define POPTILE(tp, pl) \
+	tp = (Tile *) STACKPOP(extNodeStack); \
+	pl = (int) STACKPOP(extNodeStack)
+
+#endif
 
 /* ------------------------- Region finding --------------------------- */
 
@@ -985,8 +984,6 @@ extern struct stack *extNodeStack;
  * according to the connectivity table 'tbl'
  */
 #define extConnectsTo(r, s, tbl)	( TTMaskHasType(&(tbl)[(r)], (s)) )
-#define	extTileConn(tp1, tp2, tbl) \
-	extConnectsTo(TiGetType(tp1), TiGetType(tp2), (tbl))
 
 /* -------------------------------------------------------------------- */
 
