@@ -17,16 +17,21 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/gcr/gcrRiver.c,v 1.2 2001/01/12 22:12:43 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/gcr/gcrRiver.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "gcr/gcr.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
 
+/* Forward declarations */
+bool gcrOverCellVert();
+bool gcrOverCellHoriz();
+
 
 /*
  * ----------------------------------------------------------------------------
