@@ -19,11 +19,12 @@
 
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/graphics/grClip.c,v 1.8 2001/10/19 15:40:10 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/graphics/grClip.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
@@ -182,6 +183,7 @@ bool grClipAddFunc(box, cd)
 }
 
 
+void
 grObsBox(r)
     Rect *r;
 {
@@ -221,7 +223,7 @@ grObsBox(r)
  *	between a line and a box.
  *
  * Results:
- *	False if the line is completely outside of the box.
+ *	FALSE if the line is completely outside of the box.
  *
  * Side Effects:
  *---------------------------------------------------------
@@ -879,10 +881,17 @@ GrBox(MagWindow *mw, Transform *trans, Tile *tile)
 
     if (grCurFill == GR_STCROSS)
     {
+	Rect rnc;
+	/* don't clip contact diagonals */
 	if (needClip || needObscure)
 	{
-	    GrClipLine(r.r_xbot, r.r_ybot, r.r_xtop, r.r_ytop);
-	    GrClipLine(r.r_xbot, r.r_ytop, r.r_xtop, r.r_ybot);
+	    WindSurfaceToScreenNoClip(mw, &r2, &rnc);
+/*
+	    (*grDrawLinePtr)(rnc.r_xbot, rnc.r_ybot, rnc.r_xtop, rnc.r_ytop);
+	    (*grDrawLinePtr)(rnc.r_xbot, rnc.r_ytop, rnc.r_xtop, rnc.r_ybot);
+*/
+	    GrClipLine(rnc.r_xbot, rnc.r_ybot, rnc.r_xtop, rnc.r_ytop);
+	    GrClipLine(rnc.r_xbot, rnc.r_ytop, rnc.r_xtop, rnc.r_ybot);
 	}
 	else
 	{
