@@ -19,7 +19,7 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/graphics/grDStyle.c,v 1.2 2001/01/12 22:12:45 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/graphics/grDStyle.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -27,8 +27,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/graphics/grDStyle.c,v 1.2 20
 #include <string.h>
 #include <ctype.h>
 
-#include "misc/magic.h"
-#include "misc/styles.h"
+#include "utils/magic.h"
+#include "utils/malloc.h"
+#include "utils/styles.h"
 #include "utils/utils.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
@@ -60,11 +61,11 @@ typedef struct _dstylelink {
 
 extern int grBitPlaneMask;	/* Mask of the valid bit-plane bits. */
 
-global dstylelink *dstylehead = NULL;
-global int GrStippleTable[GR_NUM_STIPPLES][8];
-global bool grIsStipple[GR_NUM_STIPPLES];
+static GrGlyphs *grCursorGlyphs = NULL;
+static dstylelink *dstylehead = NULL;
+
+global int **GrStippleTable = NULL;
 global int grNumStipples = 0;
-global GrGlyphs *grCursorGlyphs = NULL;
 
 /* MUST be the same indices as the constants in graphicsInt.h */
 char *fillStyles[] = {
@@ -188,7 +189,7 @@ styleBuildDisplayStyle(line, version)
     char fill[42], ordstr[12], colorName[30];
     dstylelink *newstyle, *sstyle;
 
-    char v6scanline[] = "%10s %o %o %o %40s %d %c %50s";
+    char v6scanline[] = "%10s %o %29s %o %40s %d %c %50s";
     char v7scanline[] = "%10s %i %29s %i %40s %d %c %50s";
 
     char *scanline = (version > 6) ? v7scanline : v6scanline;
@@ -210,7 +211,7 @@ styleBuildDisplayStyle(line, version)
 					 */
 
 	/* Allow colors to be specified by index or by name */
-	if (sscanf(colorName, "%d", &color) == 0)
+	if (sscanf(colorName, ((version > 6) ? "%i" : "%o"), &color) == 0)
 	    color = GrNameToColor(colorName);
 
 	newstyle->style.mask = (mask & grBitPlaneMask);
@@ -228,8 +229,6 @@ styleBuildDisplayStyle(line, version)
 	if (nfill < 0)
 	    res = FALSE;
 	newstyle->style.fill = nfill;
-	if (stipple >= grMaxStipples)
-	    res = FALSE;
 	newstyle->style.stipple = stipple;
 
 	/* Add short style name reverse lookup table entry */
@@ -282,20 +281,33 @@ styleBuildStipplesStyle(line, version)
     }
     else
     {
-	if ( (ord < 0) || (ord >= grMaxStipples) )
+	if (ord < 0)
 	    res = FALSE;
 	else
 	{
-	    int i;
+	    int i, j, ns, **sttable;
 
-	    grNumStipples = MAX(grNumStipples, ord);
-	    grIsStipple[ord] = TRUE;
-	    for (i = 0; i < 8; i++)
+	    ns = MAX(grNumStipples, ord + 1);
+	    if (ns > grNumStipples)
 	    {
-		GrStippleTable[ord][i] = row[i];
+		/* Grab in blocks of 8 to avoid over-use of malloc. . . */
+		if (ns < (grNumStipples + 8)) ns = grNumStipples + 8;
+
+		sttable = (int **)mallocMagic(ns * sizeof(int *));
+	  	for (i = 0; i < grNumStipples; i++)
+		    sttable[i] = GrStippleTable[i];
+		for (; i < ns; i++)
+		{
+		    sttable[i] = (int *)mallocMagic(8 * sizeof(int));
+		    for (j = 0; j < 8; j++)
+			sttable[i][j] = 0;
+		}
+		if (GrStippleTable) freeMagic((char *)GrStippleTable);
+		GrStippleTable = sttable;
+		grNumStipples = ns;
 	    }
-	    if (grSetSPatternPtr)
-		(*grSetSPatternPtr)(ord, GrStippleTable[ord]);
+	    for (i = 0; i < 8; i++)
+		GrStippleTable[ord][i] = row[i];
 	}
     }
     return(res);
@@ -485,7 +497,16 @@ char *libPath;
 		    scount = 0;
 		}
 		else if (strcmp(sectionName, "stipples") == 0)
+		{
 		    section = STIPPLES;
+		    if (grNumStipples > 0)
+		    {
+			while (grNumStipples > 0)
+			    freeMagic((char *)GrStippleTable[--grNumStipples]);
+			freeMagic((char *)GrStippleTable);
+			GrStippleTable = NULL;
+		    }
+		}
 		else
 		{
 		    TxError("Bad section name \"%s\" in .dstyle file.\n",
@@ -546,6 +567,9 @@ char *libPath;
     }
     else
     {
+	if (grSetSPatternPtr)
+	    (*grSetSPatternPtr)(GrStippleTable, grNumStipples);
+
 	if ((MaxTechStyles - TECHBEGINSTYLES) != scount)
 	{
 	    TxError("Error:  Number of pale styles (%d) is different from "
