@@ -22,6 +22,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/grap
 
 #include <stdio.h>
 #include <ctype.h>
+#include <string.h>
 
 #include "utils/magic.h"
 #include "utils/geometry.h"
@@ -214,9 +215,13 @@ GrReadGlyphs(filename, path, libPath, gl)
 		ourgl->gr_num = glyphnummax + 1;
 		for (i = 0; i <= glyphnummax; i++)
 		{
-		    ourgl->gr_glyph[i] = (GrGlyph *) mallocMagic((unsigned) 
-			    sizeof(GrGlyph) +
-			    sizeof(int) * (xmax + 1) * (ymax + 1) );
+		    size_t size = sizeof(GrGlyph) + sizeof(int) * (xmax + 1)
+				* (ymax + 1);
+		    ourgl->gr_glyph[i] = (GrGlyph *) mallocMagic(size);
+
+		    /* Null all the fields initially. */
+		    memset(ourgl->gr_glyph[i], 0, size);
+
 		    ourgl->gr_glyph[i]->gr_origin.p_x = 0;
 		    ourgl->gr_glyph[i]->gr_origin.p_y = 0;
 		    ourgl->gr_glyph[i]->gr_xsize = xmax + 1;
