@@ -8,12 +8,8 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
-#ifdef	SYSV
 #include <string.h>
-#else
-#include <strings.h>
-#endif
+#include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -27,6 +23,7 @@
 #include <GL/glx.h>
 
 #include "tcltk/tclmagic.h"
+#include "utils/main.h"
 #include "utils/magic.h"
 #include "utils/malloc.h"
 #include "utils/magsgtty.h"
@@ -55,8 +52,6 @@ XVisualInfo	*grVisualInfo;
 TOGL_CURRENT toglCurrent= {(Tk_Font)0, 0, 0, 0, 0,
 	(Tk_Window)0, (Window)0, (MagWindow *)NULL};
 
-extern bool TxTkConsole;
-
 /* This is kind of a long story, and very kludgy, but the following
  * things need to be defined as externals because of the way lint
  * libraries are made by taking this module and changing all procedures
