@@ -9,12 +9,8 @@
  */
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
-#ifdef	SYSV
 #include <string.h>
-#else
-#include <strings.h>
-#endif
+#include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <signal.h>
@@ -24,6 +20,7 @@
 #include <X11/keysym.h>
 
 #include "tcltk/tclmagic.h"
+#include "utils/main.h"
 #include "utils/magic.h"
 #include "utils/malloc.h"
 #include "utils/magsgtty.h"
@@ -76,7 +73,6 @@ static LineStyle LineStyleTab[256];
 #define grXsToMagic(n) (DisplayHeight(grXdpy,grXscrn)-(n))
 
 extern bool GrTkInstalledCMap;
-extern bool TxTkConsole;
 
 /* machine-dependent constants - see below */
 #ifdef macosx
@@ -384,6 +380,7 @@ GrTkInit(dispType)
     grXdpy = Tk_Display(grCurrent.window);
     grDisplay.depth = Tk_Depth(grCurrent.window);
     grCurrent.windowid = Tk_WindowId(grCurrent.window);
+    grXscrn = Tk_ScreenNumber(grCurrent.window);
 
     /* The idea here is to first try allocating the required
      * planes out of the default colormap.  This is the kindest,
@@ -1454,7 +1451,10 @@ GrTkCreate(w, name)
 	    /* incompatible visual (see above).				*/
 
 	    if (Tk_Visual(tklayout) == Tk_Visual(tkwind))
+	    {
 		XSetWindowColormap(grXdpy, parent, grXcmap);
+		Tk_SetWindowColormap(tklayout, grXcmap);
+	    }
 	    else
 	    {
 		GrTkInstalledCMap = FALSE;
