@@ -368,6 +368,7 @@ grx11CreateBackingStore(MagWindow *w)
     unsigned int width, height;
     GC gc;
     XGCValues gcValues;
+    int grDepth;
 
     /* ignore for all windows except layout */
     if (w->w_client != DBWclientID) return;
@@ -383,7 +384,11 @@ grx11CreateBackingStore(MagWindow *w)
     gcValues.graphics_exposures = FALSE;
     grXcopyGC = XCreateGC(grXdpy, wind, GCGraphicsExposures, &gcValues);
 
-    pmap = XCreatePixmap(grXdpy, wind, width, height, grDisplay.depth);
+    grDepth = grDisplay.depth;
+    if(grClass == 3) grDepth = 8;  /* Needed since grDisplay.depth is reset
+				     to 7 if Pseudocolor      */
+
+    pmap = XCreatePixmap(grXdpy, wind, width, height, grDepth);
     w->w_backingStore = (ClientData)pmap;
 
     /* TxPrintf("grx11CreateBackingStore area %d %d %d %d\n",
