@@ -17,15 +17,13 @@
  * pointers in order to achieve graphics display independence.
  */
 
-/* rcsid "$Header: /ufs/repository/magic/graphics/graphics.h,v 1.3 2001/04/13 20:03:00 tim Exp $" */
+/* rcsid "$Header: /usr/cvsroot/magic/graphics/graphics.h,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $" */
 
-#define	_GRAPHICS
-#ifndef	_MAGIC
-    int err = Need_to_include_misc/magic_header
-#endif
-#ifndef	_GEOMETRY
-    int err = Need_to_include_utils/geometry_header
-#endif
+#ifndef _GRAPHICS_H
+#define	_GRAPHICS_H
+
+#include "utils/magic.h"
+#include "utils/geometry.h"
 
 /* data structures */
 typedef struct {
@@ -59,6 +57,9 @@ extern void GrClipTo();
 extern void GrClipBox();
 extern void GrClipLine();
 extern bool GrPutText();
+#ifdef NONMANHATTAN
+extern void GrFillPolygon();
+#endif
 extern void (*GrDrawGlyphPtr)();
 extern void (*GrBitBltPtr)();
 extern int  (*GrReadPixelPtr)();
@@ -70,7 +71,7 @@ extern void (*GrDisableTabletPtr)();
 extern void (*GrSetCursorPtr)();
 
 /* graphics routines that are called in the same way for all displays */
-extern bool GrLoadStyles();
+extern int  GrLoadStyles();
 extern bool GrLoadCursors();
 extern bool GrSetDisplay();
 extern bool GrIsDisplay();
@@ -118,6 +119,13 @@ extern char *(*GrWindowNamePtr)(); 	/* Get the window name from a MagWin ptr.
 extern bool (*GrGetCursorPosPtr)(); 	/* Get the current cursor position
 					 */
 
+/* Backing store mechanism (added 4/2/05) */
+extern bool (*GrGetBackingStorePtr)();
+extern bool (*GrScrollBackingStorePtr)();
+extern void (*GrPutBackingStorePtr)();
+extern void (*GrCreateBackingStorePtr)();
+extern void (*GrFreeBackingStorePtr)();
+
 /* Routines called by the signals module just before Magic is stopped
  * (such as via ^Z) and just after it is resumed.
  */
@@ -126,6 +134,9 @@ extern void (*GrResumePtr)();
 #define GrStop	(*GrStopPtr)
 #define GrResume (*GrResumePtr)
 
+/* Number of colors defined in the colormap */
+extern int GrNumColors;
+
 /* Different graphics (OpenGL vs. X11, for instance) have different 
  * definitions of line and rectangle/polygon coordinates.  Usually
  * this boils down to a single pixel difference on rectangle edges.
@@ -142,7 +153,7 @@ extern Rect GrCrossRect;
 
 /* Style tables */
 extern GR_STYLE_LINE *GrStyleTable;
-extern int GrStippleTable[][8];
+extern int **GrStippleTable;
 extern int GrStyleNames[];
 
 #ifndef lint
@@ -168,7 +179,7 @@ extern int GrStyleNames[];
 
 #endif
 
-enum { DISPLAY_IDLE, DISPLAY_IN_PROGRESS, DISPLAY_BREAK_PENDING };
+enum { DISPLAY_IDLE, DISPLAY_IN_PROGRESS, DISPLAY_BREAK_PENDING, DISPLAY_SUSPEND };
 extern unsigned char GrDisplayStatus;
 
 /* constants */
@@ -202,3 +213,5 @@ extern unsigned char GrDisplayStatus;
 
 /* Special full-screen access for window manager only */
 #define GR_LOCK_SCREEN	(MagWindow *)(-1)
+
+#endif /* _GRAPHICS_H */
