@@ -20,9 +20,10 @@
  */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "utils/utils.h"
@@ -31,13 +32,13 @@
 #include "debug/debug.h"
 #include "gcr/gcr.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
-#include "netlist/netlist.h"
-#include "misc/styles.h"
+#include "utils/netlist.h"
+#include "utils/styles.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
 
