@@ -18,13 +18,13 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/grouter/grouteCrss.c,v 1.2 2001/01/12 22:12:51 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/grouter/grouteCrss.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
@@ -35,14 +35,14 @@ static char rcsid[] = "$Header: /ufs/repository/magic/grouter/grouteCrss.c,v 1.2
 #include "database/database.h"
 #include "gcr/gcr.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "dbwind/dbwind.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 
 /* Passed to glCrossChoose() */
 GlPoint *glCrossLookAhead;
