@@ -18,24 +18,24 @@
  */
 
 #ifndef	lint
-static char rcsid[] = "$Header: /ufs/repository/magic/grouter/groutePen.c,v 1.2 2001/01/12 22:12:52 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/grouter/groutePen.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif	/* lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "tiles/tile.h"
 #include "database/database.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "gcr/gcr.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/list.h"
 
 /* Forward declarations */
