@@ -22,26 +22,27 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/irouter/irMain.c,v 1.2 2001/01/12 22:12:53 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/irouter/irMain.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 /*--- includes --- */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "drc/drc.h"
 #include "select/select.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "debug/debug.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "textio/txcommands.h"
 #include "utils/malloc.h"
 #include "utils/list.h"
