@@ -18,13 +18,13 @@
  *     * of the United States of America may require an export license.    * 
  *     *********************************************************************
  *
- * rcsid $Header: /ufs/repository/magic/irouter/irouter.h,v 1.1.1.1 2000/03/29 18:35:07 rajit Exp $
+ * rcsid $Header: /usr/cvsroot/magic/irouter/irouter.h,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $
  */
 
 #ifndef _IROUTER_H
 #define _IROUTER_H
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 
 /*
  * Interface procedures.
