@@ -15,9 +15,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/lef/
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
-#ifdef SYSV
 #include <string.h>
-#endif
 #include <errno.h>
 #include <stdarg.h>
 
@@ -561,11 +559,11 @@ DefReadLocation(use, f, oscale)
     FILE *f;
     float oscale;
 {
-    Rect *r;
+    Rect *r, tr;
     int keyword;
     char *token;
     float x, y;
-    Transform t;
+    Transform t, t2;
 
     static char *orientations[] = {
 	"N", "S", "E", "W", "FN", "FS", "FE", "FW"
@@ -599,52 +597,32 @@ DefReadLocation(use, f, oscale)
     {
 	case DEF_NORTH:
 	    t = GeoIdentityTransform;
-	    t.t_c = -(r->r_xbot);
-	    t.t_f = -(r->r_ybot);
 	    break;
 	case DEF_SOUTH:
 	    t = Geo180Transform;
-	    t.t_c = r->r_xtop;
-	    t.t_f = r->r_ytop;
 	    break;
 	case DEF_EAST:
 	    t = Geo90Transform;
-	    t.t_c = -(r->r_ybot);
-	    t.t_f = r->r_xtop;
 	    break;
 	case DEF_WEST:
 	    t = Geo270Transform;
-	    t.t_c = r->r_ytop;
-	    t.t_f = -(r->r_xbot);
 	    break;
 	case DEF_FLIPPED_NORTH:
 	    t = GeoSidewaysTransform;
-	    t.t_c = r->r_xtop;
-	    t.t_f = -(r->r_ybot);
 	    break;
 	case DEF_FLIPPED_SOUTH:
 	    t = GeoUpsideDownTransform;
-	    t.t_c = -(r->r_xbot);
-	    t.t_f = r->r_ytop;
 	    break;
 	case DEF_FLIPPED_EAST:
 	    t = GeoRef135Transform;
-	    t.t_c = r->r_ytop;
-	    t.t_f = r->r_xtop;
 	    break;
 	case DEF_FLIPPED_WEST:
 	    t = GeoRef45Transform;
-	    t.t_c = -(r->r_ybot);
-	    t.t_f = -(r->r_xbot);
 	    break;
     }
-
-    /* Translate --- see GeoTranslateTrans() in utils/geometry.c */
-    /* t_c -> x translation, t_f -> y translation */
-
-    t.t_c += (int)(x / oscale);
-    t.t_f += (int)(y / oscale);
-
+    GeoTransRect(&t, r, &tr);
+    GeoTranslateTrans(&t, -tr.r_xbot, -tr.r_ybot, &t2);
+    GeoTranslateTrans(&t2, (int)(x / oscale), (int)(y / oscale), &t);
     DBSetTrans(use, &t);
     return;
 
@@ -911,11 +889,15 @@ DefReadComponents(f, rootDef, sname, oscale, total)
 			DBCellDeleteDef(defMacro);
 			defMacro = NULL;
 		    }
+		    else
+		       DBReComputeBbox(defMacro);
 		}
 
 		/* Create a use for this celldef in the edit cell */
 		/* Don't process properties for cells we could not find */
-		if ((defUse = DBCellNewUse(defMacro, usename)) == NULL)
+
+		if ((defMacro == NULL) || ((defUse = DBCellNewUse(defMacro, usename))
+			== NULL))
 		{
 		    LefEndStatement(f);
 		    break;
