@@ -17,7 +17,7 @@
  *  software outside of the United States of America may require an
  *  export license.
  *
- *  $Id: lispIO.c,v 1.3 2001/08/23 13:48:54 tim Exp $
+ *  $Id: lispIO.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $
  *
  *************************************************************************/
 
@@ -30,7 +30,7 @@
 #include "textio/textio.h"
 #include "utils/malloc.h"
 #include "utils/utils.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 /*-----------------------------------------------------------------------------
  *
