@@ -17,7 +17,7 @@
  *  software outside of the United States of America may require an
  *  export license.
  *
- *  $Id: lispMain.c,v 1.3 2001/10/03 22:52:13 rajit Exp $
+ *  $Id: lispMain.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $
  *
  *************************************************************************/
 
@@ -26,7 +26,7 @@
 #include "lisp/lisp.h"
 #include "lispInt.h"
 #include "textio/textio.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "utils/malloc.h"
 
 
