@@ -20,9 +20,12 @@
  *     *********************************************************************
  *
  *
- * rcsid $Header: /ufs/repository/magic/mzrouter/mzInternal.h,v 1.2 2001/01/12 22:13:02 jsolomon Exp $
+ * rcsid $Header: /usr/cvsroot/magic/mzrouter/mzInternal.h,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $
  */
 
+#ifndef _MZINTERNAL_H
+#define _MZINTERNAL_H
+
 /* 
  * Structures etc. that are exported by the mzrouter are defined in
  * mzrouter.h.
@@ -36,23 +39,12 @@
  *  the head of that function.
  */
 
-#ifndef _MAGIC
-int err0 = Need_to_include_misc/magic_header;
+#ifndef _MZROUTER_H
+#include "mzrouter/mzrouter.h"
 #endif
-#ifndef _DATABASE
-int err1 = Need_to_include_database/database_header;
-#endif
-#ifndef _MZROUTER
-int err2 = Need_to_include_mzrouter/mzrouter_header;
-#endif
-#ifndef _LIST
-int err3 = Need_to_include_utils/list_header;
-#endif
-#ifndef _DOUBLEINT
-int err4 = Need_to_include_utils/doubleint_header;
-#endif
-#ifndef _HEAP
-int err5 = Need_to_include_utils/heap_header;
+
+#ifndef _HEAP_H
+#include "utils/heap.h"
 #endif
 
 /* ------------------------ Version String --------------------------- */
@@ -199,9 +191,10 @@ typedef struct numberLine
  * Macros for allocating segments of a RoutePath.
  * During maze-routing, we allocate RoutePaths from our own private area.
  * When the time comes to return a RoutePath, it is copied to permanent
- * storage (i.e., MALLOC/FREE-managed) and the rest of the temporary storage
- * is reclaimed.  This approach avoids the need for additional pointers in
- * each RoutePath that would otherwise be required for storage reclamation.
+ * storage (i.e., mallocMagic/freeMagic-managed) and the rest of the
+ * temporary storage is reclaimed.  This approach avoids the need for
+ * additional pointers in each RoutePath that would otherwise be required
+ * for storage reclamation.
  */
 #define	PATHSPERSEG	200	/* Number of RoutePaths per segment */
 
@@ -288,7 +281,8 @@ extern Heap mzMinCostCompleteHeap;  /* completed paths */
 extern RoutePath *mzAllocRPath();
 extern char *mzCost2String();
 extern char *mzDICost2String();
-extern DoubleInt mzEstimatedCost();
+/* BY NP */
+extern dlong mzEstimatedCost();
 extern RouteType *mzFindRouteType();
 extern void mzNLClear();
 extern int *mzNLGetContainingInterval();
@@ -379,16 +373,19 @@ extern int mzVerbosity;
 extern int mzBloomLimit;
 
 /* minimum estimated total cost for initial paths */
-extern DoubleInt mzMinInitialCost;
+/* BY NP */
+extern dlong mzMinInitialCost;
 
 /* Parameters controlling search */
 extern RouteFloat mzPenalty;
-extern DoubleInt mzWRate;
-extern DoubleInt mzBloomDeltaCost;
-extern DoubleInt mzWWidth;
+/* BY NP */
+extern dlong mzWRate;
+extern dlong mzBloomDeltaCost;
+extern dlong mzWWidth;
 
 /* Statistics */
-extern DoubleInt mzInitialEstimate;  /* Initial estimated cost of route */
+/* BY NP */
+extern dlong mzInitialEstimate;  /* Initial estimated cost of route */
 extern int mzNumBlooms;
 extern int mzNumOutsideBlooms;	/* num blooms from outside window */
 extern int mzNumComplete;	/* number of complete paths so far */
@@ -402,13 +399,15 @@ extern int mzReportInterval;    /* frequency that # of paths etc.
 extern int mzPathsTilReport;	/* counts down to next path report */
 
 /* Variables controling search */
-extern DoubleInt mzWInitialMinToGo;
-extern DoubleInt mzWInitialMaxToGo;
-extern DoubleInt mzBloomMaxCost;	
+/* BY NP */
+extern dlong mzWInitialMinToGo;
+extern dlong mzWInitialMaxToGo;
+extern dlong mzBloomMaxCost;	
 
 /* Search status */
-extern DoubleInt mzWindowMinToGo; /* Window location */
-extern DoubleInt mzWindowMaxToGo;
+/* BY NP */
+extern dlong mzWindowMinToGo; /* Window location */
+extern dlong mzWindowMaxToGo;
 
 /* Marked tile and cell lists */
 extern List *mzMarkedTilesList;
@@ -459,3 +458,5 @@ extern List *mzMarkedCellsList;
 #define RC_WALK		256
 #define RC_WALKC	512
 #define RC_DONE		1024
+
+#endif /* _MZINTERNAL_H */
