@@ -18,19 +18,19 @@
  *     *********************************************************************
  */
 #ifndef lint
-static char rcsid[] = "$Header:";
+static char rcsid[] __attribute__ ((unused)) = "$Header:";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
-#include "../tiles/tile.h"
-#include "utils/doubleint.h"
+#include "tiles/tile.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "utils/list.h"
 #include "debug/debug.h"
@@ -64,7 +64,7 @@ extern void mzStartDown();
  *
  * ----------------------------------------------------------------------------
  */
-
+/* BY NP */
 void
 mzStart(term)
     ColoredPoint *term;
@@ -94,7 +94,7 @@ mzStart(term)
 	mzExtendInitPath(NULL, 			/* path so far */
 			 rL, 			/* layer of new point */
 			 term->cp_point, 	/* new point */
-			 DIZero, 		/* cost of new segment */
+			 0, 		/* cost of new segment */
 			 0, 			/* length of path so far */
 			 directions		/* how to extend init path */
 			 );
@@ -123,13 +123,13 @@ mzStart(term)
  *
  * ----------------------------------------------------------------------------
  */
-
+/* BY NP */
 void
 mzExtendInitPath(path, rL, point, cost, length, directions)
     RoutePath *path;	/* Initial Path, being extended */
     RouteLayer *rL;     /* routelayer of new point */
     Point point;	/* new point for  initPath */
-    DoubleInt cost;     /* cost of new segment */
+    dlong cost;		/* cost of new segment */
     int length;		/* length of path (excluding new segment) */
     int directions;	/* directions to extend init path in */
 {
@@ -159,48 +159,34 @@ mzExtendInitPath(path, rL, point, cost, length, directions)
 	switch (TiGetType(tp))
 	{
 	    case TT_SPACE:
-	    {
 		extendCode = EC_RIGHT | EC_LEFT | EC_UP | EC_DOWN 
-		| EC_CONTACTS;
-	    }
-	    break;
+				| EC_CONTACTS;
+		break;
 
 	    case TT_LEFT_WALK:
-	    {
 		extendCode = EC_WALKRIGHT;
-	    }
-	    break;
+		break;
 			
 	    case TT_RIGHT_WALK:
-	    {
 		extendCode = EC_WALKLEFT;
-	    }
-	    break;
+		break;
 			
 	    case TT_TOP_WALK:
-	    {
 		extendCode = EC_WALKDOWN;
-	    }
-	    break;
+		break;
 			
 	    case TT_BOTTOM_WALK:
-	    {
 		extendCode = EC_WALKUP;
-	    }
-	    break;
+		break;
 
 	    case TT_CONTACT_WALK:
-	    {
 		extendCode = EC_WALKCONTACT;
-	    }
-	    break;
+		break;
 			
 	    case TT_DEST_AREA:
-	    {
 		TxError("Zero length route!\n");
 		extendCode = EC_COMPLETE;
-	    }
-	    break;
+		break;
 	}
 
 	if(extendCode != 0)
@@ -291,7 +277,7 @@ mzExtendInitPath(path, rL, point, cost, length, directions)
  *
  * ----------------------------------------------------------------------------
  */
-
+/* BY NP */
 void
 mzAddInitialContacts(rL, point)
     RouteLayer *rL;     /* routelayer of initial point */
@@ -304,7 +290,7 @@ mzAddInitialContacts(rL, point)
     {
 	RouteContact *rC = (RouteContact *) LIST_FIRST(cL);
 	RouteLayer *newRLayer;
-	DoubleInt conCost;
+	dlong conCost;
 	RoutePath *initPath;
 
 	/* Don't use inactive contacts */
@@ -340,10 +326,8 @@ mzAddInitialContacts(rL, point)
 	
 	/* compute cost of contact */
 	{
-	    
-	    int i = rC->rc_cost;
-	    DOUBLE_CREATE(conCost, i);
-	}
+	    conCost = (dlong) rC->rc_cost;
+ 	}
 
 	/* build path consisting of initial point */
 	{
@@ -351,18 +335,13 @@ mzAddInitialContacts(rL, point)
 	    initPath->rp_rLayer = rL;
 	    initPath->rp_entry = point;
 	    initPath->rp_orient = 'O'; 
-	    initPath->rp_cost = DIZero;
+	    initPath->rp_cost = 0;
 	    initPath->rp_back = NULL;   
 	}
 
 	/* Extend thru new point */
-	mzExtendInitPath(initPath,
-			 newRLayer,
-			 point,
-			 conCost,
-			 0,
-			 (EC_LEFT | EC_RIGHT | EC_UP | EC_DOWN)
-			 );
+	mzExtendInitPath(initPath, newRLayer, point, conCost, 0,
+			(EC_LEFT | EC_RIGHT | EC_UP | EC_DOWN));
     }
 
     return;
@@ -384,7 +363,7 @@ mzAddInitialContacts(rL, point)
  *
  * ----------------------------------------------------------------------------
  */
-
+/* BY NP */
 void
 mzStartRight(path, length)
     RoutePath *path;
@@ -392,7 +371,7 @@ mzStartRight(path, length)
 {
     Point pOrg;		/* point to extend from */
     Point pNew;		/* next interesting point in direction of extension */
-    DoubleInt segCost; 	/* cost of segment between pOrg and pNew */
+    dlong segCost; 	/* cost of segment between pOrg and pNew */
     int extendCode;	/* Interesting directions to extend in */
     Tile *tpThis;	/* Tile containing org point */
     Tile *tpNew;	/* Tile containing new point */
@@ -428,10 +407,10 @@ mzStartRight(path, length)
 	rotate = (TiGetType(tp) != TT_SPACE);
 
 	if (rotate)
-	segCost = DoubleMultII(pNew.p_x - pOrg.p_x,
+	segCost = (dlong)((pNew.p_x - pOrg.p_x) *
 			       path->rp_rLayer->rl_vCost);
 	else
-	segCost = DoubleMultII(pNew.p_x - pOrg.p_x, 
+	segCost = (dlong)((pNew.p_x - pOrg.p_x) *
 			       path->rp_rLayer->rl_hCost);
     }
 
@@ -441,7 +420,7 @@ mzStartRight(path, length)
      */
     {
 	Tile *tp;
-	DoubleInt hintCost;
+	dlong hintCost;
 	int deltaUp, deltaDown, delta;
 	Point lowPt;
 
@@ -484,12 +463,10 @@ mzStartRight(path, length)
 
 		if(delta>0)
 		{
-		    hintCost = DoubleMultII( 
-					    MIN(RIGHT(tp),pNew.p_x)
-					            - lowPt.p_x,
-					    path->rp_rLayer->rl_hintCost);
-		    hintCost = DoubleMultI(hintCost, delta);
-		    DOUBLE_ADD(segCost,segCost,hintCost);
+		    hintCost = (dlong)((MIN(RIGHT(tp),pNew.p_x) - lowPt.p_x) *
+					path->rp_rLayer->rl_hintCost);
+		    hintCost =(dlong) (hintCost * delta);
+		    segCost += hintCost;
 		}
 	    }
 	}
@@ -519,6 +496,7 @@ mzStartRight(path, length)
  * ----------------------------------------------------------------------------
  */
 
+/* BY NP */
 void
 mzStartLeft(path, length)
     RoutePath *path;
@@ -526,7 +504,7 @@ mzStartLeft(path, length)
 {
     Point pOrg;		/* point to extend from */
     Point pNew;		/* next interesting point in direction of extension */
-    DoubleInt segCost; 	/* cost of segment between pOrg and pNew */
+    dlong segCost; 	/* cost of segment between pOrg and pNew */
     int extendCode;	/* Interesting directions to extend in */
     Tile *tpThis;	/* Tile containing org point */
     Tile *tpNew;	/* Tile containing new point */
@@ -562,10 +540,10 @@ mzStartLeft(path, length)
 	rotate = (TiGetType(tp) != TT_SPACE);
 
 	if (rotate)
-	    segCost = DoubleMultII(pOrg.p_x - pNew.p_x,
+	    segCost = (dlong)((pOrg.p_x - pNew.p_x) *
 		path->rp_rLayer->rl_vCost);
 	else
-	    segCost = DoubleMultII(pOrg.p_x - pNew.p_x, 
+	    segCost = (dlong)((pOrg.p_x - pNew.p_x) *
 		path->rp_rLayer->rl_hCost);
     }
 
@@ -575,7 +553,7 @@ mzStartLeft(path, length)
      */
     {
 	Tile *tp;
-	DoubleInt hintCost;
+	dlong hintCost;
 	int deltaUp, deltaDown, delta;
 	Point lowPt;
 
@@ -610,11 +588,10 @@ mzStartLeft(path, length)
 
 		if(delta>0)
 		{
-		    hintCost = DoubleMultII( 
-			MIN(RIGHT(tp),pOrg.p_x) - lowPt.p_x,
-			path->rp_rLayer->rl_hintCost);
-		    hintCost = DoubleMultI(hintCost, delta);
-		    DOUBLE_ADD(segCost,segCost,hintCost);
+		    hintCost = (dlong) ((MIN(RIGHT(tp),pOrg.p_x) - lowPt.p_x) *
+				path->rp_rLayer->rl_hintCost);
+		    hintCost = (dlong)(hintCost * delta);
+		    segCost += hintCost;
 		}
 	    }
 	}
@@ -623,7 +600,6 @@ mzStartLeft(path, length)
     /* Extend thru new point */
     mzExtendInitPath(path, path->rp_rLayer, pNew, segCost, length, EC_LEFT);
 
-
     return;
 }
 
@@ -644,7 +620,7 @@ mzStartLeft(path, length)
  *
  * ----------------------------------------------------------------------------
  */
-
+/* BY NP */
 void
 mzStartUp(path, length)
     RoutePath *path;
@@ -652,7 +628,7 @@ mzStartUp(path, length)
 {
     Point pOrg;		/* point to extend from */
     Point pNew;		/* next interesting point in direction of extension */
-    DoubleInt segCost; 	/* cost of segment between pOrg and pNew */
+    dlong segCost; 	/* cost of segment between pOrg and pNew */
     int extendCode;	/* Interesting directions to extend in */
     Tile *tpThis;	/* Tile containing org point */
     Tile *tpNew;	/* Tile containing new point */
@@ -688,10 +664,10 @@ mzStartUp(path, length)
 	rotate = (TiGetType(tp) != TT_SPACE);
 
 	if (rotate)
-	    segCost = DoubleMultII(pNew.p_y - pOrg.p_y,
+	    segCost = (dlong)((pNew.p_y - pOrg.p_y) *
 		path->rp_rLayer->rl_hCost);
 	else
-	    segCost = DoubleMultII(pNew.p_y - pOrg.p_y, 
+	    segCost = (dlong)((pNew.p_y - pOrg.p_y) *
 		path->rp_rLayer->rl_vCost);
     }
 
@@ -701,7 +677,7 @@ mzStartUp(path, length)
      */
     {
 	Tile *tp;
-	DoubleInt hintCost;
+	dlong hintCost;
 	int deltaRight, deltaLeft, delta;
 	Point lowPt;
 
@@ -736,11 +712,10 @@ mzStartUp(path, length)
 
 		if(delta>0)
 		{
-		    hintCost = DoubleMultII( 
-			MIN(TOP(tp),pNew.p_y) - lowPt.p_y,
-			path->rp_rLayer->rl_hintCost);
-		    hintCost = DoubleMultI(hintCost, delta);
-		    DOUBLE_ADD(segCost,segCost,hintCost);
+		    hintCost = (dlong) ((MIN(TOP(tp),pNew.p_y) - lowPt.p_y) *
+					path->rp_rLayer->rl_hintCost);
+		    hintCost = (dlong) (hintCost * delta);
+		    segCost += hintCost;
 		}
 	    }
 	}
@@ -770,6 +745,7 @@ mzStartUp(path, length)
  * ----------------------------------------------------------------------------
  */
 
+/* BY NP */
 void
 mzStartDown(path, length)
     RoutePath *path;
@@ -777,7 +753,7 @@ mzStartDown(path, length)
 {
     Point pOrg;		/* point to extend from */
     Point pNew;		/* next interesting point in direction of extension */
-    DoubleInt segCost; 	/* cost of segment between pOrg and pNew */
+    dlong segCost; 	/* cost of segment between pOrg and pNew */
     int extendCode;	/* Interesting directions to extend in */
     Tile *tpThis;	/* Tile containing org point */
     Tile *tpNew;	/* Tile containing new point */
@@ -813,10 +789,10 @@ mzStartDown(path, length)
 	rotate = (TiGetType(tp) != TT_SPACE);
 
 	if (rotate)
-	    segCost = DoubleMultII(pOrg.p_y - pNew.p_y,
+	    segCost = (dlong)((pOrg.p_y - pNew.p_y) *
 		path->rp_rLayer->rl_hCost);
 	else
-	    segCost = DoubleMultII(pOrg.p_y - pNew.p_y, 
+	    segCost = (dlong)((pOrg.p_y - pNew.p_y) *
 		path->rp_rLayer->rl_vCost);
     }
 
@@ -826,7 +802,7 @@ mzStartDown(path, length)
      */
     {
 	Tile *tp;
-	DoubleInt hintCost;
+	dlong hintCost;
 	int deltaRight, deltaLeft, delta;
 	Point lowPt;
 
@@ -861,11 +837,10 @@ mzStartDown(path, length)
 
 		if(delta>0)
 		{
-		    hintCost = DoubleMultII( 
-			MIN(TOP(tp),pOrg.p_y) - lowPt.p_y,
-			path->rp_rLayer->rl_hintCost);
-		    hintCost = DoubleMultI(hintCost, delta);
-		    DOUBLE_ADD(segCost,segCost,hintCost);
+		    hintCost = (dlong) ((MIN(TOP(tp),pOrg.p_y) - lowPt.p_y) *
+				path->rp_rLayer->rl_hintCost);
+		    hintCost = (dlong)(hintCost * delta);
+		    segCost += hintCost;
 		}
 	    }
 	}
@@ -894,6 +869,7 @@ mzStartDown(path, length)
  * ----------------------------------------------------------------------------
  */
 
+/* BY NP */
 void
 mzStartContact(path)
     RoutePath *path;
@@ -902,7 +878,7 @@ mzStartContact(path)
     int extendCode;	/* Interesting directions to extend in */
     RouteContact *rC;   /* Route contact to make connection with */
     RouteLayer *newRL;	/* Route layer of dest area */ 
-    DoubleInt conCost;	/* Cost of final contact */
+    dlong conCost;	/* Cost of final contact */
 
     /* DEBUG - trace calls to this routine. */
     if (DebugIsSet(mzDebugID, mzDebMaze))
@@ -946,8 +922,7 @@ mzStartContact(path)
 	
     /* compute contact cost */
     {
-	int i = rC->rc_cost;
-	DOUBLE_CREATE(conCost, i);
+	conCost = (dlong) rC->rc_cost;
     }
 
     /* Add final point */
@@ -956,4 +931,3 @@ mzStartContact(path)
     return;
 }
 
-
