@@ -18,28 +18,28 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzSubrs.c,v 1.2 2001/01/12 22:13:03 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/mzrouter/mzSubrs.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
-/*--- includes --- */
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "drc/drc.h"
 #include "select/select.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "debug/debug.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "textio/txcommands.h"
 #include "utils/malloc.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/geofast.h"
 #include "utils/list.h"
 #include "utils/touchingtypes.h"
@@ -743,22 +743,16 @@ mzPaintContact(path, prev)
     /* compute the contact tileType */
     cType = rC->rc_routeType.rt_tileType;
 
-    /* Paint the contact */
-    pNum = DBPlane(cType);
-    DBPaintPlane(mzResultDef->cd_planes[pNum], &r,
-			DBStdPaintTbl(cType, pNum),
-			(PaintUndoInfo *) NULL);
+    /* Paint the contact on all connected mask planes */
+    /* (should just let DBPaint() do this. . . ) */
 
-    /* Paint it on all connected mask planes */
-    if (DBConnPlanes[cType])
+    if (DBIsContact(cType))
     {
-	for (pNumC = PL_TECHDEPBASE; pNumC < DBNumPlanes; pNumC++)
-	    if (PlaneMaskHasPlane(DBConnPlanes[cType], pNumC))
-	    {
-		DBPaintPlane(mzResultDef->cd_planes[pNumC],
-			&r, DBStdPaintTbl(cType, pNumC),
+	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
+	    if (PlaneMaskHasPlane(DBConnPlanes[cType], pNum))
+		DBPaintPlane(mzResultDef->cd_planes[pNum],
+			&r, DBStdPaintTbl(cType, pNum),
 			(PaintUndoInfo *) NULL);
-	    }
     }
 
     return;
