@@ -19,16 +19,17 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzTestCmd.c,v 1.2 2001/01/12 22:13:03 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/mzrouter/mzTestCmd.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "tiles/tile.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "irouter/irouter.h"
 #include "graphics/graphics.h"
@@ -36,13 +37,12 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzTestCmd.c,v 1.2
 #include "dbwind/dbwind.h"
 #include "dbwind/dbwtech.h"
 #include "textio/txcommands.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/utils.h"
 #include "commands/commands.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "utils/malloc.h"
 #include "utils/list.h"
-#include "utils/doubleint.h"
 #include "utils/heap.h"
 #include "mzrouter/mzrouter.h"
 #include "mzrouter/mzInternal.h"
