@@ -17,19 +17,19 @@
  *     *********************************************************************
  */
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzXtndDown.c,v 1.2 2001/01/12 22:13:03 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/mzrouter/mzXtndDown.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
-#include "../tiles/tile.h"
-#include "utils/doubleint.h"
+#include "tiles/tile.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "utils/list.h"
 #include "debug/debug.h"
@@ -52,7 +52,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzXtndDown.c,v 1.
  *
  * ----------------------------------------------------------------------------
  */
-
+/* BY NP */
 void
 mzExtendDown(path)
     RoutePath *path;
@@ -60,7 +60,7 @@ mzExtendDown(path)
     Point pOrg;		/* point to extend from */
     Point pStep;	/* one unit from pOrg in direction of extension */
     Point pNew;		/* next interesting point in direction of extension */
-    DoubleInt segCost; 	/* cost of segment between pOrg and pNew */
+    dlong segCost; 	/* cost of segment between pOrg and pNew */
     RouteLayer *rL;     /* temp variable for routelayers */
     int reasons;	/* Reasons point is interesting.  Used to
 			 * avoid extensions in uninteresting directions.
@@ -539,11 +539,11 @@ mzExtendDown(path)
 	rotate = (TiGetType(tp) != TT_SPACE);
 
 	if (rotate)
-	    segCost = DoubleMultII(pOrg.p_y - pNew.p_y,
-		path->rp_rLayer->rl_hCost);
+	    segCost = (dlong) ((pOrg.p_y - pNew.p_y) *
+			  path->rp_rLayer->rl_hCost);
 	else
-	    segCost = DoubleMultII(pOrg.p_y - pNew.p_y, 
-		path->rp_rLayer->rl_vCost);
+	    segCost = (dlong) ((pOrg.p_y - pNew.p_y) *
+													path->rp_rLayer->rl_vCost);
     }
 
     /* Compute additional cost for paralleling nearest hint segment */
@@ -552,7 +552,7 @@ mzExtendDown(path)
      */
     {
 	Tile *tp;
-	DoubleInt hintCost;
+	dlong hintCost;
 	int deltaRight, deltaLeft, delta;
 	Point lowPt;
 
@@ -587,11 +587,10 @@ mzExtendDown(path)
 
 		if(delta>0)
 		{
-		    hintCost = DoubleMultII( 
-			MIN(TOP(tp),pOrg.p_y) - lowPt.p_y,
-			path->rp_rLayer->rl_hintCost);
-		    hintCost = DoubleMultI(hintCost, delta);
-		    DOUBLE_ADD(segCost,segCost,hintCost);
+		    hintCost = (dlong) ((MIN(TOP(tp),pOrg.p_y) - lowPt.p_y) *
+					path->rp_rLayer->rl_hintCost);
+		    hintCost = (dlong)(hintCost * delta);
+		    segCost += hintCost;
 		}
 	    }
 	}
