@@ -17,18 +17,19 @@
  *     *********************************************************************
  */
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/mzrouter/mzXtndRght.c,v 1.2 2001/01/12 22:13:03 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/mzrouter/mzXtndRght.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
-#include "../tiles/tile.h"
+#include "tiles/tile.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "database/database.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "textio/textio.h"
 #include "utils/list.h"
 #include "debug/debug.h"
