@@ -17,11 +17,12 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMcmdAK.c,v 1.2 2001/01/12 22:13:07 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/netmenu/NMcmdAK.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -30,7 +31,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMcmdAK.c,v 1.2 20
 #include "textio/txcommands.h"
 #include "netmenu/nmInt.h"
 #include "netmenu/netmenu.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "textio/textio.h"
 #include "utils/malloc.h"
 
@@ -448,11 +449,13 @@ NMCmdExtract(w, cmd)
 	TxError("Usage: extract\n");
 	return;
     }
+/*
     if (!NMHasList())
     {
 	TxError("Select a netlist first.\n");
 	return;
     }
+*/
     NMExtract();
 }
 
@@ -549,12 +552,12 @@ NMCmdFlush(w, cmd)
 /*
  * ----------------------------------------------------------------------------
  *
- * NMCmdJoin --
+ * NMCmdJoinNets --
  *
  *	Join two nets together into a single net.
  *
  * Usage:
- *	join term1 term2
+ *	joinnets term1 term2
  *
  * Results:
  *	None.
@@ -562,18 +565,23 @@ NMCmdFlush(w, cmd)
  * Side effects:
  *	The current netlist is modified.
  *
+ * Notes
+ *	This command was previously called "join" but conflicts with
+ *	the Tcl command of the same name, and for which the syntax is
+ *	not distinct.
+ *
  * ----------------------------------------------------------------------------
  */
 
 	/* ARGSUSED */
 void
-NMCmdJoin(w, cmd)
+NMCmdJoinNets(w, cmd)
     MagWindow *w;			/* Netlist window. */
     TxCommand *cmd;		/* Contains the command's argc and argv. */
 {
     if (cmd->tx_argc != 3)
     {
-	TxError("Usage: join term1 term2\n");
+	TxError("Usage: joinnets term1 term2\n");
 	return;
     }
     if (!NMHasList())
