@@ -19,11 +19,12 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMshowcell.c,v 1.2 2001/01/12 22:13:07 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/netmenu/NMshowcell.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -31,9 +32,9 @@ static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMshowcell.c,v 1.2
 #include "windows/windows.h"
 #include "graphics/graphics.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "textio/textio.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "netmenu/nmInt.h"
 
 /* The following owns describe the cell currently being highlighted,
@@ -99,7 +100,7 @@ NMRedrawCell(window, plane)
      * so that the material type is easy to see through the highlighting.
      */
     
-    if (window->w_scale > 4096)
+    if (window->w_scale > SUBPIXEL)
 	GrSetStuff(STYLE_PALEHIGHLIGHTS);
     else 
 	GrSetStuff(STYLE_SOLIDHIGHLIGHTS);
@@ -240,7 +241,7 @@ nmGetShowCell()
     }
     nmscShowUse = DBCellNewUse(nmscShowDef, (char *) NULL);
     DBSetTrans(nmscShowUse, &GeoIdentityTransform);
-    nmscShowUse->cu_expandMask = -1;
+    nmscShowUse->cu_expandMask = CU_DESCEND_SPECIAL;
 }
 
 /*
@@ -367,6 +368,7 @@ NMShowRoutedNet(netName)
  *
  * ----------------------------------------------------------------------------
  */
+int
 nmShowRoutedNetFunc(name, clientData)
     char *name;
     ClientData clientData;
@@ -395,6 +397,7 @@ nmShowRoutedNetFunc(name, clientData)
  */
 
     /*ARGSUSED*/
+int
 nmSRNFunc(rect, name, label, cdarg)
     Rect *rect;
     char *name;		/* Unused */
