@@ -18,11 +18,12 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMshowpt.c,v 1.2 2001/01/12 22:13:07 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/netmenu/NMshowpt.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -30,8 +31,8 @@ static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMshowpt.c,v 1.2 2
 #include "windows/windows.h"
 #include "graphics/graphics.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
-#include "main/main.h"
+#include "utils/styles.h"
+#include "utils/main.h"
 #include "utils/malloc.h"
 
 /* The net highlight information consists of an array of points.
