@@ -20,24 +20,24 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/netmenu/NMwiring.c,v 1.2 2001/01/12 22:13:07 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/netmenu/NMwiring.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "netmenu/netmenu.h"
 #include "netmenu/nmInt.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "drc/drc.h"
 #include "utils/malloc.h"
 #include "router/router.h"
@@ -1189,6 +1189,7 @@ nmwCullNetFunc(name, first)
  *
  * ----------------------------------------------------------------------------
  */
+void
 NMMeasureNet()
 {
     int nmMeasureFunc();
