@@ -16,26 +16,31 @@
  *     * of the United States of America may require an export license.    * 
  *     *********************************************************************
  *
- * rcsid $Header: /ufs/repository/magic/plot/plot.h,v 1.4 2001/01/12 22:13:09 jsolomon Exp $
+ * rcsid $Header: /usr/cvsroot/magic/plot/plot.h,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $
  */
 
-#define _PLOT
+#ifndef _PLOT_H
+#define _PLOT_H
 
-#ifndef	_MAGIC
-int err0 = Need_to_include_misc/magic_header;
-#endif	/* _MAGIC */
+#include "utils/magic.h"
 
 /* Technology-file reading procedures: */
 
 extern int PlotTechInit();
 extern bool PlotTechLine();
-extern bool PlotTechFinal();
+extern void PlotTechFinal();
 
 /* Top-level plot procedures: */
 
-extern void PlotPS();
+#ifdef GREMLIN
 extern void PlotGremlin();
+#endif
+#ifdef VERSATEC
 extern void PlotVersatec();
+#endif
+extern void PlotPS();
+extern void PlotPNM();
 extern void PlotSetParam();
 extern void PlotPrintParams();
-extern void PlotPNM();
+
+#endif /* _PLOT_H */
