@@ -19,19 +19,19 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/plot/plotMain.c,v 1.7 2001/07/24 18:03:43 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/plot/plotMain.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "utils/malloc.h"
 #include "plot/plotInt.h"
 #include "textio/textio.h"
@@ -47,12 +47,17 @@ static char rcsid[]="$Header: /ufs/repository/magic/plot/plotMain.c,v 1.7 2001/0
  * the top-level plotting routine.
  */
 
+/* Note (10/8/04):  All of the plot styles except PostScript and PNM	*/
+/* have been removed in the default compilation.  However, they should	*/
+/* remain in the following lists so that magic doesn't complain when	*/
+/* encountering these styles in the technology file.			*/
+
 static char *plotStyles[] =		/* Names of tech subsections. */
 {
     "postscript",
+    "pnm",
     "gremlin",
     "versatec",
-    "pnm",
     "colorversatec",
     "pixels",
     NULL
@@ -64,9 +69,9 @@ static void (*plotInitProcs[])() =	/* Initialization procedures for
 					 */
 {
     PlotPSTechInit,
+    PlotPNMTechInit,
     PlotGremlinTechInit,
     PlotVersTechInit,
-    PlotPNMTechInit,
     PlotColorVersTechInit,
     PlotPixTechInit,
     NULL
@@ -77,9 +82,9 @@ static bool (*plotLineProcs[])() =	/* Proc to call for each line in
 					 */
 {
     PlotPSTechLine,
+    PlotPNMTechLine,
     PlotGremlinTechLine,
     PlotVersTechLine,
-    PlotPNMTechLine,
     PlotColorVersTechLine,
     PlotPixTechLine,
     NULL
@@ -89,12 +94,12 @@ static void (*plotFinalProcs[])() =	/* Proc to call at end of reading
 					 * tech files.
 					 */
 {
-    NULL,
-    NULL,
     NULL,
     PlotPNMTechFinal,
     NULL,
     NULL,
+    NULL,
+    NULL,
     NULL
 };
 
@@ -266,6 +271,8 @@ PlotPrintParams()
 {
     TxPrintf("General plotting parameters are:\n");
     TxPrintf("    showCellNames: %s\n", PlotShowCellNames ? "true" : "false");
+
+    TxPrintf("");
     TxPrintf("Postscript plotting parameters are:\n");
     TxPrintf("    PS_cellIdFont:  \"%s\"\n", PlotPSIdFont);
     TxPrintf("    PS_cellNameFont:\"%s\"\n", PlotPSNameFont);
@@ -280,6 +287,15 @@ PlotPrintParams()
 		(float)PlotPSHeight / 72);
     TxPrintf("    PS_margin:      %d (%.3f in)\n", PlotPSMargin,
 		(float)PlotPSMargin / 72);
+
+    TxPrintf("");
+    TxPrintf("PNM plotting parameters are:\n");
+    TxPrintf("    pnmmaxmem: %d KB\n", PlotPNMmaxmem);
+    TxPrintf("    pnmdownsample: %d\n", PlotPNMdownsample);
+    TxPrintf("    pnmbackground: %d\n", PlotPNMBG);
+
+#ifdef VERSATEC
+    TxPrintf("");
     TxPrintf("Versatec plotting parameters are:\n");
     TxPrintf("    cellIdFont:    \"%s\"\n", PlotVersIdFont);
     TxPrintf("    cellNameFont:  \"%s\"\n", PlotVersNameFont);
@@ -291,13 +307,13 @@ PlotPrintParams()
     TxPrintf("    swathHeight:   %d\n", PlotVersSwathHeight);
     TxPrintf("    width:         %d\n", PlotVersWidth);
     TxPrintf("    color:         %s\n", PlotVersColor ? "true" : "false");
+#endif
+#ifdef LLNL
+    TxPrintf("");
     TxPrintf("Pixel plotting parameters are:\n");
     TxPrintf("    pixheight:   %d\n", PlotPixHeight);
     TxPrintf("    pixwidth:         %d\n", PlotPixWidth);
-    TxPrintf("PNM plotting parameters are:\n");
-    TxPrintf("    pnmmaxmem: %d KB\n", PlotPNMmaxmem);
-    TxPrintf("    pnmbg: (%3d %3d %3d)\n", PlotPNMBGr, PlotPNMBGg,
-	     PlotPNMBGb);
+#endif /* LLNL */
 }
 
 /*
@@ -318,33 +334,38 @@ PlotPrintParams()
  * ----------------------------------------------------------------------------
  */
 
-#define	SHOWCELLNAMES	 0
-#define PSCELLIDFONT	 1
-#define PSNAMEFONT	 2
-#define PSLABELFONT	 3
-#define PSIDSIZE	 4
-#define PSNAMESIZE	 5
-#define PSLABELSIZE	 6
-#define PSBOUNDARY	 7
-#define PSWIDTH		 8
-#define PSHEIGHT	 9
-#define PSMARGIN	10 
-#define CELLIDFONT	11
-#define CELLNAMEFONT	12
-#define LABELFONT	13
-#define DIRECTORY	14
-#define DOTSPERINCH	15
-#define PRINTER		16
-#define SPOOLCOMMAND	17
-#define SWATHHEIGHT	18
-#define WIDTH		19	
-#define COLOR		20
-#define PIXWIDTH	21
-#define PIXHEIGHT	22
-#define PNMMAXMEM	23
-#define PNMBGRED	24
-#define PNMBGGREEN	25
-#define PNMBGBLUE	26
+typedef enum {
+	SHOWCELLNAMES=0,
+	PSCELLIDFONT,
+	PSNAMEFONT,
+	PSLABELFONT,
+	PSIDSIZE,
+	PSNAMESIZE,
+	PSLABELSIZE,
+	PSBOUNDARY,
+	PSWIDTH,
+	PSHEIGHT,
+	PSMARGIN,
+#ifdef VERSATEC
+	CELLIDFONT,
+	CELLNAMEFONT,
+	LABELFONT,
+	DIRECTORY,
+	DOTSPERINCH,
+	PRINTER,
+	SPOOLCOMMAND,
+	SWATHHEIGHT,
+	WIDTH,
+	COLOR,
+#endif
+#ifdef LLNL
+	PIXWIDTH,
+	PIXHEIGHT,
+#endif
+	PNMMAXMEM,
+	PNMDOWNSAMPLE,
+	PNMBACKGROUND
+} PlotParameterOptions;
 
 void
 PlotSetParam(name, value)
@@ -366,6 +387,7 @@ PlotSetParam(name, value)
 	"ps_width",
 	"ps_height",
 	"ps_margin",
+#ifdef VERSATEC
 	"cellidfont",
 	"cellnamefont",
 	"labelfont",
@@ -376,12 +398,14 @@ PlotSetParam(name, value)
 	"swathheight",
 	"width",
 	"color",
+#endif
+#ifdef LLNL
 	"pixwidth",
 	"pixheight",
+#endif
 	"pnmmaxmem",
-	"pnmbgr",
-	"pnmbgg",
-	"pnmbgb",
+	"pnmdownsample",
+	"pnmbackground",
 	NULL
     };
 
@@ -471,6 +495,8 @@ PlotSetParam(name, value)
 	    }
 	    else PlotPSMargin = i;
 	    break;
+
+#ifdef VERSATEC
 	case CELLIDFONT:
 	    StrDup(&PlotVersIdFont, value);
 	    break;
@@ -524,6 +550,11 @@ PlotSetParam(name, value)
 	    }
 	    else PlotVersWidth = i;
 	    break;
+
+#endif /* VERSATEC */
+
+#ifdef LLNL
+
 	case PIXWIDTH:
 	    if (!StrIsInt(value) || (i <= 0))
 	    {
@@ -540,6 +571,9 @@ PlotSetParam(name, value)
 	    }
 	    else PlotPixHeight = i;
 	    break;
+
+#endif /* LLNL */
+
         case PNMMAXMEM:
   	    if (!StrIsInt(value) || (i <= 0))
 	    {
@@ -548,32 +582,23 @@ PlotSetParam(name, value)
 	    }
 	    else PlotPNMmaxmem = i;
 	    break;
-        case PNMBGRED:
-  	    if (!StrIsInt(value) || (i < 0) || (i > 255))
+
+        case PNMDOWNSAMPLE:
+  	    if (!StrIsInt(value) || (i < 0))
 	    {
-	        TxError("pnmbgr must be an integer in [0,255]\n");
+	        TxError("pnmdownsample must be an integer zero or larger.\n");
 		return;
 	    }
-	    else PlotPNMBGr = i;
-	    PlotPNMSetBG ();
+	    else PlotPNMdownsample = i;
 	    break;
-        case PNMBGGREEN:
+
+        case PNMBACKGROUND:
   	    if (!StrIsInt(value) || (i < 0) || (i > 255))
 	    {
-	        TxError("pnmbgg must be an integer in [0,255]\n");
+	        TxError("pnmbackground must be an integer 0-255.\n");
 		return;
 	    }
-	    else PlotPNMBGg = i;
-	    PlotPNMSetBG ();
-	    break;
-        case PNMBGBLUE:
-  	    if (!StrIsInt(value) || (i < 0) || (i > 255))
-	    {
-	        TxError("pnmbgb must be an integer in [0,255]\n");
-		return;
-	    }
-	    else PlotPNMBGb = i;
-	    PlotPNMSetBG ();
+	    else PlotPNMBG = (unsigned char)i;
 	    break;
     }
 }
