@@ -18,19 +18,19 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/plot/plotPS.c,v 1.11 2001/08/13 19:31:25 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/plot/plotPS.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "utils/malloc.h"
 #include "utils/utils.h"
 #include "windows/windows.h"
@@ -527,7 +527,7 @@ plotPSPaint(tile, cxp)
     if (IsSplit(tile))
     {
 	int np, i, j;
-	int o1, o2, o3, dir, side;
+	TileType dinfo;
 	Point polyp[5];
 
 	plotPSFlushRect();
@@ -536,16 +536,12 @@ plotPSPaint(tile, cxp)
 
 	/* Side and direction are altered by geometric transformations */
 
-        o1 = ((scx->scx_trans.t_e > 0) || (scx->scx_trans.t_d > 0)) ? 1 : 0;
-        o2 = ((scx->scx_trans.t_a > 0) || (scx->scx_trans.t_b > 0)) ? 1 : 0;
-        o3 = (scx->scx_trans.t_a != 0) ? 1 : 0;
-        dir = SplitDirection(tile) ^ o1 ^ o2;
-        side = SplitSide(tile) ^ o2 ^ (SplitDirection(tile) | o3);
+	dinfo = DBTransformDiagonal(TiGetTypeExact(tile), &scx->scx_trans);
 
 	/* Use GrClipTriangle() routine to get the n-sided polygon that */
 	/* results from clipping a triangle to the clip region.		*/
 
-	GrClipTriangle(&rootArea, &bbox, TRUE, dir, side, polyp, &np);
+	GrClipTriangle(&rootArea, &bbox, TRUE, dinfo, polyp, &np);
 	for (i = 0; i < np; i++)
 	{
 	   polyp[i].p_x -= bbox.r_xbot;
