@@ -413,8 +413,8 @@ void
 prContactLHS(edge)
     Edge *edge;	/* Edge being moved (LHS is contact) */
 {
-    int pNum, connPlanes = DBConnPlanes[edge->e_ltype];
-    int pMax;
+    int pNum, pMax;
+    PlaneMask connPlanes = DBConnPlanes[edge->e_ltype];
 
     /* Add the edges of the contact on its other planes */
     connPlanes &= ~(edge->e_pNum);
@@ -429,8 +429,8 @@ int
 prContactRHS(edge)
     Edge *edge;	/* Edge being moved (RHS is contact) */
 {
-    int pNum, connPlanes = DBConnPlanes[edge->e_rtype];
-    int pMax;
+    int pNum, pMax;
+    PlaneMask connPlanes = DBConnPlanes[edge->e_rtype];
 
     /* Add the edges of the contact on its other planes */
     connPlanes &= ~(edge->e_pNum);
