@@ -18,16 +18,17 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowRules3.c,v 1.2 2001/01/12 22:13:12 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/plow/PlowRules3.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "plow/plow.h"
 #include "plow/plowInt.h"
 #include "drc/drc.h"
