@@ -18,11 +18,12 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowSearch.c,v 1.4 2001/06/15 17:14:05 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/plow/PlowSearch.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
@@ -48,8 +49,13 @@ Stack *plowOutlineStack = NULL;
 
 #define	FLUSHSTACK(s)	while (STACKLOOK(s)) (void) STACKPOP(s)
 
-/* Outline tracing: is tile (indicated by type) inside the outline */
-#define	IsInside(ttype, out) TTMaskHasType(&(out)->o_insideTypes, ttype)
+/* Outline tracing: is tile inside the outline */
+#define	IsInside(tp, out) TTMaskHasType(&(out)->o_insideTypes, TiGetTypeExact(tp))
+
+/* Forward declarations */
+
+extern void plowSrOutlineInit();
+extern void plowSrOutlineNext();
 
 /*
  * ----------------------------------------------------------------------------
@@ -57,7 +63,7 @@ Stack *plowOutlineStack = NULL;
  * EXTENDOUTLINE --
  *
  * EXTENDOUTLINE(outline)
- *	register Outline *outline;
+ *	Outline *outline;
  * {
  * }
  *
@@ -83,8 +89,8 @@ Stack *plowOutlineStack = NULL;
  */
 
 #define	EXTENDOUTLINE(o) { \
-register Tile *in = (o)->o_nextIn; \
-register Tile *out = (o)->o_nextOut; \
+Tile *in = (o)->o_nextIn; \
+Tile *out = (o)->o_nextOut; \
 switch ((o)->o_nextDir) \
 { \
     case GEO_NORTH: (o)->o_nextRect.r_ytop=MIN(TOP(out),TOP(in)); break; \
@@ -100,7 +106,7 @@ switch ((o)->o_nextDir) \
  * STACKOUTLINE --
  *
  * STACKOUTLINE(outline)
- *	register Outline *outline;
+ *	Outline *outline;
  *
  * Called whenever we advance to a new inside/outside tile to
  * load the tile stack with the tiles on the opposite side of
@@ -125,7 +131,7 @@ switch ((o)->o_nextDir) \
  */
 
 #define	STACKOUTLINE(o) { \
-    register Tile *tp; \
+    Tile *tp; \
 \
     FLUSHSTACK(plowOutlineStack); \
     switch ((o)->o_nextDir) \
@@ -196,6 +202,7 @@ switch ((o)->o_nextDir) \
  * ----------------------------------------------------------------------------
  */
 
+int
 plowSrShadow(pNum, area, okTypes, proc, cdata)
     int pNum;			/* Plane from plowYankDef to search */
     Rect *area;			/* Area to search.  Edges coincident with the
@@ -208,7 +215,7 @@ plowSrShadow(pNum, area, okTypes, proc, cdata)
 {
     Plane *plane = plowYankDef->cd_planes[pNum];
     struct shadow s;
-    register Tile *tp;
+    Tile *tp;
     int bottom, ret;
     Point p;
 
@@ -270,12 +277,13 @@ plowSrShadow(pNum, area, okTypes, proc, cdata)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowShadowRHS(tp, s, bottomLeft)
-    register Tile *tp;		/* Tile whose RHS is to be followed */
-    register struct shadow *s;	/* Shadow search argument */
+    Tile *tp;		/* Tile whose RHS is to be followed */
+    struct shadow *s;	/* Shadow search argument */
     int bottomLeft;		/* Bottom of 'tp', clipped to area */
 {
-    register Tile *tpR;
+    Tile *tpR;
     int bottom, left;
 
     /* Walk along the RHS of 'tp' from top to bottom */
@@ -290,11 +298,11 @@ plowShadowRHS(tp, s, bottomLeft)
 	if (bottom < s->s_edge.e_ytop)
 	{
 	    /* If tpR is not in okTypes, pass the edge to the client function */
-	    if (!TTMaskHasType(&s->s_okTypes, TiGetLeftType(tpR)))
+	    if (!TTMaskHasType(&s->s_okTypes, TiGetTypeExact(tpR)))
 	    {
 		/* Left, right hand types */
-		s->s_edge.e_ltype = TiGetRightType(tp);
-		s->s_edge.e_rtype = TiGetLeftType(tpR);
+		s->s_edge.e_ltype = TiGetTypeExact(tp);
+		s->s_edge.e_rtype = TiGetTypeExact(tpR);
 
 		/* Coordinates */
 		s->s_edge.e_x = left;
@@ -347,6 +355,7 @@ plowShadowRHS(tp, s, bottomLeft)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowSrShadowInitial(pNum, area, okTypes, proc, cdata)
     int pNum;			/* Plane from plowYankDef to search */
     Rect *area;			/* Area to search.  Edges coincident with the
@@ -359,7 +368,7 @@ plowSrShadowInitial(pNum, area, okTypes, proc, cdata)
 {
     Plane *plane = plowYankDef->cd_planes[pNum];
     struct shadow s;
-    register Tile *tp;
+    Tile *tp;
     int bottom, ret;
     Point p;
 
@@ -422,12 +431,13 @@ plowSrShadowInitial(pNum, area, okTypes, proc, cdata)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowShadowInitialRHS(tp, s, bottomLeft)
-    register Tile *tp;		/* Tile whose RHS is to be followed */
-    register struct shadow *s;	/* Shadow search argument */
+    Tile *tp;		/* Tile whose RHS is to be followed */
+    struct shadow *s;	/* Shadow search argument */
     int bottomLeft;		/* Bottom of 'tp', clipped to area */
 {
-    register Tile *tpR;
+    Tile *tpR;
     int bottom, left;
 
     /* Walk along the RHS of 'tp' from top to bottom */
@@ -443,12 +453,12 @@ plowShadowInitialRHS(tp, s, bottomLeft)
 	{
 	    /* If tpR is not in okTypes, pass the edge to the client function */
 	    if (TiGetTypeExact(tp) != TiGetTypeExact(tpR)
-		&& (!TTMaskHasType(&s->s_okTypes, TiGetLeftType(tpR))
-			|| !TTMaskHasType(&s->s_okTypes, TiGetRightType(tp))))
+		&& (!TTMaskHasType(&s->s_okTypes, TiGetTypeExact(tpR))
+			|| !TTMaskHasType(&s->s_okTypes, TiGetTypeExact(tp))))
 	    {
 		/* Left, right hand types */
-		s->s_edge.e_ltype = TiGetRightType(tp);
-		s->s_edge.e_rtype = TiGetLeftType(tpR);
+		s->s_edge.e_ltype = TiGetTypeExact(tp);
+		s->s_edge.e_rtype = TiGetTypeExact(tpR);
 
 		/* Coordinates */
 		s->s_edge.e_x = left;
@@ -500,6 +510,7 @@ plowShadowInitialRHS(tp, s, bottomLeft)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowSrShadowBack(pNum, area, okTypes, proc, cdata)
     int pNum;			/* Plane from plowYankDef to search */
     Rect *area;			/* Area to search.  Edges coincident with the
@@ -512,7 +523,7 @@ plowSrShadowBack(pNum, area, okTypes, proc, cdata)
 {
     Plane *plane = plowYankDef->cd_planes[pNum];
     struct shadow s;
-    register Tile *tp;
+    Tile *tp;
     int top, ret;
     Point p;
 
@@ -576,12 +587,13 @@ plowSrShadowBack(pNum, area, okTypes, proc, cdata)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowShadowLHS(tp, s, topRight)
-    register Tile *tp;		/* Tile whose LHS is to be followed */
-    register struct shadow *s;	/* Shadow search argument */
+    Tile *tp;		/* Tile whose LHS is to be followed */
+    struct shadow *s;	/* Shadow search argument */
     int topRight;		/* Top of 'tp', clipped to area */
 {
-    register Tile *tpL;
+    Tile *tpL;
     int top, right;
 
     /* Walk along the LHS of 'tp' from bottom to top */
@@ -596,11 +608,11 @@ plowShadowLHS(tp, s, topRight)
 	if (top > s->s_edge.e_ybot)
 	{
 	    /* If tpL is not in okTypes, pass the edge to the client function */
-	    if (!TTMaskHasType(&s->s_okTypes, TiGetRightType(tpL)))
+	    if (!TTMaskHasType(&s->s_okTypes, TiGetTypeExact(tpL)))
 	    {
 		/* Left, right hand types */
-		s->s_edge.e_ltype = TiGetRightType(tpL);
-		s->s_edge.e_rtype = TiGetLeftType(tp);
+		s->s_edge.e_ltype = TiGetTypeExact(tpL);
+		s->s_edge.e_rtype = TiGetTypeExact(tp);
 
 		/* Coordinates */
 		s->s_edge.e_x = right;
@@ -658,16 +670,17 @@ plowShadowLHS(tp, s, topRight)
  * ----------------------------------------------------------------------------
  */
 
+int
 plowAtomize(pNum, rect, proc, cdata)
     int pNum;			/* Plane from plowYankDef to search */
-    register Rect *rect;	/* LHS is the geometrical edge we search; each
+    Rect *rect;	/* LHS is the geometrical edge we search; each
 				 * Edge found will have an e_newx coordinate
 				 * equal to the RHS of this rect.
 				 */
     int (*proc)();		/* Procedure to apply to each Edge */
     ClientData cdata;		/* Additional argument to (*proc)() */
 {
-    register Tile *tpL, *tpR;
+    Tile *tpL, *tpR;
     Plane *plane = plowYankDef->cd_planes[pNum];
     Point startPoint;
     Edge edge;
@@ -692,7 +705,7 @@ plowAtomize(pNum, rect, proc, cdata)
 	/* Only process edges that haven't moved far enough */
 	if (TRAILING(tpR) < rect->r_xtop)
 	{
-	    edge.e_rtype = TiGetLeftType(tpR);
+	    edge.e_rtype = TiGetTypeExact(tpR);
 	    edge.e_ybot = MAX(BOTTOM(tpR), rect->r_ybot);
 
 	    /* Walk up the LHS of the edge */
@@ -702,7 +715,7 @@ plowAtomize(pNum, rect, proc, cdata)
 		if (TOP(tpL) > edge.e_ybot)
 		{
 		    edge.e_ytop = MIN(ytop, TOP(tpL));
-		    edge.e_ltype = TiGetRightType(tpL);
+		    edge.e_ltype = TiGetTypeExact(tpL);
 		    if ((*proc)(&edge, cdata))
 			return (1);
 		    edge.e_ybot = edge.e_ytop;
@@ -765,6 +778,7 @@ plowAtomize(pNum, rect, proc, cdata)
  * ----------------------------------------------------------------------------
  */
 
+void
 plowSrOutline(pNum, startPoint, insideTypes, initialDir, dirMask, proc, cdata)
     int pNum;				/* Plane # in plowYankDef to search */
     Point *startPoint;			/* Point on boundary; material of types
@@ -870,11 +884,12 @@ plowSrOutline(pNum, startPoint, insideTypes, initialDir, dirMask, proc, cdata)
  * ----------------------------------------------------------------------------
  */
 
+void
 plowSrOutlineInit(outline)
-    register Outline *outline;
+    Outline *outline;
 {
     Plane *plane = plowYankDef->cd_planes[outline->o_pNum];
-    register Tile *in, *out;
+    Tile *in, *out;
     Point p;
 
     outline->o_nextDir = outline->o_currentDir;
@@ -900,7 +915,7 @@ plowSrOutlineInit(outline)
 	    in = out;
 	    GOTOPOINT(in, &p);
 
-	    if (!IsInside(TiGetRightType(in), outline))
+	    if (!IsInside(in, outline))
 	    {
 		/*
 		 * Tile 'in' is really outside the outline, so go left.
@@ -915,7 +930,7 @@ plowSrOutlineInit(outline)
 		outline->o_nextDir = GEO_WEST;
 		outline->o_nextOut = in;
 	    }
-	    else if (IsInside(TiGetBottomType(out), outline))
+	    else if (IsInside(out, outline))
 	    {
 		/*
 		 * Tile 'out' is really inside the outline, so go right.
@@ -962,7 +977,7 @@ plowSrOutlineInit(outline)
 	    in = out;
 	    GOTOPOINT(in, &p);
 
-	    if (!IsInside(TiGetLeftType(in), outline))
+	    if (!IsInside(in, outline))
 	    {
 		/*
 		 * Tile 'in' is really outside the outline, so go right.
@@ -977,7 +992,7 @@ plowSrOutlineInit(outline)
 		outline->o_nextDir = GEO_EAST;
 		outline->o_nextOut = in;
 	    }
-	    else if (IsInside(TiGetTopType(out), outline))
+	    else if (IsInside(out, outline))
 	    {
 		/*
 		 * Tile 'out' is really inside the outline, so go left.
@@ -1034,10 +1049,11 @@ plowSrOutlineInit(outline)
  * ----------------------------------------------------------------------------
  */
 
+void
 plowSrOutlineNext(outline)
-    register Outline *outline;
+    Outline *outline;
 {
-    register Tile *tpL, *tpR;
+    Tile *tpL, *tpR;
 
     /*
      * Initialize the "next" segment to be the degenerate
@@ -1080,7 +1096,7 @@ plowSrOutlineNext(outline)
 	     */
 	    case GEO_NORTH:
 		outline->o_nextOut = (Tile *) STACKPOP(plowOutlineStack);
-		if (IsInside(TiGetLeftType(outline->o_nextOut), outline))
+		if (IsInside(outline->o_nextOut, outline))
 		{
 		    outline->o_nextOut = LB(outline->o_nextOut);
 		    outline->o_nextDir = GEO_EAST;
@@ -1098,7 +1114,7 @@ plowSrOutlineNext(outline)
 	     */
 	    case GEO_SOUTH:
 		outline->o_nextOut = (Tile *) STACKPOP(plowOutlineStack);
-		if (IsInside(TiGetRightType(outline->o_nextOut), outline))
+		if (IsInside(outline->o_nextOut, outline))
 		{
 		    outline->o_nextOut = RT(outline->o_nextOut);
 		    outline->o_nextDir = GEO_WEST;
@@ -1116,7 +1132,7 @@ plowSrOutlineNext(outline)
 	     */
 	    case GEO_EAST:
 		outline->o_nextIn = (Tile *) STACKPOP(plowOutlineStack);
-		if (!IsInside(TiGetBottomType(outline->o_nextIn), outline))
+		if (!IsInside(outline->o_nextIn, outline))
 		{
 		    outline->o_nextIn = BL(outline->o_nextIn);
 		    outline->o_nextDir = GEO_NORTH;
@@ -1134,7 +1150,7 @@ plowSrOutlineNext(outline)
 	     */
 	    case GEO_WEST:
 		outline->o_nextIn = (Tile *) STACKPOP(plowOutlineStack);
-		if (!IsInside(TiGetTopType(outline->o_nextIn), outline))
+		if (!IsInside(outline->o_nextIn, outline))
 		{
 		    outline->o_nextIn = TR(outline->o_nextIn);
 		    outline->o_nextDir = GEO_SOUTH;
@@ -1175,7 +1191,7 @@ plowSrOutlineNext(outline)
 	 */
 	case GEO_NORTH:
 	    tpL = RT(outline->o_nextIn);
-	    if (!IsInside(TiGetBottomType(tpL), outline))
+	    if (!IsInside(tpL, outline))
 	    {
 		outline->o_nextOut = tpL;
 		outline->o_nextDir = GEO_WEST;
@@ -1187,7 +1203,7 @@ plowSrOutlineNext(outline)
 	    else for (tpR = TR(tpL);
 			BOTTOM(tpR) > outline->o_nextRect.r_ybot; tpR = LB(tpR))
 		/* Nothing */;
-	    if (IsInside(TiGetLeftType(tpR), outline))
+	    if (IsInside(tpR, outline))
 	    {
 		outline->o_nextOut = TR(outline->o_nextIn);
 		outline->o_nextDir = GEO_EAST;
@@ -1207,7 +1223,7 @@ plowSrOutlineNext(outline)
 	 */
 	case GEO_SOUTH:
 	    tpR = LB(outline->o_nextIn);
-	    if (!IsInside(TiGetTopType(tpR), outline))
+	    if (!IsInside(tpR, outline))
 	    {
 		outline->o_nextOut = tpR;
 		outline->o_nextDir = GEO_EAST;
@@ -1219,7 +1235,7 @@ plowSrOutlineNext(outline)
 	    else for (tpL = BL(tpR);
 			TOP(tpL) < outline->o_nextRect.r_ytop; tpL = RT(tpL))
 		/* Nothing */;
-	    if (IsInside(TiGetTopType(tpL), outline))
+	    if (IsInside(tpL, outline))
 	    {
 		outline->o_nextOut = BL(outline->o_nextIn);
 		outline->o_nextDir = GEO_WEST;
@@ -1244,12 +1260,12 @@ plowSrOutlineNext(outline)
 		    LEFT(tpL) > outline->o_nextRect.r_xbot; tpL = BL(tpL))
 		/* Nothing */;
 
-	    if (!IsInside(TiGetLeftType(tpL), outline))
+	    if (!IsInside(tpL, outline))
 	    {
 		outline->o_nextIn = RT(outline->o_nextOut);
 		outline->o_nextDir = GEO_NORTH;
 	    }
-	    else if (IsInside(TiGetLeftType(tpR), outline))
+	    else if (IsInside(tpR, outline))
 	    {
 		outline->o_nextIn = tpR;
 		outline->o_nextDir = GEO_SOUTH;
@@ -1273,12 +1289,12 @@ plowSrOutlineNext(outline)
 	    else for (tpR = LB(tpL);
 		    RIGHT(tpR) < outline->o_nextRect.r_xbot; tpR = TR(tpR))
 		/* Nothing */;
-	    if (!IsInside(TiGetTopType(tpR), outline))
+	    if (!IsInside(tpR, outline))
 	    {
 		outline->o_nextIn = LB(outline->o_nextOut);
 		outline->o_nextDir = GEO_SOUTH;
 	    }
-	    else if (IsInside(TiGetBottomType(tpL), outline))
+	    else if (IsInside(tpL, outline))
 	    {
 		outline->o_nextIn = tpL;
 		outline->o_nextDir = GEO_NORTH;
