@@ -654,7 +654,7 @@ plowDebugEdge(edge, rtePtr, mesg)
     WindUpdate();
 
     plowDebugMore();
-    DBWFeedbackClear();
+    DBWFeedbackClear(NULL);
     WindUpdate();
 }
 
