@@ -15,9 +15,14 @@
  *     * of the United States of America may require an export license.    * 
  *     *********************************************************************
  *
- * rcsid $Header: /ufs/repository/magic/plow/plow.h,v 1.1.1.1 2000/03/29 18:35:10 rajit Exp $
+ * rcsid $Header: /usr/cvsroot/magic/plow/plow.h,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $
  */
 
+#ifndef _PLOW_H
+#define _PLOW_H
+
+#include "utils/magic.h"
+
 /* Technology file clients */
 extern int PlowDRCInit(), PlowDRCFinal();
 extern int PlowTechInit(), PlowTechFinal();
@@ -45,3 +50,5 @@ extern int PlowJogHorizon;
 
 /* TRUE if we should eliminate jogs after each plow operation */
 extern bool PlowDoStraighten;
+
+#endif /* _PLOW_H */
