@@ -4,13 +4,9 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/resi
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
 #include <math.h>
-#ifdef	SYSV
-#include <string.h>
-#else
-#include <strings.h>
-#endif
 
 #include "utils/magic.h"
 #include "utils/geometry.h"
