@@ -8,13 +8,9 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/resi
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
 #include <math.h>
-#ifdef	SYSV
-#include <string.h>
-#else
-#include <strings.h>
-#endif
 
 #include "utils/magic.h"
 #include "utils/geometry.h"
@@ -244,7 +240,7 @@ dbcConnectFuncDCS(tile, cx)
 
 	/* Differenct contact types may share residues (6/18/04) */     
 	for (ctype = TT_TECHDEPBASE; ctype < DBNumUserLayers; ctype++)
-	    if (TTMaskEqual(rMask, DBResidueMask(ctype)))
+	    if (TTMaskIntersect(rMask, DBResidueMask(ctype)))
 		TTMaskSetType(&notConnectMask, ctype);
 
 	/* The mask of contact types must include all stacked contacts */
