@@ -3,13 +3,9 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/resi
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
 #include <math.h>
-#ifdef	SYSV
-#include <string.h>
-#else
-#include <strings.h>
-#endif
 
 #include "utils/magic.h"
 #include "utils/geometry.h"
@@ -144,7 +140,7 @@ ResDissolveContacts(contacts)
 {
     TileType t, oldtype;
     Tile *tp;
-    TileTypeBitMask *residues;
+    TileTypeBitMask residues;
 
     for (; contacts != (ResContactPoint *) NULL; contacts = contacts->cp_nextcontact)
 
@@ -157,12 +153,12 @@ ResDissolveContacts(contacts)
 	}
 #endif
 	
-	residues = DBResidueMask(oldtype);
+	DBFullResidueMask(oldtype, &residues);
 
 	DBErase(ResUse->cu_def, &(contacts->cp_rect), oldtype);
 	for (t = TT_TECHDEPBASE; t < DBNumTypes; t++)
 	{
-	    if (TTMaskHasType(residues, t))
+	    if (TTMaskHasType(&residues, t))
 	    {
 		if (TTMaskHasType(&ExtCurStyle->exts_transMask, t))
 		    continue;
@@ -269,11 +265,11 @@ ResFindNewContactTiles(contacts)
 {
      int pNum;
      Tile *tile;
-     TileTypeBitMask *mask;
+     TileTypeBitMask mask;
      
      for (; contacts != (ResContactPoint *) NULL; contacts = contacts->cp_nextcontact)
      {
-          mask = &DBComponentTbl[contacts->cp_type];
+	  DBFullResidueMask(contacts->cp_type, &mask);
      	  for (pNum=PL_TECHDEPBASE; pNum<DBNumPlanes; pNum++)
 	  {
 		  tile = ResDef->cd_planes[pNum]->pl_hint;
@@ -285,10 +281,10 @@ ResFindNewContactTiles(contacts)
 		  }
 #endif
 #ifdef NONMANHATTAN
-		  if ((IsSplit(tile) && TTMaskHasType(mask, TiGetRightType(tile)))
-			|| TTMaskHasType(mask, TiGetType(tile)))
+		  if ((IsSplit(tile) && TTMaskHasType(&mask, TiGetRightType(tile)))
+			|| TTMaskHasType(&mask, TiGetType(tile)))
 #else
-		  if TTMaskHasType(mask, TiGetType(tile))
+		  if TTMaskHasType(&mask, TiGetType(tile))
 #endif
 		  {
 		       tileJunk	*j = (tileJunk *)tile->ti_client;
