@@ -4,13 +4,9 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/resi
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
 #include <math.h>
-#ifdef	SYSV
-#include <string.h>
-#else
-#include <strings.h>
-#endif
 
 #include "utils/magic.h"
 #include "utils/geometry.h"
@@ -583,11 +579,13 @@ ResPreProcessTransistors(TileList, TransistorList, Def)
 	if (DBIsContact(tt))
 	{
 	    /* Find which residue of the contact is a transistor type. */
-	    TileTypeBitMask *ttresidues = DBResidueMask(tt);
+	    TileTypeBitMask ttresidues;
+
+	    DBFullResidueMask(tt, &ttresidues);
 	       
-	    for (residue = TT_TECHDEPBASE; residue < DBNumTypes; residue++)
+	    for (residue = TT_TECHDEPBASE; residue < DBNumUserLayers; residue++)
 	    {
-		if (TTMaskHasType(ttresidues, residue))
+		if (TTMaskHasType(&ttresidues, residue))
 		{
 		    if (TTMaskHasType(&ExtCurStyle->exts_transMask, residue))
 		    {
