@@ -16,12 +16,13 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/router/rtrChannel.c,v 1.2 2001/01/12 22:13:18 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/router/rtrChannel.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
 #include "utils/hash.h"
@@ -31,13 +32,13 @@ static char rcsid[]="$Header: /ufs/repository/magic/router/rtrChannel.c,v 1.2 20
 #include "gcr/gcr.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "signals/signals.h"
-#include "main/main.h"
+#include "utils/signals.h"
+#include "utils/main.h"
 #include "router/router.h"
 #include "router/rtrDcmpose.h"
 #include "grouter/grouter.h"
 #include "textio/textio.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 
 /*
  * Maps a tile pointer to a channel structure.
