@@ -20,26 +20,26 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/router/ftrFdback.c,v 1.2 2001/01/12 22:13:17 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/router/rtrFdback.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/utils.h"
 #include "gcr/gcr.h"
 #include "router/router.h"
 #include "utils/heap.h"
 #include "grouter/grouter.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "textio/textio.h"
 #include "dbwind/dbwind.h"
 #include "utils/malloc.h"
