@@ -18,23 +18,24 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/router/rtrPaint.c,v 1.2 2001/01/12 22:13:18 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) ="$Header: /usr/cvsroot/magic/router/rtrPaint.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "utils/heap.h"
 #include "tiles/tile.h"
 #include "database/database.h"
 #include "gcr/gcr.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "router/router.h"
 #include "grouter/grouter.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "main/main.h"
+#include "utils/main.h"
 
 int RtrViaLimit		= 2;
 int rtrMetalLength	= 0;
