@@ -20,29 +20,30 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/router/rtrStem.c,v 1.2 2001/01/12 22:13:19 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/router/rtrStem.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/hash.h"
 #include "tiles/tile.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "misc/styles.h"
+#include "utils/styles.h"
 #include "router/router.h"
 #include "gcr/gcr.h"
 #include "utils/heap.h"
 #include "grouter/grouter.h"
-#include "netlist/netlist.h"
+#include "utils/netlist.h"
 #include "textio/textio.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/malloc.h"
 #include "debug/debug.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 
 /* Used when searching for stems */
 typedef struct
@@ -1114,7 +1115,7 @@ rtrStemTypes(startMask, finalMask, startType, finalType)
  *	or to actually paint the stem.
  *
  * Results:
- *	True on success, False on failure.
+ *	TRUE on success, FALSE on failure.
  *
  * Side effects:
  *	Returns contact, jog, and start points, passed via pointer.
