@@ -11,20 +11,18 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "magic/tclmagic.h"
-#include "misc/magic.h"
+#include "tcltk/tclmagic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
-#include "utils/doubleint.h"
 #include "utils/heap.h"
 #include "utils/list.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "commands/commands.h"
-#include "tech/tech.h"
+#include "utils/tech.h"
 #include "dbwind/dbwind.h"
-
 #include "router/router.h"
 #include "gcr/gcr.h"
 #include "grouter/grouter.h"
@@ -53,7 +51,8 @@ Tclroute_Init(interp)
 
     /* Sanity checks! */
     if (interp == NULL) return TCL_ERROR;
-    if (Tcl_PkgRequire(interp, "Tclmagic", "7.3", 0) == NULL) return TCL_ERROR;
+    if (Tcl_PkgRequire(interp, "Tclmagic", MAGIC_VERSION, 0) == NULL)
+	return TCL_ERROR;
     if (Tcl_InitStubs(interp, "8.1", 0) == NULL) return TCL_ERROR;
 
     TxPrintf("Auto-loading ROUTE module\n");
@@ -91,7 +90,7 @@ Tclroute_Init(interp)
     invsec &= TechSectionGetMask("router", NULL);
     if (!TechLoad(NULL, invsec)) return TCL_ERROR;
 
-    Tcl_PkgProvide(interp, "Route", "7.3");
+    Tcl_PkgProvide(interp, "Route", MAGIC_VERSION);
     return TCL_OK;
 }
 
