@@ -17,23 +17,27 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/select/selCreate.c,v 1.6 2001/07/30 17:16:22 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/select/selCreate.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+#include <string.h>
+
+#include "utils/magic.h"
+#include "utils/malloc.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "commands/commands.h"
 #include "select/selInt.h"
+#include "select/select.h"
 #include "drc/drc.h"
-#include "main/main.h"
-#include "signals/signals.h"
+#include "utils/main.h"
+#include "utils/signals.h"
 
 /* Two cells worth of information are kept around by the selection
  * module.  SelectDef and SelectUse are for the cells whose contents
@@ -111,7 +115,7 @@ SelectInit()
     }
     SelectUse = DBCellNewUse(SelectDef, (char *) NULL);
     DBSetTrans(SelectUse, &GeoIdentityTransform);
-    SelectUse->cu_expandMask = -1;	/* This is always expanded. */
+    SelectUse->cu_expandMask = CU_DESCEND_SPECIAL;	/* This is always expanded. */
 
     Select2Def = DBCellLookDef("__SELECT2__");
     if (Select2Def == (CellDef *) NULL)
@@ -123,7 +127,7 @@ SelectInit()
     }
     Select2Use = DBCellNewUse(Select2Def, (char *) NULL);
     DBSetTrans(Select2Use, &GeoIdentityTransform);
-    Select2Use->cu_expandMask = -1;	/* This is always expanded. */
+    Select2Use->cu_expandMask = CU_DESCEND_SPECIAL;	/* This is always expanded. */
     UndoEnable();
 
     SelUndoInit();
@@ -158,16 +162,19 @@ void
 SelectClear()
 {
     SearchContext scx;
+    Rect r;
     extern int selClearFunc();		/* Forward declaration. */
 
     if (SelectRootDef == NULL) return;
 
     scx.scx_area = SelectDef->cd_bbox;
 
-    if (!strcmp(SelectDef->cd_name, "__SELECT_NET__"))
+    /* Special handling when the cell is named __SELECT_NET__ 	*/
+
+    if (!strncmp(SelectDef->cd_name + 9, "NET", 3))
     {
 	SelNetRememberForUndo((CellDef *)NULL, (Point *)NULL,
-		TT_SPACE, FALSE, FALSE);
+			TT_SPACE, FALSE, FALSE);
 	DBCellRenameDef(SelectDef, "__SELECT__");
 	DBCellClearDef(SelectDef);
     }
@@ -207,12 +214,17 @@ SelectClear()
 	    if (selNDelete < MAXUSES) break;
 	}
 	selectLastUse = NULL;
+
 	SelRememberForUndo(FALSE, SelectRootDef, &scx.scx_area);
     }
 
+    /* Reset the transform, if we have been moving the selection around */
+    GeoTransRect(&SelectUse->cu_transform, &scx.scx_area, &r);
+    SelectUse->cu_transform = GeoIdentityTransform;
+
     /* Erase the selection from the screen. */
+    DBWHLRedraw(SelectRootDef, &r, TRUE);
 
-    DBWHLRedraw(SelectRootDef, &scx.scx_area, TRUE);
     DBReComputeBbox(SelectDef);
     DBWAreaChanged(SelectDef, &scx.scx_area, DBW_ALLWINDOWS,
 	(TileTypeBitMask *) NULL);
@@ -231,6 +243,7 @@ selClearFunc(scx)
     if (selNDelete == MAXUSES) return 1;
     else return 2;
 }
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -736,7 +749,7 @@ SelectRegion(scx, type, xMask, pArea, less)
 	scx2.scx_trans = GeoIdentityTransform;
 	DBCellCopyAllPaint(&scx2, &DBAllButSpaceAndDRCBits,
 			0, SelectUse);
-	DBCellCopyAllLabels(&scx2, &DBAllTypeBits, -1, SelectUse,
+	DBCellCopyAllLabels(&scx2, &DBAllTypeBits, CU_DESCEND_SPECIAL, SelectUse,
 			(Rect *) NULL);
       }
 
@@ -746,8 +759,9 @@ SelectRegion(scx, type, xMask, pArea, less)
 
     /* SelectDef should not need to recompute the bounding box;	*/
     /* only to copy it (transformed) from Select2Def.		*/
-    GeoTransRect(&scx->scx_trans, &Select2Def->cd_bbox, &SelectDef->cd_bbox);
     /* DBReComputeBbox(SelectDef); */
+    GeoTransRect(&scx->scx_trans, &Select2Def->cd_bbox, &SelectDef->cd_bbox);
+    DBComputeUseBbox(SelectUse);
 
     DBWHLRedraw(SelectRootDef, &Select2Def->cd_bbox, TRUE);
     DBWAreaChanged(SelectDef, &Select2Def->cd_bbox, DBW_ALLWINDOWS,
@@ -841,7 +855,7 @@ SelectNet(scx, type, xMask, pArea, less)
 	scx2.scx_trans = GeoIdentityTransform;
 	DBCellCopyAllPaint(&scx2, &DBAllButSpaceAndDRCBits,
 			   0, SelectUse);
-	DBCellCopyAllLabels(&scx2, &DBAllTypeBits, -1, SelectUse,
+	DBCellCopyAllLabels(&scx2, &DBAllTypeBits, CU_DESCEND_SPECIAL, SelectUse,
 			(Rect *) NULL);
     }
 
@@ -853,11 +867,14 @@ SelectNet(scx, type, xMask, pArea, less)
 
     /* Display the newly-selected material. */
     /* SelectDef should not need to recompute the bounding box;	*/
-    /* only to copy it (transformed) from Select2Def.		*/
+    /* only to copy it (transformed) from Select2Def, and then	*/
+    /* transfer this bounding box to the use.			*/
     /* ---Nishit, 7/6/04					*/
-    GeoTransRect(&scx->scx_trans, &Select2Def->cd_bbox, &SelectDef->cd_bbox);
     /* DBReComputeBbox(SelectDef); */
 
+    GeoTransRect(&scx->scx_trans, &Select2Def->cd_bbox, &SelectDef->cd_bbox);
+    DBComputeUseBbox(SelectUse);
+
     DBWHLRedraw(SelectRootDef, &Select2Def->cd_bbox, TRUE);
     DBWAreaChanged(SelectDef, &Select2Def->cd_bbox, DBW_ALLWINDOWS,
 	&DBAllButSpaceBits);
@@ -962,13 +979,61 @@ SelectCell(use, rootDef, trans, replace)
     DBWAreaChanged(SelectDef, &newUse->cu_bbox, DBW_ALLWINDOWS,
 	&DBAllButSpaceBits);
 }
-
+
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * SelectAndCopy1 --
+ *
+ *	This procedure takes the contents of SelectDef,  and makes a
+ *	copy of them in the edit cell.  Unlike SelectAndCopy2, the
+ *	original selection is unchanged, and SelectDef is not cleared.
+ *	This allows the implementation of "drag and drop" selections.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	The selection is augmented with what's in Select2Def.  The caller
+ *	should normally have cleared the selection before calling us.
+ *	The edit cell is modified to include everything that was in
+ *	Select2Def.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+SelectAndCopy1()
+{
+    SearchContext scx;
+    Rect editArea;
+
+    /* Just copy the information in Select2Def twice, once into the
+     * edit cell and once into the main selection cell.
+     */
+    
+    scx.scx_use = SelectUse;
+    scx.scx_area = SelectUse->cu_bbox;
+    GeoTransTrans(&SelectUse->cu_transform, &RootToEditTransform, &scx.scx_trans);
+    (void) DBCellCopyAllPaint(&scx, &DBAllButSpaceAndDRCBits, CU_DESCEND_SPECIAL,
+		EditCellUse);
+    (void) DBCellCopyAllLabels(&scx, &DBAllTypeBits, CU_DESCEND_SPECIAL, EditCellUse,
+		(Rect *) NULL);
+    (void) DBCellCopyAllCells(&scx, CU_DESCEND_SPECIAL, EditCellUse, (Rect *) NULL);
+    GeoTransRect(&scx.scx_trans, &scx.scx_area, &editArea);
+    DBAdjustLabels(EditCellUse->cu_def, &editArea);
+    DBWAreaChanged(EditCellUse->cu_def, &editArea, DBW_ALLWINDOWS,
+	(TileTypeBitMask *) NULL);
+    DRCCheckThis(EditCellUse->cu_def, TT_CHECKPAINT, &editArea);
+    DBReComputeBbox(EditCellUse->cu_def);
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
  * SelectAndCopy2 --
  *
- * 	This is procedure is intended for use only within the selection
+ * 	This procedure is intended for use only within the selection
  *	module.  It takes what's in Select2Def, makes a copy of it in the
  *	edit cell, and makes the copy the selection.  It's used, for
  *	example, by the transformation and copying routines.
@@ -1005,10 +1070,11 @@ SelectAndCopy2(newSourceDef)
     scx.scx_use = Select2Use;
     scx.scx_area = Select2Use->cu_bbox;
     scx.scx_trans = RootToEditTransform;
-    (void) DBCellCopyAllPaint(&scx, &DBAllButSpaceAndDRCBits, -1, EditCellUse);
-    (void) DBCellCopyAllLabels(&scx, &DBAllTypeBits, -1, EditCellUse,
-	(Rect *) NULL);
-    (void) DBCellCopyAllCells(&scx, -1, EditCellUse, (Rect *) NULL);
+    (void) DBCellCopyAllPaint(&scx, &DBAllButSpaceAndDRCBits, CU_DESCEND_SPECIAL,
+		EditCellUse);
+    (void) DBCellCopyAllLabels(&scx, &DBAllTypeBits, CU_DESCEND_SPECIAL, EditCellUse,
+		(Rect *) NULL);
+    (void) DBCellCopyAllCells(&scx, CU_DESCEND_SPECIAL, EditCellUse, (Rect *) NULL);
     GeoTransRect(&scx.scx_trans, &scx.scx_area, &editArea);
     DBAdjustLabels(EditCellUse->cu_def, &editArea);
     DBWAreaChanged(EditCellUse->cu_def, &editArea, DBW_ALLWINDOWS,
@@ -1036,7 +1102,8 @@ SelectAndCopy2(newSourceDef)
 		&TiPlaneRect, &DBAllButSpaceAndDRCBits, selACPaintFunc,
 		(ClientData) plane);
     }
-    (void) DBCellCopyAllLabels(&scx, &DBAllTypeBits, -1, SelectUse,
+
+    (void) DBCellCopyAllLabels(&scx, &DBAllTypeBits, CU_DESCEND_SPECIAL, SelectUse,
 	    &labelArea);
 
     /* We also have to be careful about copying subcells into the
@@ -1065,6 +1132,14 @@ SelectAndCopy2(newSourceDef)
 	(TileTypeBitMask *) NULL);
 }
 
+/* Structure to hold information about an edit area, which may be
+ * a triangular region.
+ */
+typedef struct {
+    Rect *editClip;
+    TileType dinfo;
+} acparg;
+
 /* Utility function: for each tile, copy information over its area from
  * the given edit cell plane to SelectDef.  Always return 0 to keep the
  * search alive.
@@ -1076,88 +1151,164 @@ selACPaintFunc(tile, plane)
     int plane;			/* Index of plane this tile came from. */
 {
     Rect area, editArea;
+    acparg selACarg;
     int selACPaintFunc2();	/* Forward reference. */
 
     TiToRect(tile, &area);
+    /* we want editClip in root coordinates. . . */
+    selACarg.editClip = &area;
     GeoTransRect(&RootToEditTransform, &area, &editArea);
+
+#ifndef NONMANHATTAN
+    selACarg.dinfo = 0;
+#else
+    selACarg.dinfo = TiGetTypeExact(tile);
+
+    if (IsSplit(tile))
+    {
+	DBSrPaintNMArea((Tile *) NULL, EditCellUse->cu_def->cd_planes[plane],
+		selACarg.dinfo, &editArea, &DBAllButSpaceAndDRCBits,
+		selACPaintFunc2, (ClientData) &selACarg);
+    }
+    else
+#endif
     (void) DBSrPaintArea((Tile *) NULL, EditCellUse->cu_def->cd_planes[plane],
 	    &editArea, &DBAllButSpaceAndDRCBits, selACPaintFunc2,
-	    (ClientData) &editArea);
+	    (ClientData) &selACarg);
     return 0;
 }
 
 /* Second-level paint function:  just paint the overlap between
  * tile and editClip into SelectDef.
+ *
+ * This function is like dbCopyAllPaint() but differs just enough
+ * that a separate function is required.  However, much of the code 
+ * could be shared between the two functions if it were properly
+ * broken out into subroutines.
  */
 
 int
-selACPaintFunc2(tile, editClip)
+selACPaintFunc2(tile, selACarg)
     Tile *tile;			/* Tile in edit cell. */
-    Rect *editClip;		/* Edit-cell area to clip to before painting
-				 * into selection.
+    acparg *selACarg;		/* Contains edit-cell area to clip to
+				 * before painting into selection.
 				 */
 {
+    Rect *editClip = selACarg->editClip;
     Rect area, selArea;
-    TileType type;
+    TileType type = TiGetTypeExact(tile);
+
+#ifdef NONMANHATTAN
+    TileType dinfo = selACarg->dinfo & (TT_DIAGONAL | TT_DIRECTION | TT_SIDE);
+#endif
 
     TiToRect(tile, &area);
-    GeoClip(&area, editClip);
     GeoTransRect(&EditToRootTransform, &area, &selArea);
 
 #ifdef NONMANHATTAN
-    if (IsSplit(tile))  
+
+    if (dinfo & TT_DIAGONAL)
     {
-	if (SplitSide(tile))
-	    type = SplitRightType(tile);
+	/* If the select area is triangular, then we need to	*/
+	/* clip in a more complicated manner.			*/
+
+	Point points[5];
+	Rect rrect, orect;
+	int np, i, j;
+	TileType rtype;
+
+	if (type & TT_DIAGONAL)
+	    rtype = (type & TT_SIDE) ? SplitRightType(tile) :
+			SplitLeftType(tile);
 	else
-	    type = SplitLeftType(tile);
+	    rtype = type;
+
+	type = (dinfo & TT_SIDE) ? (rtype << 14) : rtype;
+	type |= dinfo;
+
+	GrClipTriangle(editClip, &selArea, TRUE, dinfo, points, &np);
+
+	if (np == 0)
+	    return 0;
+	if (np >= 3)
+	{
+	    for (i = 0; i < np; i++)
+	    {
+		j = (i + 1) % np;
+		if (points[i].p_x != points[j].p_x && points[i].p_y !=
+				points[j].p_y)
+		{
+		    /* Break out the triangle */
+		    rrect.r_xbot = points[i].p_x;
+		    rrect.r_xtop = points[j].p_x;
+		    rrect.r_ybot = points[i].p_y;
+		    rrect.r_ytop = points[j].p_y;
+		    GeoCanonicalRect(&rrect, &selArea);
+		    break;
+		}
+	    }
+	    if (i == np)  /* Exactly one Manhattan rectangle */
+	    {
+		rrect.r_xbot = points[0].p_x;
+		rrect.r_xtop = points[2].p_x;
+		rrect.r_ybot = points[0].p_y;
+		rrect.r_ytop = points[2].p_y;
+		GeoCanonicalRect(&rrect, &selArea);
+		type = rtype;
+	    }
+	    else if (np >= 4) /* Process extra rectangles in the area */
+	    {
+		/* "orect" is the bounding box of the polygon returned	*/
+		/* by ClipTriangle.					*/
+
+		orect.r_xtop = orect.r_xbot = points[0].p_x;
+		orect.r_ytop = orect.r_ybot = points[0].p_y;
+		for (i = 0; i < np; i++)
+		    GeoIncludePoint(&points[i], &orect);
+
+		/* Rectangle to left or right */
+		rrect.r_ybot = orect.r_ybot;
+		rrect.r_ytop = orect.r_ytop;
+		if (selArea.r_xbot > orect.r_xbot)
+		{
+		    rrect.r_xbot = orect.r_xbot;
+		    rrect.r_xtop = selArea.r_xbot;
+		}
+		else if (selArea.r_xtop < orect.r_xtop)
+		{
+		    rrect.r_xtop = orect.r_xtop;
+		    rrect.r_xbot = selArea.r_xtop;
+		}
+		else
+		    goto topbottom;
+
+		DBPaint(SelectDef, &rrect, rtype);
+topbottom:
+		/* Rectangle to top or bottom */
+		rrect.r_xbot = selArea.r_xbot;
+		rrect.r_xtop = selArea.r_xtop;
+		if (selArea.r_ybot > orect.r_ybot)
+		{
+		    rrect.r_ybot = orect.r_ybot;
+		    rrect.r_ytop = selArea.r_ybot;
+		}
+		else if (selArea.r_ytop < orect.r_ytop)
+		{
+		    rrect.r_ytop = orect.r_ytop;
+		    rrect.r_ybot = selArea.r_ytop;
+		}
+		else
+		    goto splitdone;
+
+		DBPaint(SelectDef, &rrect, rtype);
+	    }
+	}
     }
-    else 
-#endif
-
-    type = TiGetType(tile);
-    if (type >= DBNumUserLayers)
-    {
-        TileType primary,first;
-        int typecount = 0;
-
-        for (primary = TT_SELECTBASE; primary < DBNumUserLayers; primary++)
-        {
-            if (TTMaskHasType(&DBLayerTypeMaskTbl[primary], type))
-            {
-                  typecount++;
-                 first = primary;
-            }
-        }
-        if (typecount == 1)
-        {
-             type = first;
-        }
-        else  /* have to see what's down there  */
-        {
-
-             for (primary = TT_SELECTBASE; primary < DBNumUserLayers; primary++)
-             {
-                  if (TTMaskHasType(&DBLayerTypeMaskTbl[primary], type))
-                  {
-                       int      planenum = DBPlane(primary);
-                       Tile     *tp = EditCellUse->cu_def->cd_planes[planenum]->pl_hint;
-                       GOTOPOINT(tp,&(tile->ti_ll));
-                       if (TiGetType(tp) == primary)
-                       {
-                            type = primary;
-                            break;
-                       }
-                  }
-             }
-        }
-    }
-
-#ifdef NONMANHATTAN
-    if (IsSplit(tile))
-	type = TiGetTypeExact(tile);
+    else
 #endif
+    GeoClip(&selArea, editClip);	/* editClip already in root coords */
 
+splitdone:
     DBPaint(SelectDef, &selArea, type);
     return 0;
 }
