@@ -26,6 +26,8 @@
 #include <string.h>
 #include <ctype.h>
 #include <signal.h>
+#include <unistd.h>
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
@@ -136,7 +138,7 @@ SimGetNodeCommand(cmd)
  *	This procedure is used to fork the rsim process.  It takes a list of
  *	arguements to pass to rsim when initiating the fork.  The
  * 	environment variable RSIM is first checked to find the pathname for
- *	rsim/irsim.  If this variable does not exist, then $CAD_HOME/bin/irsim
+ *	rsim/irsim.  If this variable does not exist, then BIN_DIR/irsim
  *	is then used.
  *
  * Results:
@@ -157,7 +159,7 @@ SimStartRsim(argv)
     int rsimToMagPipe[2];
     char *getenv();
     char rsimfile[256];
-    char *cad = "$CAD_HOME";
+    char *cad = BIN_DIR;
     char *src, *dst;
 
     /* don't start another rsim if one is already running */
@@ -182,7 +184,7 @@ SimStartRsim(argv)
     }
 
     /* Look for rsim; check for environ var first; if none, then
-     * try to open the one located in $CAD_HOME/bin.
+     * try to open the one located in BIN_DIR
      */
 
     src = getenv("RSIM");
@@ -192,10 +194,10 @@ SimStartRsim(argv)
 	src = cad;
 	dst = rsimfile;
 	if (PaExpand(&src, &dst, 100) == -1) {
-	    TxError ("Could not find $CAD_HOME\n");
+	    TxError ("Could not find " BIN_DIR "\n");
 	    return(FALSE);
 	}
-	strcat(rsimfile, "/bin/irsim");
+	strcat(rsimfile, "/irsim");
     }
 #ifndef NO_ACCESS_CALL
     if( access( rsimfile, 1 ) != 0 )
@@ -624,7 +626,7 @@ SimFillBuffer(buffHead, pLastChar, charCount)
     int 	charsRead = 0;
     char 	*temp;
     int		n, nfd;
-#if defined(SYSV) || defined(CYGWIN)
+#if defined(SYSV) || defined(CYGWIN) || defined(__FreeBSD__) || defined(macosx)
     fd_set readfds, writefds, exceptfds;
 #else
     int		nr, nex;
@@ -640,7 +642,7 @@ SimFillBuffer(buffHead, pLastChar, charCount)
 
     /* read reply from Rsim */
 
-#if defined(SYSV) || defined(CYGWIN)
+#if defined(SYSV) || defined(CYGWIN) || defined(__FreeBSD__) || defined(macosx)
     FD_ZERO(&readfds);
     FD_ZERO(&exceptfds);
 #endif  /* SYSV */
@@ -649,7 +651,7 @@ SimFillBuffer(buffHead, pLastChar, charCount)
 
 try_again:
 
-#if defined(SYSV) || defined(CYGWIN)
+#if defined(SYSV) || defined(CYGWIN) || defined(__FreeBSD__) || defined(macosx)
     FD_SET(pipeIn, &readfds);
     FD_ZERO(&writefds);
     FD_SET(pipeIn, &exceptfds);
