@@ -23,26 +23,22 @@ static char sccsid[] = "@(#)SimSelect.c	4.14 MAGIC (Berkeley) 10/3/85";
 #endif  /* not lint */
 
 #include <stdio.h>
-#ifdef SYSV
 #include <string.h>
-#else
-#include <strings.h>
-#endif
 
 #include "tcltk/tclmagic.h"
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
 #include "windows/windows.h"
 #include "dbwind/dbwind.h"
-#include "undo/undo.h"
+#include "utils/undo.h"
 #include "commands/commands.h"
 #include "select/selInt.h"
-#include "main/main.h"
+#include "utils/main.h"
 #include "utils/malloc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "sim/sim.h"
 
 /* Two cells worth of information are kept around by the selection
@@ -179,6 +175,7 @@ SimSelectNode(scx, type, xMask, buffer)
     return(strptr);
 }
 
+int
 NullFunc()
 {
     return(0);
@@ -394,7 +391,7 @@ SimSelectFunc(tile, pHead)
 	if (TTMaskHasType(&mask, type)) break;
     }
 
-    nodeName = SimSelectNode(&scx, type, 0, nameBuff);
+    nodeName = SimSelectNode(&scx, type, CU_DESCEND_ALL, nameBuff);
 
     /* add the node name to the list only if it has not been seen yet */
 
