@@ -21,25 +21,25 @@ if {! [catch {package require BLT}]} {set MagicBLT 1}
 # Simple console commands (like TkCon, but much simpler)
 
 if {[lsearch [namespace children] ::tkshell] < 0} {
-   catch {source ${CAD_HOME}/lib/magic/tcl/tkshell.tcl}
+   catch {source ${CAD_ROOT}/magic/tcl/tkshell.tcl}
 }
 
 # Button images
 
 set Glyph(up) [image create bitmap \
-	-file ${CAD_HOME}/lib/magic/tcl/bitmaps/up.xbm \
+	-file ${CAD_ROOT}/magic/tcl/bitmaps/up.xbm \
 	-background gray -foreground steelblue]
 set Glyph(down) [image create bitmap \
-	-file ${CAD_HOME}/lib/magic/tcl/bitmaps/down.xbm \
+	-file ${CAD_ROOT}/magic/tcl/bitmaps/down.xbm \
 	-background gray -foreground steelblue]
 set Glyph(left) [image create bitmap \
-	-file ${CAD_HOME}/lib/magic/tcl/bitmaps/left.xbm \
+	-file ${CAD_ROOT}/magic/tcl/bitmaps/left.xbm \
 	-background gray -foreground steelblue]
 set Glyph(right) [image create bitmap \
-	-file ${CAD_HOME}/lib/magic/tcl/bitmaps/right.xbm \
+	-file ${CAD_ROOT}/magic/tcl/bitmaps/right.xbm \
 	-background gray -foreground steelblue]
 set Glyph(zoom) [image create bitmap \
-	-file ${CAD_HOME}/lib/magic/tcl/bitmaps/zoom.xbm \
+	-file ${CAD_ROOT}/magic/tcl/bitmaps/zoom.xbm \
 	-background gray -foreground steelblue]
 
 # Menu button callback functions
@@ -419,7 +419,6 @@ proc magic::maketechmanager { mgrpath } {
 
 proc magic::techmanager {{option "update"}} {
    global tcl_precision
-   global CAD_HOME
 
    if {[catch {wm state .techmgr}]} {
       if {$option == "create"} {
@@ -507,9 +506,13 @@ proc magic::techmanager {{option "update"}} {
    set tcl_precision $psave
 }
 
-proc magic::caption {winpath} {
+proc magic::caption {winpath {subcommand {}}} {
    global Opts
 
+   if {$subcommand != {} && $subcommand != "writeable"} {
+      return;
+   }
+
    set framename [winfo parent $winpath]
    set caption [$winpath windowcaption]
    set subcaption1 [lindex $caption 0]
@@ -548,6 +551,8 @@ if {$MagicBLT} {
    magic::tag select "magic::mgrselect %R"
    magic::tag cif "magic::mgrupdate %W %1"
    magic::tag gds "magic::mgrupdate %W %1"
+} else {
+   magic::tag cellname "magic::caption %W %1"
 }
 
 # This should be a list. . . do be done later
@@ -762,6 +767,8 @@ if {$MagicBLT} {
       } elseif {${cmdstr} == "delete" || ${cmdstr} == "rename"} {
 	 magic::cellmanager
 	 magic::caption $win
+      } elseif {${cmdstr} == "writeable"} {
+	 magic::caption $win
       }
    }
 }
@@ -1193,15 +1200,6 @@ proc magic::openwrapper {{cell ""} {framename ""}} {
 		} else { \
 		wm withdraw .techmgr } }]
 
-   if {![catch {set Opts(padlist)}]} {
-      $m add check -label "Pinout List" -variable Opts(padlist) \
-		-command [subst { magic::padmanager create; \
-		if { \$Opts(padlist) } { \
-		wm deiconify .padlist ; raise .padlist \
-		} else { \
-		wm withdraw .padlist } }]
-   }
-
    $m add check -label "Netlist Window" -variable Opts(netlist) \
 	-command [subst { if { \[windownames netlist\] != {}} { \
 		   set Opts(netlist) 0 ; closewindow \[windownames netlist\] \
@@ -1280,7 +1278,6 @@ proc magic::closewrapper { framename } {
 # a wrapper window (rudimentary functionality---incomplete)
 
 proc magic::addcommandentry { framename } {
-   global CAD_HOME
    if {![winfo exists ${framename}.eval]} {
       tkshell::YScrolled_Text ${framename}.eval -height 5
       tkshell::MakeEvaluator ${framename}.eval.text \
