@@ -16,20 +16,14 @@
  *     *********************************************************************
  *
  *
- * rcsid $Header: /ufs/repository/magic/textio/textioInt.h,v 1.3 2001/08/23 13:48:57 tim Exp $
+ * rcsid $Header: /usr/cvsroot/magic/textio/textioInt.h,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $
  */
 
-#define _TEXTIOINT
+#ifndef _TEXTIOINT_H
+#define _TEXTIOINT_H
 
-#ifndef _MAGIC
-	err = Need_to_include_misc/magic_header
-#endif
-#ifndef _TEXTIO
-	err = Need_to_include_textio/textio_header
-#endif
-#ifndef _TXCOMMANDS
-	err = Need_to_include_textio/txcommands_header
-#endif
+#include "textio/textio.h"
+#include "textio/txcommands.h"
 
 extern bool txHavePrompt;
 
@@ -54,8 +48,10 @@ typedef struct {
 } txTermState;
 #endif /* SYSV */
 
-extern int TxGetInputEvent();
+extern bool TxGetInputEvent();
 
 /* Routines with variable argument lists */
 
 extern void txFprintfBasic(FILE *, ...);
+
+#endif /* _TEXTIOINT_H */
