@@ -18,34 +18,31 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/textio/txCommands.c,v 1.7 2001/07/23 20:37:01 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) ="$Header: /usr/cvsroot/magic/textio/txCommands.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#ifdef  SYSV
 #include <string.h>
-#else
-#include <strings.h>
-#endif
 #include <ctype.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/time.h>
 #include <signal.h>
-#include "misc/magsgtty.h"
 
-#include "misc/magic.h"
+#include "utils/magsgtty.h"
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "textio/txcommands.h"
 #include "textio/textioInt.h"
-#include "macros/macros.h"
+#include "utils/macros.h"
 #include "windows/windows.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "database/database.h"
+#include "dbwind/dbwind.h"
 #include "drc/drc.h"
-#include "signals/signals.h"
+#include "utils/signals.h"
 #include "graphics/graphics.h"
 #include "utils/dqueue.h"
 #include "utils/malloc.h"
@@ -69,7 +66,6 @@ static txLastInputEntry = -1;
 
 /* The current point -- reset by the 'setpoint' command and for each
  * interactive command.  Calls to TxClearPoint clear previous setpoints,
- * as do interactive commands.
  *
  * Each input point is associated with a window, as windows may use 
  * different coordinate systems.
@@ -90,9 +86,8 @@ TxInputEvent txLastEvent;
 #ifdef MAGIC_WRAPPER
 extern void send_interpreter(char *);
 
-char *TxBuffer;		/* For use with special stdin processing */
-bool TxInputRedirect;	/* For redirecting Tk events to the terminal */
-TxCommand TxCurCommand;
+char *TxBuffer;			/* For use with special stdin processing */
+unsigned char TxInputRedirect;	/* For redirecting Tk events to the terminal */
 #endif
 
 DQueue txInputEvents;
@@ -548,7 +543,7 @@ TxDelete1InputDevice(fd)
  *	None.
  *
  * Side effects:
- *	None.
+ *	Changes global set point variables.
  * ----------------------------------------------------------------------------
  */
 
@@ -571,7 +566,7 @@ TxSetPoint(x, y, wid)
  *
  * Results:
  *	integer ID of the current window, or -1 if txHaveCurrentPoint is
- *	FALSE.
+ *	TX_POINT_CLEAR
  *
  * Side effects:
  *	Current point goes into
@@ -583,7 +578,7 @@ int
 TxGetPoint(tx_p)
     Point *tx_p;
 {
-    if (txHaveCurrentPoint == TRUE)
+    if (txHaveCurrentPoint)
     {
 	if (tx_p != (Point *)NULL)
 	    *tx_p = txCurrentPoint;
@@ -971,15 +966,16 @@ txGetInteractiveCommand(block, queue)
 	if ((ch == (int)TX_LONG_CMD) || (ch == (int)TX_LONG_CMD2))
 	{
 	    (void) TxGetLinePrompt(inputLine, TX_MAX_CMDLEN, TX_CMD_PROMPT);
-	    if (inputLine[0] != '\0') MacroDefine((int)'.', inputLine, FALSE);
+	    if (inputLine[0] != '\0') MacroDefine(DBWclientID, (int)'.',
+			inputLine, FALSE);
 	    TxParseString(inputLine, queue, (TxInputEvent* ) NULL);
 	}
 	else
 	{
-	    int iMacro; /* Interactive macro */
+	    bool iMacro; /* Interactive macro */
 	    char *macroDef;
 
-	    macroDef = MacroRetrieve(ch, &iMacro);
+	    macroDef = MacroRetrieve(DBWclientID, ch, &iMacro);
 	    if (macroDef == NULL)
 	    {
 		/* Cases macroDef may be NULL:			*/
@@ -1003,7 +999,8 @@ txGetInteractiveCommand(block, queue)
 		{
 		    (void) TxGetLineWPrompt(inputLine,
 					TX_MAX_CMDLEN, TX_CMD_PROMPT, macroDef);
-		    if (inputLine[0] != '\0') MacroDefine((int)'.', inputLine, FALSE);
+		    if (inputLine[0] != '\0') MacroDefine(DBWclientID, (int)'.',
+				inputLine, FALSE);
 		    TxParseString(inputLine, queue, (TxInputEvent *) NULL);
 		}
 		else
@@ -1085,10 +1082,7 @@ txGetFileCommand(f, queue)
 		current++;
 		spaceleft--;
 	    }
-	    if (*(current-1) != '\n') goto gotline;
-	    current--;
-	    spaceleft++;
-	    if (*(current-1) != '\\') goto gotline;
+	    if ((*(current-1) != '\n') || (*(current-1) != '\\')) goto gotline;
 	    current--;
 	    spaceleft++;
 	}
@@ -1157,15 +1151,11 @@ TxTclDispatch(clientData, argc, argv)
 	tclcmd->tx_argv[n] = &tclcmd->tx_argstring[asize];
 	asize += (1 + strlen(argv[n]));
     }
-    if (txHaveCurrentPoint) {
-	tclcmd->tx_p = txCurrentPoint;
+    tclcmd->tx_p = txCurrentPoint;
+    if (txHaveCurrentPoint)
 	tclcmd->tx_wid = txCurrentWindowID;
-	txHaveCurrentPoint = FALSE;
-    }
-    else {
-	tclcmd->tx_p = TxCurCommand.tx_p;
-	tclcmd->tx_wid = TxCurCommand.tx_wid;
-    }
+    else
+	tclcmd->tx_wid = WIND_UNKNOWN_WINDOW;
 
     result = WindSendCommand((MagWindow *)clientData, tclcmd);
     TxFreeCommand(tclcmd);
@@ -1366,6 +1356,8 @@ TxDispatch(f)
 	    }
 #endif
         }
+	/* ?? */
+	WindUpdate();
 
     } /* while */
 
