@@ -21,19 +21,18 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/text
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <string.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <ctype.h>
 #include <dirent.h>
-#ifdef SYSV
-#include <string.h>
-#endif
 
 
 #include "utils/magsgtty.h"
 #include "utils/magic.h"
 #include "utils/magsgtty.h"
+#include "utils/main.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "textio/txcommands.h"
@@ -275,10 +274,6 @@ bool txHavePrompt = FALSE;	/* is a prompt on the screen? */
 char *txReprint1 = NULL;
 char *txReprint2 = NULL;
 
-#ifdef MAGIC_WRAPPER
-extern bool TxTkConsole;
-#endif
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -313,7 +308,8 @@ TxReprint()
  *	Interactive input with a prompt and a fixed set of responses
  *
  * Results:
- *	Returns the index of the response chosen.
+ *	Returns the index of the response chosen.  If no response is given,
+ *      returns the default value.
  *
  * Side effects:
  *	Terminal input and output (stdout, stdin).
@@ -327,25 +323,26 @@ TxDialog(prompt, responses, deflt)
     char *(responses[]);
     int deflt;
 {
-    int code, pos;
+    int code;
     int maxresp;
     char ans[100];
 
-    /* Sanity check on value of "deflt" */
-
-    maxresp = 0;
-    for (pos = 0; responses[pos] != NULL; pos++) maxresp++;
-    if (deflt >= maxresp) deflt = -1;
+    /* Find size of valid response set */
+    for (maxresp = 0; responses[maxresp] != NULL; maxresp++);
 
     /* Get input until something matches one of the responses */
     do
     {
 	TxPrintf("%s ", prompt);
-	TxFlushOut();
-	if (deflt >= 0)
+	if ((deflt >= 0) && (deflt < maxresp))
 	    TxPrintf("[%s] ", responses[deflt]);
+	TxFlushOut();
+
 	if (TxGetLine(ans, sizeof ans) == NULL || (ans[0] == '\0'))
+	{
+	    code = deflt;
 	    break;
+	}
     } while ((code = Lookup(ans, responses)) < 0);
 
     return code;
