@@ -17,30 +17,28 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/textio/txOutput.c,v 1.4 2001/02/21 15:52:52 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/textio/txOutput.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <stdarg.h>
+#include <string.h>
 
 #ifndef	SYSV
 #include <sys/wait.h>
-#include <strings.h>
-#else
-#include <string.h>
 #endif /* SYSV */
 #include <sys/stat.h>
 #include <unistd.h>
-#include "misc/magsgtty.h"
 
-#include "misc/magic.h"
+#include "utils/magsgtty.h"
+#include "utils/magic.h"
 #include "textio/textio.h"
 #include "utils/geometry.h"
 #include "textio/txcommands.h"
 #include "textio/textioInt.h"
 #include "windows/windows.h"
 #include "graphics/graphics.h"
-#include "misc/paths.h"
+#include "utils/paths.h"
 #include "utils/utils.h"
 #include "utils/malloc.h"
 
@@ -364,7 +362,7 @@ TxUseMore()
     /* Determine if "more" executable exists and is world executable */
     /* before attempting a fork.  Check environment variable PAGER   */
     /* first before defaulting to the built-in value PAGERDIR	     */
-    /* (see misc/paths.h).					     */
+    /* (see utils/paths.h).					     */
 
     if ((useenv = getenv("PAGER")) == NULL)
     {
