@@ -26,6 +26,8 @@ static char rcsid[] = "$Header: /usr/cvsroot/magic/utils/LIBdbio.c,v 1.1.1.1 200
 #include <unistd.h>
 #endif
 
+#include "utils/magic.h"
+
 
 /*
  * ----------------------------------------------------------------------------
@@ -45,13 +47,14 @@ static char rcsid[] = "$Header: /usr/cvsroot/magic/utils/LIBdbio.c,v 1.1.1.1 200
  */
 
 FILE *
-flock_open(filename, ext, mode)
+flock_open(filename, mode, is_locked)
     char *filename;
-    char *ext;
     char *mode;
+    bool *is_locked;
 {
     FILE *f;
 
+    if (is_locked) *is_locked = FALSE;
     f = fopen(filename, mode);
     return(f);
 }
