@@ -22,6 +22,7 @@ static char rcsid[] = "$Header: /usr/cvsroot/magic/utils/LIBmain.c,v 1.1.1.1 200
 #endif	/* not lint */
 
 #include <stdio.h>
+#include <stdlib.h>
 
 
 /*
@@ -56,7 +57,7 @@ char AbortMessage[500] = "";
  * niceabort --
  *
  * Simple version of niceabort, which dumps core and terminates the program.
- * Magic uses the more complex version found in $CAD_HOME/src/magic/misc/niceabort.c.
+ * Magic uses the more complex version found in misc/niceabort.c.
  *
  * Results:
  *	None.
