@@ -19,13 +19,13 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/utils/hash.c,v 1.2 2001/01/12 22:13:31 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/utils/hash.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
 
-#include "misc/magic.h"
+#include "utils/magic.h"
 #include "utils/hash.h"
 #include "utils/malloc.h"
 
