@@ -4,7 +4,7 @@
  *	See malloc.c for a description of magic's allocation functions.
  *	Magic's built-in malloc() function has been removed.
  *
- * rcsid "$Header: /ufs/repository/magic/utils/malloc.h,v 1.2 2001/01/12 22:13:32 jsolomon Exp $"
+ * rcsid "$Header: /usr/cvsroot/magic/utils/malloc.h,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $"
  *
  *     ********************************************************************* 
  *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
@@ -19,7 +19,11 @@
  *     *********************************************************************
  */
 
+#ifndef _MALLOC_H
+#define _MALLOC_H
+
 extern char *mallocMagic();
 extern char *callocMagic();
 extern void freeMagic();
 
+#endif
