@@ -102,7 +102,7 @@ PaAppend(char **pathptr, char *newstring)
  *	If the first character of the string indicated by psource is a
  *	dollar sign ("$") then the subsequent name is converted to the
  *	expansion of the indicated environment variable.  If the environment
- *	variable does not exist and the indicated name is "CAD_HOME", then
+ *	variable does not exist and the indicated name is "CAD_ROOT", then
  *	we substitute the value of CAD_DIR passed down from the Makefile.
  *	Otherwise, we return error status -1.
  *
@@ -221,10 +221,10 @@ PaExpand(psource, pdest, size)
 
 	if (string == NULL)
 	{
-	    /* Check for CAD_HOME = CAD_DIR, the only internal variable */
+	    /* Check for CAD_ROOT = CAD_DIR, the only internal variable */
 	    /* recognized (this is passed down from the Makefile)	*/
 
-	    if (!strcmp(expandName, "CAD_HOME"))
+	    if (!strcmp(expandName, "CAD_ROOT"))
 		string = CAD_DIR;
 	    else
 	    {
@@ -340,9 +340,8 @@ nextName(ppath, file, dest, size)
     return dest;
 }
 
-
 /*-------------------------------------------------------------------
- * PaOpen --
+ * PaLockOpen --
  *	This routine does a file lookup using the current path and
  *	supplying a default extension.
  *
@@ -373,7 +372,7 @@ nextName(ppath, file, dest, size)
  */
 
 FILE *
-PaOpen(file, mode, ext, path, library, pRealName)
+PaLockOpen(file, mode, ext, path, library, pRealName, is_locked)
     char *file;			/* Name of the file to be opened. */
     char *mode;			/* The file mode, as given to fopen. */
     char *ext;			/* The extension to be added to the file name,
@@ -393,6 +392,11 @@ PaOpen(file, mode, ext, path, library, pRealName)
 				 * the file that was successfully opened.
 				 * If NULL, then nothing is stored.
 				 */
+    bool *is_locked;		/* Pointer to a location to store the result
+				 * of the attempt to grab an advisory lock
+				 * on the file.  If NULL, then nothing is
+				 * stored.
+				 */
 {
     char extendedName[MAXSIZE], *p1, *p2;
     static char realName[MAXSIZE];
@@ -435,7 +439,7 @@ PaOpen(file, mode, ext, path, library, pRealName)
 #ifndef FILE_LOCKS
 	return fopen(realName, mode);
 #else
-	return flock_open(realName, ext, mode);
+	return flock_open(realName, mode, is_locked);
 #endif
     }
 
@@ -454,7 +458,7 @@ PaOpen(file, mode, ext, path, library, pRealName)
 #ifndef FILE_LOCKS
 	return fopen(realName, mode);
 #else
-	return flock_open(realName, ext, mode);
+	return flock_open(realName, mode, is_locked);
 #endif
     }
 
@@ -466,7 +470,7 @@ PaOpen(file, mode, ext, path, library, pRealName)
 #ifndef FILE_LOCKS
 	f = fopen(realName, mode);
 #else
-	f = flock_open(realName, ext, mode);
+	f = flock_open(realName, mode, is_locked);
 #endif
 	if (f != NULL) return f;
     }
@@ -481,7 +485,7 @@ PaOpen(file, mode, ext, path, library, pRealName)
 #ifndef FILE_LOCKS
 	f = fopen(realName, mode);
 #else
-	f = flock_open(realName, ext, mode);
+	f = flock_open(realName, mode, is_locked);
 #endif
 	if (f != NULL) return f;
     }
@@ -489,7 +493,48 @@ PaOpen(file, mode, ext, path, library, pRealName)
     return NULL;
 }
 
-
+/*
+ *-------------------------------------------------------------------
+ * PaOpen --
+ *	This is a wrapper for PaLockOpen() that is backwardly-
+ *	compatible with the original (non-file-locking) PaOpen(),
+ *	and is here because it's a pain to add an extra argument
+ *	to every call to PaOpen() when only .mag files are locked.
+ *
+ * Results:
+ *	See PaLockOpen()
+ *
+ * Side Effects:
+ *	See PaLockOpen()
+ *
+ *-------------------------------------------------------------------
+ */
+
+FILE *
+PaOpen(file, mode, ext, path, library, pRealName)
+    char *file;			/* Name of the file to be opened. */
+    char *mode;			/* The file mode, as given to fopen. */
+    char *ext;			/* The extension to be added to the file name,
+				 * or NULL.  Note:  this string must include
+				 * the dot (or whatever separator you use).
+				 */
+    char *path;			/* A search path:  a list of directory names
+				 * separated by colons or blanks.  To use
+				 * only the working directory, use "." for
+				 * the path.
+				 */
+    char *library;		/* A 2nd path containing library names.  Can be
+				 * NULL to indicate no library.
+				 */
+    char **pRealName;		/* Pointer to a location that will be filled
+				 * in with the address of the real name of
+				 * the file that was successfully opened.
+				 * If NULL, then nothing is stored.
+				 */
+{
+    return PaLockOpen(file, mode, ext, path, library, pRealName, NULL);
+}
+
 /*
  * ----------------------------------------------------------------------------
  *	PaSubsWD --
