@@ -17,11 +17,12 @@
  */
 
 #ifndef lint
-static char rcsid[]  =  "$Header: /ufs/repository/magic/utils/show.c,v 1.2 2001/01/12 22:13:33 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/utils/show.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include "misc/magic.h"
+
+#include "utils/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
 #include "graphics/graphics.h"
