@@ -62,19 +62,21 @@ extern int windOverCmd(), windUnderCmd(), windDebugCmd();
 extern int windDumpCmd(), windHelpCmd();
 extern int windMacroCmd(), windIntMacroCmd();
 extern int windLogCommandsCmd(), windUpdateCmd(), windSleepCmd();
-extern int windSourceCmd();
 extern int windSetpointCmd();
-extern int windPushbuttonCmd(), windSendCmd();
+extern int windPushbuttonCmd();
 extern int windPauseCmd(), windGrstatsCmd();
-extern int windEchoCmd(), windGrowCmd();
+extern int windGrowCmd();
 extern int windUndoCmd(), windRedoCmd();
 extern int windCenterCmd(), windScrollCmd();
 extern int windVersionCmd(), windViewCmd(), windXviewCmd(), windZoomCmd();
 extern int windScrollBarsCmd(), windPositionsCmd();
+extern int windNamesCmd();
+
 
 #ifdef MAGIC_WRAPPER
-extern int windNamesCmd();
 extern int windBypassCmd();
+#else
+extern int windEchoCmd(), windSourceCmd(), windSendCmd();
 #endif
 
 static Rect windFrameRect;
@@ -809,12 +811,10 @@ windClientInit()
     WindAddCommand(windClientID,
 	"zoom amount		zoom window by amount",
 	windZoomCmd, FALSE);
-
-#ifdef MAGIC_WRAPPER
     WindAddCommand(windClientID,
 	"windownames [all|type]	get name of current or all windows",
 	windNamesCmd, FALSE);
-#else
+#ifndef MAGIC_WRAPPER
     WindAddCommand(windClientID,
 	"echo [-n] [strings]	print text on the terminal",
 	windEchoCmd, FALSE);
