@@ -51,8 +51,8 @@ typedef ClientData WindClient;	/* A unique ID of a client of the
  * comments in windMain.c and above the proc 'WindAddClient' for more info.
  *
  * To see an example of a simple window client, look at the colormap window 
- * located in '$CAD_HOME/src/magic/cmwind/CMWmain.c'.  A more complex window is
- * the layout window, located in '$CAD_HOME/src/magic/dbwind/DBWprocs.c'.
+ * located in 'cmwind/CMWmain.c'.  A more complex window is the layout window,
+ * located in 'dbwind/DBWprocs.c'.
  *
  * The following key letters in parens after a field indicate who should 
  * read & write it:
@@ -288,6 +288,7 @@ extern void WindSeparateRedisplay();
 extern bool WindButtonInFrame();
 
 /* interface variables */
+extern int WindDefaultFlags;	/* A mask of settings to apply to new windows. */
 extern int WindNewButtons;	/* A mask of the buttons that are down now. */
 extern int WindOldButtons;	/* The buttons that were down on the previous
 				 * command.
@@ -317,7 +318,7 @@ extern int WindPackageType;
 /* Scroll bar width.
  * May be set by the graphics package before WindInit() is called.
  * If the width is XX, the window package tries to load glyphs from
- * the file 'windowsXX.glyphs' located in $CAD_HOME/lib/magic/sys.  This file
+ * the file 'windowsXX.glyphs' located in $CAD_ROOT/magic/sys.  This file
  * contains the arrow for the scroll bars, and those icons should be of
  * this width.
  */
