@@ -16,17 +16,14 @@
  *     * of the United States of America may require an export license.    * 
  *     *********************************************************************
  *
- * rcsid $Header: /ufs/repository/magic/wiring/wireInt.h,v 1.2 2001/01/12 22:13:37 jsolomon Exp $
+ * rcsid $Header: /usr/cvsroot/magic/wiring/wireInt.h,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $
  */
 
-#define _WIREINT
+#ifndef _WIREINT_H
+#define _WIREINT_H
 
-#ifndef	_MAGIC
-int err0 = Need_to_include_misc/magic_header;
-#endif	/* _MAGIC */
-#ifndef	_DATABASE
-int err0 = Need_to_include_database/database_header;
-#endif	/* _DATABASE */
+#include "utils/magic.h"
+#include "database/database.h"
 
 /* Undo-able wiring parameters: */
 
@@ -38,3 +35,5 @@ extern int WireLastDir;
 
 extern void WireRememberForUndo();
 extern void WireUndoInit();
+
+#endif /* _WIREINT_H */
